# Automatically generated by `_icons_generate_enum.py`
# See https://tabler-icons.io/

import enum


class Icon(enum.Enum):
    """Icon enum.

    We use open-source icons from Tabler, see:
        https://tabler-icons.io/
        https://github.com/tabler/tabler-icons
    """

    ICON_123 = "123"
    ICON_24_HOURS = "24-hours"
    ICON_2FA = "2fa"
    ICON_360 = "360"
    ICON_360_VIEW = "360-view"
    ICON_3D_CUBE_SPHERE = "3d-cube-sphere"
    ICON_3D_CUBE_SPHERE_OFF = "3d-cube-sphere-off"
    ICON_3D_ROTATE = "3d-rotate"
    A_B = "a-b"
    A_B_2 = "a-b-2"
    A_B_OFF = "a-b-off"
    ABACUS = "abacus"
    ABACUS_OFF = "abacus-off"
    ABC = "abc"
    ACCESS_POINT = "access-point"
    ACCESS_POINT_OFF = "access-point-off"
    ACCESSIBLE = "accessible"
    ACCESSIBLE_OFF = "accessible-off"
    ACCESSIBLE_OFF_FILLED = "accessible-off-filled"
    ACTIVITY = "activity"
    ACTIVITY_HEARTBEAT = "activity-heartbeat"
    AD = "ad"
    AD_2 = "ad-2"
    AD_CIRCLE = "ad-circle"
    AD_CIRCLE_FILLED = "ad-circle-filled"
    AD_CIRCLE_OFF = "ad-circle-off"
    AD_FILLED = "ad-filled"
    AD_OFF = "ad-off"
    ADDRESS_BOOK = "address-book"
    ADDRESS_BOOK_OFF = "address-book-off"
    ADJUSTMENTS = "adjustments"
    ADJUSTMENTS_ALT = "adjustments-alt"
    ADJUSTMENTS_BOLT = "adjustments-bolt"
    ADJUSTMENTS_CANCEL = "adjustments-cancel"
    ADJUSTMENTS_CHECK = "adjustments-check"
    ADJUSTMENTS_CODE = "adjustments-code"
    ADJUSTMENTS_COG = "adjustments-cog"
    ADJUSTMENTS_DOLLAR = "adjustments-dollar"
    ADJUSTMENTS_DOWN = "adjustments-down"
    ADJUSTMENTS_EXCLAMATION = "adjustments-exclamation"
    ADJUSTMENTS_FILLED = "adjustments-filled"
    ADJUSTMENTS_HEART = "adjustments-heart"
    ADJUSTMENTS_HORIZONTAL = "adjustments-horizontal"
    ADJUSTMENTS_MINUS = "adjustments-minus"
    ADJUSTMENTS_OFF = "adjustments-off"
    ADJUSTMENTS_PAUSE = "adjustments-pause"
    ADJUSTMENTS_PIN = "adjustments-pin"
    ADJUSTMENTS_PLUS = "adjustments-plus"
    ADJUSTMENTS_QUESTION = "adjustments-question"
    ADJUSTMENTS_SEARCH = "adjustments-search"
    ADJUSTMENTS_SHARE = "adjustments-share"
    ADJUSTMENTS_STAR = "adjustments-star"
    ADJUSTMENTS_UP = "adjustments-up"
    ADJUSTMENTS_X = "adjustments-x"
    AERIAL_LIFT = "aerial-lift"
    AFFILIATE = "affiliate"
    AFFILIATE_FILLED = "affiliate-filled"
    AIR_BALLOON = "air-balloon"
    AIR_CONDITIONING = "air-conditioning"
    AIR_CONDITIONING_DISABLED = "air-conditioning-disabled"
    ALARM = "alarm"
    ALARM_FILLED = "alarm-filled"
    ALARM_MINUS = "alarm-minus"
    ALARM_MINUS_FILLED = "alarm-minus-filled"
    ALARM_OFF = "alarm-off"
    ALARM_PLUS = "alarm-plus"
    ALARM_PLUS_FILLED = "alarm-plus-filled"
    ALARM_SNOOZE = "alarm-snooze"
    ALARM_SNOOZE_FILLED = "alarm-snooze-filled"
    ALBUM = "album"
    ALBUM_OFF = "album-off"
    ALERT_CIRCLE = "alert-circle"
    ALERT_CIRCLE_FILLED = "alert-circle-filled"
    ALERT_HEXAGON = "alert-hexagon"
    ALERT_HEXAGON_FILLED = "alert-hexagon-filled"
    ALERT_OCTAGON = "alert-octagon"
    ALERT_OCTAGON_FILLED = "alert-octagon-filled"
    ALERT_SMALL = "alert-small"
    ALERT_SQUARE = "alert-square"
    ALERT_SQUARE_FILLED = "alert-square-filled"
    ALERT_SQUARE_ROUNDED = "alert-square-rounded"
    ALERT_SQUARE_ROUNDED_FILLED = "alert-square-rounded-filled"
    ALERT_TRIANGLE = "alert-triangle"
    ALERT_TRIANGLE_FILLED = "alert-triangle-filled"
    ALIEN = "alien"
    ALIEN_FILLED = "alien-filled"
    ALIGN_BOX_BOTTOM_CENTER = "align-box-bottom-center"
    ALIGN_BOX_BOTTOM_CENTER_FILLED = "align-box-bottom-center-filled"
    ALIGN_BOX_BOTTOM_LEFT = "align-box-bottom-left"
    ALIGN_BOX_BOTTOM_LEFT_FILLED = "align-box-bottom-left-filled"
    ALIGN_BOX_BOTTOM_RIGHT = "align-box-bottom-right"
    ALIGN_BOX_BOTTOM_RIGHT_FILLED = "align-box-bottom-right-filled"
    ALIGN_BOX_CENTER_BOTTOM = "align-box-center-bottom"
    ALIGN_BOX_CENTER_MIDDLE = "align-box-center-middle"
    ALIGN_BOX_CENTER_MIDDLE_FILLED = "align-box-center-middle-filled"
    ALIGN_BOX_CENTER_STRETCH = "align-box-center-stretch"
    ALIGN_BOX_CENTER_TOP = "align-box-center-top"
    ALIGN_BOX_LEFT_BOTTOM = "align-box-left-bottom"
    ALIGN_BOX_LEFT_BOTTOM_FILLED = "align-box-left-bottom-filled"
    ALIGN_BOX_LEFT_MIDDLE = "align-box-left-middle"
    ALIGN_BOX_LEFT_MIDDLE_FILLED = "align-box-left-middle-filled"
    ALIGN_BOX_LEFT_STRETCH = "align-box-left-stretch"
    ALIGN_BOX_LEFT_TOP = "align-box-left-top"
    ALIGN_BOX_LEFT_TOP_FILLED = "align-box-left-top-filled"
    ALIGN_BOX_RIGHT_BOTTOM = "align-box-right-bottom"
    ALIGN_BOX_RIGHT_BOTTOM_FILLED = "align-box-right-bottom-filled"
    ALIGN_BOX_RIGHT_MIDDLE = "align-box-right-middle"
    ALIGN_BOX_RIGHT_MIDDLE_FILLED = "align-box-right-middle-filled"
    ALIGN_BOX_RIGHT_STRETCH = "align-box-right-stretch"
    ALIGN_BOX_RIGHT_TOP = "align-box-right-top"
    ALIGN_BOX_RIGHT_TOP_FILLED = "align-box-right-top-filled"
    ALIGN_BOX_TOP_CENTER = "align-box-top-center"
    ALIGN_BOX_TOP_CENTER_FILLED = "align-box-top-center-filled"
    ALIGN_BOX_TOP_LEFT = "align-box-top-left"
    ALIGN_BOX_TOP_LEFT_FILLED = "align-box-top-left-filled"
    ALIGN_BOX_TOP_RIGHT = "align-box-top-right"
    ALIGN_BOX_TOP_RIGHT_FILLED = "align-box-top-right-filled"
    ALIGN_CENTER = "align-center"
    ALIGN_JUSTIFIED = "align-justified"
    ALIGN_LEFT = "align-left"
    ALIGN_RIGHT = "align-right"
    ALPHA = "alpha"
    ALPHABET_CYRILLIC = "alphabet-cyrillic"
    ALPHABET_GREEK = "alphabet-greek"
    ALPHABET_LATIN = "alphabet-latin"
    AMBULANCE = "ambulance"
    AMPERSAND = "ampersand"
    ANALYZE = "analyze"
    ANALYZE_FILLED = "analyze-filled"
    ANALYZE_OFF = "analyze-off"
    ANCHOR = "anchor"
    ANCHOR_OFF = "anchor-off"
    ANGLE = "angle"
    ANKH = "ankh"
    ANTENNA = "antenna"
    ANTENNA_BARS_1 = "antenna-bars-1"
    ANTENNA_BARS_2 = "antenna-bars-2"
    ANTENNA_BARS_3 = "antenna-bars-3"
    ANTENNA_BARS_4 = "antenna-bars-4"
    ANTENNA_BARS_5 = "antenna-bars-5"
    ANTENNA_BARS_OFF = "antenna-bars-off"
    ANTENNA_OFF = "antenna-off"
    APERTURE = "aperture"
    APERTURE_OFF = "aperture-off"
    API = "api"
    API_APP = "api-app"
    API_APP_OFF = "api-app-off"
    API_OFF = "api-off"
    APP_WINDOW = "app-window"
    APP_WINDOW_FILLED = "app-window-filled"
    APPLE = "apple"
    APPS = "apps"
    APPS_FILLED = "apps-filled"
    APPS_OFF = "apps-off"
    ARCHIVE = "archive"
    ARCHIVE_FILLED = "archive-filled"
    ARCHIVE_OFF = "archive-off"
    ARMCHAIR = "armchair"
    ARMCHAIR_2 = "armchair-2"
    ARMCHAIR_2_OFF = "armchair-2-off"
    ARMCHAIR_OFF = "armchair-off"
    ARROW_AUTOFIT_CONTENT = "arrow-autofit-content"
    ARROW_AUTOFIT_CONTENT_FILLED = "arrow-autofit-content-filled"
    ARROW_AUTOFIT_DOWN = "arrow-autofit-down"
    ARROW_AUTOFIT_HEIGHT = "arrow-autofit-height"
    ARROW_AUTOFIT_LEFT = "arrow-autofit-left"
    ARROW_AUTOFIT_RIGHT = "arrow-autofit-right"
    ARROW_AUTOFIT_UP = "arrow-autofit-up"
    ARROW_AUTOFIT_WIDTH = "arrow-autofit-width"
    ARROW_BACK = "arrow-back"
    ARROW_BACK_UP = "arrow-back-up"
    ARROW_BACK_UP_DOUBLE = "arrow-back-up-double"
    ARROW_BADGE_DOWN = "arrow-badge-down"
    ARROW_BADGE_DOWN_FILLED = "arrow-badge-down-filled"
    ARROW_BADGE_LEFT = "arrow-badge-left"
    ARROW_BADGE_LEFT_FILLED = "arrow-badge-left-filled"
    ARROW_BADGE_RIGHT = "arrow-badge-right"
    ARROW_BADGE_RIGHT_FILLED = "arrow-badge-right-filled"
    ARROW_BADGE_UP = "arrow-badge-up"
    ARROW_BADGE_UP_FILLED = "arrow-badge-up-filled"
    ARROW_BAR_BOTH = "arrow-bar-both"
    ARROW_BAR_DOWN = "arrow-bar-down"
    ARROW_BAR_LEFT = "arrow-bar-left"
    ARROW_BAR_RIGHT = "arrow-bar-right"
    ARROW_BAR_TO_DOWN = "arrow-bar-to-down"
    ARROW_BAR_TO_LEFT = "arrow-bar-to-left"
    ARROW_BAR_TO_RIGHT = "arrow-bar-to-right"
    ARROW_BAR_TO_UP = "arrow-bar-to-up"
    ARROW_BAR_UP = "arrow-bar-up"
    ARROW_BEAR_LEFT = "arrow-bear-left"
    ARROW_BEAR_LEFT_2 = "arrow-bear-left-2"
    ARROW_BEAR_RIGHT = "arrow-bear-right"
    ARROW_BEAR_RIGHT_2 = "arrow-bear-right-2"
    ARROW_BIG_DOWN = "arrow-big-down"
    ARROW_BIG_DOWN_FILLED = "arrow-big-down-filled"
    ARROW_BIG_DOWN_LINE = "arrow-big-down-line"
    ARROW_BIG_DOWN_LINE_FILLED = "arrow-big-down-line-filled"
    ARROW_BIG_DOWN_LINES = "arrow-big-down-lines"
    ARROW_BIG_DOWN_LINES_FILLED = "arrow-big-down-lines-filled"
    ARROW_BIG_LEFT = "arrow-big-left"
    ARROW_BIG_LEFT_FILLED = "arrow-big-left-filled"
    ARROW_BIG_LEFT_LINE = "arrow-big-left-line"
    ARROW_BIG_LEFT_LINE_FILLED = "arrow-big-left-line-filled"
    ARROW_BIG_LEFT_LINES = "arrow-big-left-lines"
    ARROW_BIG_LEFT_LINES_FILLED = "arrow-big-left-lines-filled"
    ARROW_BIG_RIGHT = "arrow-big-right"
    ARROW_BIG_RIGHT_FILLED = "arrow-big-right-filled"
    ARROW_BIG_RIGHT_LINE = "arrow-big-right-line"
    ARROW_BIG_RIGHT_LINE_FILLED = "arrow-big-right-line-filled"
    ARROW_BIG_RIGHT_LINES = "arrow-big-right-lines"
    ARROW_BIG_RIGHT_LINES_FILLED = "arrow-big-right-lines-filled"
    ARROW_BIG_UP = "arrow-big-up"
    ARROW_BIG_UP_FILLED = "arrow-big-up-filled"
    ARROW_BIG_UP_LINE = "arrow-big-up-line"
    ARROW_BIG_UP_LINE_FILLED = "arrow-big-up-line-filled"
    ARROW_BIG_UP_LINES = "arrow-big-up-lines"
    ARROW_BIG_UP_LINES_FILLED = "arrow-big-up-lines-filled"
    ARROW_BOUNCE = "arrow-bounce"
    ARROW_CAPSULE = "arrow-capsule"
    ARROW_CURVE_LEFT = "arrow-curve-left"
    ARROW_CURVE_RIGHT = "arrow-curve-right"
    ARROW_DOWN = "arrow-down"
    ARROW_DOWN_BAR = "arrow-down-bar"
    ARROW_DOWN_CIRCLE = "arrow-down-circle"
    ARROW_DOWN_LEFT = "arrow-down-left"
    ARROW_DOWN_LEFT_CIRCLE = "arrow-down-left-circle"
    ARROW_DOWN_RHOMBUS = "arrow-down-rhombus"
    ARROW_DOWN_RIGHT = "arrow-down-right"
    ARROW_DOWN_RIGHT_CIRCLE = "arrow-down-right-circle"
    ARROW_DOWN_SQUARE = "arrow-down-square"
    ARROW_DOWN_TAIL = "arrow-down-tail"
    ARROW_ELBOW_LEFT = "arrow-elbow-left"
    ARROW_ELBOW_RIGHT = "arrow-elbow-right"
    ARROW_FORK = "arrow-fork"
    ARROW_FORWARD = "arrow-forward"
    ARROW_FORWARD_UP = "arrow-forward-up"
    ARROW_FORWARD_UP_DOUBLE = "arrow-forward-up-double"
    ARROW_GUIDE = "arrow-guide"
    ARROW_ITERATION = "arrow-iteration"
    ARROW_LEFT = "arrow-left"
    ARROW_LEFT_BAR = "arrow-left-bar"
    ARROW_LEFT_CIRCLE = "arrow-left-circle"
    ARROW_LEFT_RHOMBUS = "arrow-left-rhombus"
    ARROW_LEFT_RIGHT = "arrow-left-right"
    ARROW_LEFT_SQUARE = "arrow-left-square"
    ARROW_LEFT_TAIL = "arrow-left-tail"
    ARROW_LOOP_LEFT = "arrow-loop-left"
    ARROW_LOOP_LEFT_2 = "arrow-loop-left-2"
    ARROW_LOOP_RIGHT = "arrow-loop-right"
    ARROW_LOOP_RIGHT_2 = "arrow-loop-right-2"
    ARROW_MERGE = "arrow-merge"
    ARROW_MERGE_BOTH = "arrow-merge-both"
    ARROW_MERGE_LEFT = "arrow-merge-left"
    ARROW_MERGE_RIGHT = "arrow-merge-right"
    ARROW_MOVE_DOWN = "arrow-move-down"
    ARROW_MOVE_LEFT = "arrow-move-left"
    ARROW_MOVE_RIGHT = "arrow-move-right"
    ARROW_MOVE_UP = "arrow-move-up"
    ARROW_NARROW_DOWN = "arrow-narrow-down"
    ARROW_NARROW_LEFT = "arrow-narrow-left"
    ARROW_NARROW_RIGHT = "arrow-narrow-right"
    ARROW_NARROW_UP = "arrow-narrow-up"
    ARROW_RAMP_LEFT = "arrow-ramp-left"
    ARROW_RAMP_LEFT_2 = "arrow-ramp-left-2"
    ARROW_RAMP_LEFT_3 = "arrow-ramp-left-3"
    ARROW_RAMP_RIGHT = "arrow-ramp-right"
    ARROW_RAMP_RIGHT_2 = "arrow-ramp-right-2"
    ARROW_RAMP_RIGHT_3 = "arrow-ramp-right-3"
    ARROW_RIGHT = "arrow-right"
    ARROW_RIGHT_BAR = "arrow-right-bar"
    ARROW_RIGHT_CIRCLE = "arrow-right-circle"
    ARROW_RIGHT_RHOMBUS = "arrow-right-rhombus"
    ARROW_RIGHT_SQUARE = "arrow-right-square"
    ARROW_RIGHT_TAIL = "arrow-right-tail"
    ARROW_ROTARY_FIRST_LEFT = "arrow-rotary-first-left"
    ARROW_ROTARY_FIRST_RIGHT = "arrow-rotary-first-right"
    ARROW_ROTARY_LAST_LEFT = "arrow-rotary-last-left"
    ARROW_ROTARY_LAST_RIGHT = "arrow-rotary-last-right"
    ARROW_ROTARY_LEFT = "arrow-rotary-left"
    ARROW_ROTARY_RIGHT = "arrow-rotary-right"
    ARROW_ROTARY_STRAIGHT = "arrow-rotary-straight"
    ARROW_ROUNDABOUT_LEFT = "arrow-roundabout-left"
    ARROW_ROUNDABOUT_RIGHT = "arrow-roundabout-right"
    ARROW_SHARP_TURN_LEFT = "arrow-sharp-turn-left"
    ARROW_SHARP_TURN_RIGHT = "arrow-sharp-turn-right"
    ARROW_UP = "arrow-up"
    ARROW_UP_BAR = "arrow-up-bar"
    ARROW_UP_CIRCLE = "arrow-up-circle"
    ARROW_UP_LEFT = "arrow-up-left"
    ARROW_UP_LEFT_CIRCLE = "arrow-up-left-circle"
    ARROW_UP_RHOMBUS = "arrow-up-rhombus"
    ARROW_UP_RIGHT = "arrow-up-right"
    ARROW_UP_RIGHT_CIRCLE = "arrow-up-right-circle"
    ARROW_UP_SQUARE = "arrow-up-square"
    ARROW_UP_TAIL = "arrow-up-tail"
    ARROW_WAVE_LEFT_DOWN = "arrow-wave-left-down"
    ARROW_WAVE_LEFT_UP = "arrow-wave-left-up"
    ARROW_WAVE_RIGHT_DOWN = "arrow-wave-right-down"
    ARROW_WAVE_RIGHT_UP = "arrow-wave-right-up"
    ARROW_ZIG_ZAG = "arrow-zig-zag"
    ARROWS_CROSS = "arrows-cross"
    ARROWS_DIAGONAL = "arrows-diagonal"
    ARROWS_DIAGONAL_2 = "arrows-diagonal-2"
    ARROWS_DIAGONAL_MINIMIZE = "arrows-diagonal-minimize"
    ARROWS_DIAGONAL_MINIMIZE_2 = "arrows-diagonal-minimize-2"
    ARROWS_DIFF = "arrows-diff"
    ARROWS_DOUBLE_NE_SW = "arrows-double-ne-sw"
    ARROWS_DOUBLE_NW_SE = "arrows-double-nw-se"
    ARROWS_DOUBLE_SE_NW = "arrows-double-se-nw"
    ARROWS_DOUBLE_SW_NE = "arrows-double-sw-ne"
    ARROWS_DOWN = "arrows-down"
    ARROWS_DOWN_UP = "arrows-down-up"
    ARROWS_EXCHANGE = "arrows-exchange"
    ARROWS_EXCHANGE_2 = "arrows-exchange-2"
    ARROWS_HORIZONTAL = "arrows-horizontal"
    ARROWS_JOIN = "arrows-join"
    ARROWS_JOIN_2 = "arrows-join-2"
    ARROWS_LEFT = "arrows-left"
    ARROWS_LEFT_DOWN = "arrows-left-down"
    ARROWS_LEFT_RIGHT = "arrows-left-right"
    ARROWS_MAXIMIZE = "arrows-maximize"
    ARROWS_MINIMIZE = "arrows-minimize"
    ARROWS_MOVE = "arrows-move"
    ARROWS_MOVE_HORIZONTAL = "arrows-move-horizontal"
    ARROWS_MOVE_VERTICAL = "arrows-move-vertical"
    ARROWS_RANDOM = "arrows-random"
    ARROWS_RIGHT = "arrows-right"
    ARROWS_RIGHT_DOWN = "arrows-right-down"
    ARROWS_RIGHT_LEFT = "arrows-right-left"
    ARROWS_SHUFFLE = "arrows-shuffle"
    ARROWS_SHUFFLE_2 = "arrows-shuffle-2"
    ARROWS_SORT = "arrows-sort"
    ARROWS_SPLIT = "arrows-split"
    ARROWS_SPLIT_2 = "arrows-split-2"
    ARROWS_TRANSFER_DOWN = "arrows-transfer-down"
    ARROWS_TRANSFER_UP = "arrows-transfer-up"
    ARROWS_UP = "arrows-up"
    ARROWS_UP_DOWN = "arrows-up-down"
    ARROWS_UP_LEFT = "arrows-up-left"
    ARROWS_UP_RIGHT = "arrows-up-right"
    ARROWS_VERTICAL = "arrows-vertical"
    ARTBOARD = "artboard"
    ARTBOARD_FILLED = "artboard-filled"
    ARTBOARD_OFF = "artboard-off"
    ARTICLE = "article"
    ARTICLE_FILLED_FILLED = "article-filled-filled"
    ARTICLE_OFF = "article-off"
    ASPECT_RATIO = "aspect-ratio"
    ASPECT_RATIO_FILLED = "aspect-ratio-filled"
    ASPECT_RATIO_OFF = "aspect-ratio-off"
    ASSEMBLY = "assembly"
    ASSEMBLY_OFF = "assembly-off"
    ASSET = "asset"
    ASTERISK = "asterisk"
    ASTERISK_SIMPLE = "asterisk-simple"
    AT = "at"
    AT_OFF = "at-off"
    ATOM = "atom"
    ATOM_2 = "atom-2"
    ATOM_2_FILLED = "atom-2-filled"
    ATOM_OFF = "atom-off"
    AUGMENTED_REALITY = "augmented-reality"
    AUGMENTED_REALITY_2 = "augmented-reality-2"
    AUGMENTED_REALITY_OFF = "augmented-reality-off"
    AWARD = "award"
    AWARD_FILLED = "award-filled"
    AWARD_OFF = "award-off"
    AXE = "axe"
    AXIS_X = "axis-x"
    AXIS_Y = "axis-y"
    BABY_BOTTLE = "baby-bottle"
    BABY_CARRIAGE = "baby-carriage"
    BACKHOE = "backhoe"
    BACKPACK = "backpack"
    BACKPACK_OFF = "backpack-off"
    BACKSLASH = "backslash"
    BACKSPACE = "backspace"
    BACKSPACE_FILLED = "backspace-filled"
    BADGE = "badge"
    BADGE_3D = "badge-3d"
    BADGE_4K = "badge-4k"
    BADGE_8K = "badge-8k"
    BADGE_AD = "badge-ad"
    BADGE_AR = "badge-ar"
    BADGE_CC = "badge-cc"
    BADGE_FILLED = "badge-filled"
    BADGE_HD = "badge-hd"
    BADGE_OFF = "badge-off"
    BADGE_SD = "badge-sd"
    BADGE_TM = "badge-tm"
    BADGE_VO = "badge-vo"
    BADGE_VR = "badge-vr"
    BADGE_WC = "badge-wc"
    BADGES = "badges"
    BADGES_FILLED = "badges-filled"
    BADGES_OFF = "badges-off"
    BAGUETTE = "baguette"
    BALL_AMERICAN_FOOTBALL = "ball-american-football"
    BALL_AMERICAN_FOOTBALL_OFF = "ball-american-football-off"
    BALL_BASEBALL = "ball-baseball"
    BALL_BASKETBALL = "ball-basketball"
    BALL_BOWLING = "ball-bowling"
    BALL_FOOTBALL = "ball-football"
    BALL_FOOTBALL_OFF = "ball-football-off"
    BALL_TENNIS = "ball-tennis"
    BALL_VOLLEYBALL = "ball-volleyball"
    BALLOON = "balloon"
    BALLOON_FILLED = "balloon-filled"
    BALLOON_OFF = "balloon-off"
    BALLPEN = "ballpen"
    BALLPEN_FILLED = "ballpen-filled"
    BALLPEN_OFF = "ballpen-off"
    BAN = "ban"
    BANDAGE = "bandage"
    BANDAGE_FILLED = "bandage-filled"
    BANDAGE_OFF = "bandage-off"
    BARBELL = "barbell"
    BARBELL_OFF = "barbell-off"
    BARCODE = "barcode"
    BARCODE_OFF = "barcode-off"
    BARREL = "barrel"
    BARREL_OFF = "barrel-off"
    BARRIER_BLOCK = "barrier-block"
    BARRIER_BLOCK_OFF = "barrier-block-off"
    BASELINE = "baseline"
    BASELINE_DENSITY_LARGE = "baseline-density-large"
    BASELINE_DENSITY_MEDIUM = "baseline-density-medium"
    BASELINE_DENSITY_SMALL = "baseline-density-small"
    BASKET = "basket"
    BASKET_FILLED = "basket-filled"
    BASKET_OFF = "basket-off"
    BAT = "bat"
    BATH = "bath"
    BATH_FILLED = "bath-filled"
    BATH_OFF = "bath-off"
    BATTERY = "battery"
    BATTERY_1 = "battery-1"
    BATTERY_1_FILLED = "battery-1-filled"
    BATTERY_2 = "battery-2"
    BATTERY_2_FILLED = "battery-2-filled"
    BATTERY_3 = "battery-3"
    BATTERY_3_FILLED = "battery-3-filled"
    BATTERY_4 = "battery-4"
    BATTERY_4_FILLED = "battery-4-filled"
    BATTERY_AUTOMOTIVE = "battery-automotive"
    BATTERY_CHARGING = "battery-charging"
    BATTERY_CHARGING_2 = "battery-charging-2"
    BATTERY_ECO = "battery-eco"
    BATTERY_FILLED = "battery-filled"
    BATTERY_OFF = "battery-off"
    BEACH = "beach"
    BEACH_OFF = "beach-off"
    BED = "bed"
    BED_FILLED = "bed-filled"
    BED_OFF = "bed-off"
    BEER = "beer"
    BEER_FILLED = "beer-filled"
    BEER_OFF = "beer-off"
    BELL = "bell"
    BELL_BOLT = "bell-bolt"
    BELL_CANCEL = "bell-cancel"
    BELL_CHECK = "bell-check"
    BELL_CODE = "bell-code"
    BELL_COG = "bell-cog"
    BELL_DOLLAR = "bell-dollar"
    BELL_DOWN = "bell-down"
    BELL_EXCLAMATION = "bell-exclamation"
    BELL_FILLED = "bell-filled"
    BELL_HEART = "bell-heart"
    BELL_MINUS = "bell-minus"
    BELL_MINUS_FILLED = "bell-minus-filled"
    BELL_OFF = "bell-off"
    BELL_PAUSE = "bell-pause"
    BELL_PIN = "bell-pin"
    BELL_PLUS = "bell-plus"
    BELL_PLUS_FILLED = "bell-plus-filled"
    BELL_QUESTION = "bell-question"
    BELL_RINGING = "bell-ringing"
    BELL_RINGING_2 = "bell-ringing-2"
    BELL_RINGING_2_FILLED = "bell-ringing-2-filled"
    BELL_RINGING_FILLED = "bell-ringing-filled"
    BELL_SCHOOL = "bell-school"
    BELL_SEARCH = "bell-search"
    BELL_SHARE = "bell-share"
    BELL_STAR = "bell-star"
    BELL_UP = "bell-up"
    BELL_X = "bell-x"
    BELL_X_FILLED = "bell-x-filled"
    BELL_Z = "bell-z"
    BELL_Z_FILLED = "bell-z-filled"
    BETA = "beta"
    BIBLE = "bible"
    BIKE = "bike"
    BIKE_OFF = "bike-off"
    BINARY = "binary"
    BINARY_OFF = "binary-off"
    BINARY_TREE = "binary-tree"
    BINARY_TREE_2 = "binary-tree-2"
    BIOHAZARD = "biohazard"
    BIOHAZARD_OFF = "biohazard-off"
    BLADE = "blade"
    BLADE_FILLED = "blade-filled"
    BLEACH = "bleach"
    BLEACH_CHLORINE = "bleach-chlorine"
    BLEACH_NO_CHLORINE = "bleach-no-chlorine"
    BLEACH_OFF = "bleach-off"
    BLOCKQUOTE = "blockquote"
    BLUETOOTH = "bluetooth"
    BLUETOOTH_CONNECTED = "bluetooth-connected"
    BLUETOOTH_OFF = "bluetooth-off"
    BLUETOOTH_X = "bluetooth-x"
    BLUR = "blur"
    BLUR_OFF = "blur-off"
    BMP = "bmp"
    BOLD = "bold"
    BOLD_OFF = "bold-off"
    BOLT = "bolt"
    BOLT_OFF = "bolt-off"
    BOMB = "bomb"
    BOMB_FILLED = "bomb-filled"
    BONE = "bone"
    BONE_OFF = "bone-off"
    BONG = "bong"
    BONG_OFF = "bong-off"
    BOOK = "book"
    BOOK_2 = "book-2"
    BOOK_DOWNLOAD = "book-download"
    BOOK_FILLED = "book-filled"
    BOOK_OFF = "book-off"
    BOOK_UPLOAD = "book-upload"
    BOOKMARK = "bookmark"
    BOOKMARK_EDIT = "bookmark-edit"
    BOOKMARK_FILLED = "bookmark-filled"
    BOOKMARK_MINUS = "bookmark-minus"
    BOOKMARK_OFF = "bookmark-off"
    BOOKMARK_PLUS = "bookmark-plus"
    BOOKMARK_QUESTION = "bookmark-question"
    BOOKMARKS = "bookmarks"
    BOOKMARKS_OFF = "bookmarks-off"
    BOOKS = "books"
    BOOKS_OFF = "books-off"
    BORDER_ALL = "border-all"
    BORDER_BOTTOM = "border-bottom"
    BORDER_CORNERS = "border-corners"
    BORDER_HORIZONTAL = "border-horizontal"
    BORDER_INNER = "border-inner"
    BORDER_LEFT = "border-left"
    BORDER_NONE = "border-none"
    BORDER_OUTER = "border-outer"
    BORDER_RADIUS = "border-radius"
    BORDER_RIGHT = "border-right"
    BORDER_SIDES = "border-sides"
    BORDER_STYLE = "border-style"
    BORDER_STYLE_2 = "border-style-2"
    BORDER_TOP = "border-top"
    BORDER_VERTICAL = "border-vertical"
    BOTTLE = "bottle"
    BOTTLE_FILLED = "bottle-filled"
    BOTTLE_OFF = "bottle-off"
    BOUNCE_LEFT = "bounce-left"
    BOUNCE_RIGHT = "bounce-right"
    BOW = "bow"
    BOWL = "bowl"
    BOX = "box"
    BOX_ALIGN_BOTTOM = "box-align-bottom"
    BOX_ALIGN_BOTTOM_FILLED = "box-align-bottom-filled"
    BOX_ALIGN_BOTTOM_LEFT = "box-align-bottom-left"
    BOX_ALIGN_BOTTOM_LEFT_FILLED = "box-align-bottom-left-filled"
    BOX_ALIGN_BOTTOM_RIGHT = "box-align-bottom-right"
    BOX_ALIGN_BOTTOM_RIGHT_FILLED = "box-align-bottom-right-filled"
    BOX_ALIGN_LEFT = "box-align-left"
    BOX_ALIGN_LEFT_FILLED = "box-align-left-filled"
    BOX_ALIGN_RIGHT = "box-align-right"
    BOX_ALIGN_RIGHT_FILLED = "box-align-right-filled"
    BOX_ALIGN_TOP = "box-align-top"
    BOX_ALIGN_TOP_FILLED = "box-align-top-filled"
    BOX_ALIGN_TOP_LEFT = "box-align-top-left"
    BOX_ALIGN_TOP_LEFT_FILLED = "box-align-top-left-filled"
    BOX_ALIGN_TOP_RIGHT = "box-align-top-right"
    BOX_ALIGN_TOP_RIGHT_FILLED = "box-align-top-right-filled"
    BOX_MARGIN = "box-margin"
    BOX_MODEL = "box-model"
    BOX_MODEL_2 = "box-model-2"
    BOX_MODEL_2_OFF = "box-model-2-off"
    BOX_MODEL_OFF = "box-model-off"
    BOX_MULTIPLE = "box-multiple"
    BOX_MULTIPLE_0 = "box-multiple-0"
    BOX_MULTIPLE_1 = "box-multiple-1"
    BOX_MULTIPLE_2 = "box-multiple-2"
    BOX_MULTIPLE_3 = "box-multiple-3"
    BOX_MULTIPLE_4 = "box-multiple-4"
    BOX_MULTIPLE_5 = "box-multiple-5"
    BOX_MULTIPLE_6 = "box-multiple-6"
    BOX_MULTIPLE_7 = "box-multiple-7"
    BOX_MULTIPLE_8 = "box-multiple-8"
    BOX_MULTIPLE_9 = "box-multiple-9"
    BOX_OFF = "box-off"
    BOX_PADDING = "box-padding"
    BOX_SEAM = "box-seam"
    BRACES = "braces"
    BRACES_OFF = "braces-off"
    BRACKETS = "brackets"
    BRACKETS_CONTAIN = "brackets-contain"
    BRACKETS_CONTAIN_END = "brackets-contain-end"
    BRACKETS_CONTAIN_START = "brackets-contain-start"
    BRACKETS_OFF = "brackets-off"
    BRAILLE = "braille"
    BRAIN = "brain"
    BRAND_4CHAN = "brand-4chan"
    BRAND_ABSTRACT = "brand-abstract"
    BRAND_ADOBE = "brand-adobe"
    BRAND_ADONIS_JS = "brand-adonis-js"
    BRAND_AIRBNB = "brand-airbnb"
    BRAND_AIRTABLE = "brand-airtable"
    BRAND_ALGOLIA = "brand-algolia"
    BRAND_ALIPAY = "brand-alipay"
    BRAND_ALPINE_JS = "brand-alpine-js"
    BRAND_AMAZON = "brand-amazon"
    BRAND_AMD = "brand-amd"
    BRAND_AMIGO = "brand-amigo"
    BRAND_AMONG_US = "brand-among-us"
    BRAND_ANDROID = "brand-android"
    BRAND_ANGULAR = "brand-angular"
    BRAND_ANSIBLE = "brand-ansible"
    BRAND_AO3 = "brand-ao3"
    BRAND_APPGALLERY = "brand-appgallery"
    BRAND_APPLE = "brand-apple"
    BRAND_APPLE_ARCADE = "brand-apple-arcade"
    BRAND_APPLE_PODCAST = "brand-apple-podcast"
    BRAND_APPSTORE = "brand-appstore"
    BRAND_ASANA = "brand-asana"
    BRAND_AWS = "brand-aws"
    BRAND_AZURE = "brand-azure"
    BRAND_BACKBONE = "brand-backbone"
    BRAND_BADOO = "brand-badoo"
    BRAND_BAIDU = "brand-baidu"
    BRAND_BANDCAMP = "brand-bandcamp"
    BRAND_BANDLAB = "brand-bandlab"
    BRAND_BEATS = "brand-beats"
    BRAND_BEHANCE = "brand-behance"
    BRAND_BILIBILI = "brand-bilibili"
    BRAND_BINANCE = "brand-binance"
    BRAND_BING = "brand-bing"
    BRAND_BITBUCKET = "brand-bitbucket"
    BRAND_BLACKBERRY = "brand-blackberry"
    BRAND_BLENDER = "brand-blender"
    BRAND_BLOGGER = "brand-blogger"
    BRAND_BOOKING = "brand-booking"
    BRAND_BOOTSTRAP = "brand-bootstrap"
    BRAND_BULMA = "brand-bulma"
    BRAND_BUMBLE = "brand-bumble"
    BRAND_BUNPO = "brand-bunpo"
    BRAND_C_SHARP = "brand-c-sharp"
    BRAND_CAKE = "brand-cake"
    BRAND_CAKEPHP = "brand-cakephp"
    BRAND_CAMPAIGNMONITOR = "brand-campaignmonitor"
    BRAND_CARBON = "brand-carbon"
    BRAND_CASHAPP = "brand-cashapp"
    BRAND_CHROME = "brand-chrome"
    BRAND_CINEMA_4D = "brand-cinema-4d"
    BRAND_CITYMAPPER = "brand-citymapper"
    BRAND_CLOUDFLARE = "brand-cloudflare"
    BRAND_CODECOV = "brand-codecov"
    BRAND_CODEPEN = "brand-codepen"
    BRAND_CODESANDBOX = "brand-codesandbox"
    BRAND_COHOST = "brand-cohost"
    BRAND_COINBASE = "brand-coinbase"
    BRAND_COMEDY_CENTRAL = "brand-comedy-central"
    BRAND_COREOS = "brand-coreos"
    BRAND_COUCHDB = "brand-couchdb"
    BRAND_COUCHSURFING = "brand-couchsurfing"
    BRAND_CPP = "brand-cpp"
    BRAND_CRAFT = "brand-craft"
    BRAND_CRUNCHBASE = "brand-crunchbase"
    BRAND_CSS3 = "brand-css3"
    BRAND_CTEMPLAR = "brand-ctemplar"
    BRAND_CUCUMBER = "brand-cucumber"
    BRAND_CUPRA = "brand-cupra"
    BRAND_CYPRESS = "brand-cypress"
    BRAND_D3 = "brand-d3"
    BRAND_DAYS_COUNTER = "brand-days-counter"
    BRAND_DCOS = "brand-dcos"
    BRAND_DEBIAN = "brand-debian"
    BRAND_DEEZER = "brand-deezer"
    BRAND_DELIVEROO = "brand-deliveroo"
    BRAND_DENO = "brand-deno"
    BRAND_DENODO = "brand-denodo"
    BRAND_DEVIANTART = "brand-deviantart"
    BRAND_DIGG = "brand-digg"
    BRAND_DINGTALK = "brand-dingtalk"
    BRAND_DISCORD = "brand-discord"
    BRAND_DISCORD_FILLED = "brand-discord-filled"
    BRAND_DISNEY = "brand-disney"
    BRAND_DISQUS = "brand-disqus"
    BRAND_DJANGO = "brand-django"
    BRAND_DOCKER = "brand-docker"
    BRAND_DOCTRINE = "brand-doctrine"
    BRAND_DOLBY_DIGITAL = "brand-dolby-digital"
    BRAND_DOUBAN = "brand-douban"
    BRAND_DRIBBBLE = "brand-dribbble"
    BRAND_DRIBBBLE_FILLED = "brand-dribbble-filled"
    BRAND_DROPS = "brand-drops"
    BRAND_DRUPAL = "brand-drupal"
    BRAND_EDGE = "brand-edge"
    BRAND_ELASTIC = "brand-elastic"
    BRAND_ELECTRONIC_ARTS = "brand-electronic-arts"
    BRAND_EMBER = "brand-ember"
    BRAND_ENVATO = "brand-envato"
    BRAND_ETSY = "brand-etsy"
    BRAND_EVERNOTE = "brand-evernote"
    BRAND_FACEBOOK = "brand-facebook"
    BRAND_FACEBOOK_FILLED = "brand-facebook-filled"
    BRAND_FEEDLY = "brand-feedly"
    BRAND_FIGMA = "brand-figma"
    BRAND_FILEZILLA = "brand-filezilla"
    BRAND_FINDER = "brand-finder"
    BRAND_FIREBASE = "brand-firebase"
    BRAND_FIREFOX = "brand-firefox"
    BRAND_FIVERR = "brand-fiverr"
    BRAND_FLICKR = "brand-flickr"
    BRAND_FLIGHTRADAR24 = "brand-flightradar24"
    BRAND_FLIPBOARD = "brand-flipboard"
    BRAND_FLUTTER = "brand-flutter"
    BRAND_FORTNITE = "brand-fortnite"
    BRAND_FOURSQUARE = "brand-foursquare"
    BRAND_FRAMER = "brand-framer"
    BRAND_FRAMER_MOTION = "brand-framer-motion"
    BRAND_FUNIMATION = "brand-funimation"
    BRAND_GATSBY = "brand-gatsby"
    BRAND_GIT = "brand-git"
    BRAND_GITHUB = "brand-github"
    BRAND_GITHUB_COPILOT = "brand-github-copilot"
    BRAND_GITHUB_FILLED = "brand-github-filled"
    BRAND_GITLAB = "brand-gitlab"
    BRAND_GMAIL = "brand-gmail"
    BRAND_GOLANG = "brand-golang"
    BRAND_GOOGLE = "brand-google"
    BRAND_GOOGLE_ANALYTICS = "brand-google-analytics"
    BRAND_GOOGLE_BIG_QUERY = "brand-google-big-query"
    BRAND_GOOGLE_DRIVE = "brand-google-drive"
    BRAND_GOOGLE_FIT = "brand-google-fit"
    BRAND_GOOGLE_HOME = "brand-google-home"
    BRAND_GOOGLE_MAPS = "brand-google-maps"
    BRAND_GOOGLE_ONE = "brand-google-one"
    BRAND_GOOGLE_PHOTOS = "brand-google-photos"
    BRAND_GOOGLE_PLAY = "brand-google-play"
    BRAND_GOOGLE_PODCASTS = "brand-google-podcasts"
    BRAND_GRAMMARLY = "brand-grammarly"
    BRAND_GRAPHQL = "brand-graphql"
    BRAND_GRAVATAR = "brand-gravatar"
    BRAND_GRINDR = "brand-grindr"
    BRAND_GUARDIAN = "brand-guardian"
    BRAND_GUMROAD = "brand-gumroad"
    BRAND_HBO = "brand-hbo"
    BRAND_HEADLESSUI = "brand-headlessui"
    BRAND_HEXO = "brand-hexo"
    BRAND_HIPCHAT = "brand-hipchat"
    BRAND_HTML5 = "brand-html5"
    BRAND_INERTIA = "brand-inertia"
    BRAND_INSTAGRAM = "brand-instagram"
    BRAND_INTERCOM = "brand-intercom"
    BRAND_ITCH = "brand-itch"
    BRAND_JAVASCRIPT = "brand-javascript"
    BRAND_JUEJIN = "brand-juejin"
    BRAND_KBIN = "brand-kbin"
    BRAND_KICK = "brand-kick"
    BRAND_KICKSTARTER = "brand-kickstarter"
    BRAND_KOTLIN = "brand-kotlin"
    BRAND_LARAVEL = "brand-laravel"
    BRAND_LASTFM = "brand-lastfm"
    BRAND_LEETCODE = "brand-leetcode"
    BRAND_LETTERBOXD = "brand-letterboxd"
    BRAND_LINE = "brand-line"
    BRAND_LINKEDIN = "brand-linkedin"
    BRAND_LINKTREE = "brand-linktree"
    BRAND_LINQPAD = "brand-linqpad"
    BRAND_LOOM = "brand-loom"
    BRAND_MAILGUN = "brand-mailgun"
    BRAND_MANTINE = "brand-mantine"
    BRAND_MASTERCARD = "brand-mastercard"
    BRAND_MASTODON = "brand-mastodon"
    BRAND_MATRIX = "brand-matrix"
    BRAND_MCDONALDS = "brand-mcdonalds"
    BRAND_MEDIUM = "brand-medium"
    BRAND_MERCEDES = "brand-mercedes"
    BRAND_MESSENGER = "brand-messenger"
    BRAND_META = "brand-meta"
    BRAND_MICROSOFT_TEAMS = "brand-microsoft-teams"
    BRAND_MINECRAFT = "brand-minecraft"
    BRAND_MINIPROGRAM = "brand-miniprogram"
    BRAND_MIXPANEL = "brand-mixpanel"
    BRAND_MONDAY = "brand-monday"
    BRAND_MONGODB = "brand-mongodb"
    BRAND_MY_OPPO = "brand-my-oppo"
    BRAND_MYSQL = "brand-mysql"
    BRAND_NATIONAL_GEOGRAPHIC = "brand-national-geographic"
    BRAND_NEM = "brand-nem"
    BRAND_NETBEANS = "brand-netbeans"
    BRAND_NETEASE_MUSIC = "brand-netease-music"
    BRAND_NETFLIX = "brand-netflix"
    BRAND_NEXO = "brand-nexo"
    BRAND_NEXTCLOUD = "brand-nextcloud"
    BRAND_NEXTJS = "brand-nextjs"
    BRAND_NODEJS = "brand-nodejs"
    BRAND_NORD_VPN = "brand-nord-vpn"
    BRAND_NOTION = "brand-notion"
    BRAND_NPM = "brand-npm"
    BRAND_NUXT = "brand-nuxt"
    BRAND_NYTIMES = "brand-nytimes"
    BRAND_OAUTH = "brand-oauth"
    BRAND_OFFICE = "brand-office"
    BRAND_OK_RU = "brand-ok-ru"
    BRAND_ONEDRIVE = "brand-onedrive"
    BRAND_ONLYFANS = "brand-onlyfans"
    BRAND_OPEN_SOURCE = "brand-open-source"
    BRAND_OPENAI = "brand-openai"
    BRAND_OPENVPN = "brand-openvpn"
    BRAND_OPERA = "brand-opera"
    BRAND_PAGEKIT = "brand-pagekit"
    BRAND_PATREON = "brand-patreon"
    BRAND_PAYPAL = "brand-paypal"
    BRAND_PAYPAL_FILLED = "brand-paypal-filled"
    BRAND_PAYPAY = "brand-paypay"
    BRAND_PEANUT = "brand-peanut"
    BRAND_PEPSI = "brand-pepsi"
    BRAND_PHP = "brand-php"
    BRAND_PICSART = "brand-picsart"
    BRAND_PINTEREST = "brand-pinterest"
    BRAND_PLANETSCALE = "brand-planetscale"
    BRAND_POCKET = "brand-pocket"
    BRAND_POLYMER = "brand-polymer"
    BRAND_POWERSHELL = "brand-powershell"
    BRAND_PRISMA = "brand-prisma"
    BRAND_PRODUCTHUNT = "brand-producthunt"
    BRAND_PUSHBULLET = "brand-pushbullet"
    BRAND_PUSHOVER = "brand-pushover"
    BRAND_PYTHON = "brand-python"
    BRAND_QQ = "brand-qq"
    BRAND_RADIX_UI = "brand-radix-ui"
    BRAND_REACT = "brand-react"
    BRAND_REACT_NATIVE = "brand-react-native"
    BRAND_REASON = "brand-reason"
    BRAND_REDDIT = "brand-reddit"
    BRAND_REDHAT = "brand-redhat"
    BRAND_REDUX = "brand-redux"
    BRAND_REVOLUT = "brand-revolut"
    BRAND_RUMBLE = "brand-rumble"
    BRAND_RUST = "brand-rust"
    BRAND_SAFARI = "brand-safari"
    BRAND_SAMSUNGPASS = "brand-samsungpass"
    BRAND_SASS = "brand-sass"
    BRAND_SENTRY = "brand-sentry"
    BRAND_SHARIK = "brand-sharik"
    BRAND_SHAZAM = "brand-shazam"
    BRAND_SHOPEE = "brand-shopee"
    BRAND_SKETCH = "brand-sketch"
    BRAND_SKYPE = "brand-skype"
    BRAND_SLACK = "brand-slack"
    BRAND_SNAPCHAT = "brand-snapchat"
    BRAND_SNAPSEED = "brand-snapseed"
    BRAND_SNOWFLAKE = "brand-snowflake"
    BRAND_SOCKET_IO = "brand-socket-io"
    BRAND_SOLIDJS = "brand-solidjs"
    BRAND_SOUNDCLOUD = "brand-soundcloud"
    BRAND_SPACEHEY = "brand-spacehey"
    BRAND_SPEEDTEST = "brand-speedtest"
    BRAND_SPOTIFY = "brand-spotify"
    BRAND_STACKOVERFLOW = "brand-stackoverflow"
    BRAND_STACKSHARE = "brand-stackshare"
    BRAND_STEAM = "brand-steam"
    BRAND_STORJ = "brand-storj"
    BRAND_STORYBOOK = "brand-storybook"
    BRAND_STORYTEL = "brand-storytel"
    BRAND_STRAVA = "brand-strava"
    BRAND_STRIPE = "brand-stripe"
    BRAND_SUBLIME_TEXT = "brand-sublime-text"
    BRAND_SUGARIZER = "brand-sugarizer"
    BRAND_SUPABASE = "brand-supabase"
    BRAND_SUPERHUMAN = "brand-superhuman"
    BRAND_SUPERNOVA = "brand-supernova"
    BRAND_SURFSHARK = "brand-surfshark"
    BRAND_SVELTE = "brand-svelte"
    BRAND_SWIFT = "brand-swift"
    BRAND_SYMFONY = "brand-symfony"
    BRAND_TABLER = "brand-tabler"
    BRAND_TAILWIND = "brand-tailwind"
    BRAND_TAOBAO = "brand-taobao"
    BRAND_TED = "brand-ted"
    BRAND_TELEGRAM = "brand-telegram"
    BRAND_TERRAFORM = "brand-terraform"
    BRAND_TETHER = "brand-tether"
    BRAND_THREEJS = "brand-threejs"
    BRAND_TIDAL = "brand-tidal"
    BRAND_TIKTO_FILLED = "brand-tikto-filled"
    BRAND_TIKTOK = "brand-tiktok"
    BRAND_TINDER = "brand-tinder"
    BRAND_TOPBUZZ = "brand-topbuzz"
    BRAND_TORCHAIN = "brand-torchain"
    BRAND_TOYOTA = "brand-toyota"
    BRAND_TRELLO = "brand-trello"
    BRAND_TRIPADVISOR = "brand-tripadvisor"
    BRAND_TUMBLR = "brand-tumblr"
    BRAND_TWILIO = "brand-twilio"
    BRAND_TWITCH = "brand-twitch"
    BRAND_TWITTER = "brand-twitter"
    BRAND_TWITTER_FILLED = "brand-twitter-filled"
    BRAND_TYPESCRIPT = "brand-typescript"
    BRAND_UBER = "brand-uber"
    BRAND_UBUNTU = "brand-ubuntu"
    BRAND_UNITY = "brand-unity"
    BRAND_UNSPLASH = "brand-unsplash"
    BRAND_UPWORK = "brand-upwork"
    BRAND_VALORANT = "brand-valorant"
    BRAND_VERCEL = "brand-vercel"
    BRAND_VIMEO = "brand-vimeo"
    BRAND_VINTED = "brand-vinted"
    BRAND_VISA = "brand-visa"
    BRAND_VISUAL_STUDIO = "brand-visual-studio"
    BRAND_VITE = "brand-vite"
    BRAND_VIVALDI = "brand-vivaldi"
    BRAND_VK = "brand-vk"
    BRAND_VLC = "brand-vlc"
    BRAND_VOLKSWAGEN = "brand-volkswagen"
    BRAND_VSCO = "brand-vsco"
    BRAND_VSCODE = "brand-vscode"
    BRAND_VUE = "brand-vue"
    BRAND_WALMART = "brand-walmart"
    BRAND_WAZE = "brand-waze"
    BRAND_WEBFLOW = "brand-webflow"
    BRAND_WECHAT = "brand-wechat"
    BRAND_WEIBO = "brand-weibo"
    BRAND_WHATSAPP = "brand-whatsapp"
    BRAND_WIKIPEDIA = "brand-wikipedia"
    BRAND_WINDOWS = "brand-windows"
    BRAND_WINDY = "brand-windy"
    BRAND_WISH = "brand-wish"
    BRAND_WIX = "brand-wix"
    BRAND_WORDPRESS = "brand-wordpress"
    BRAND_XAMARIN = "brand-xamarin"
    BRAND_XBOX = "brand-xbox"
    BRAND_XING = "brand-xing"
    BRAND_YAHOO = "brand-yahoo"
    BRAND_YANDEX = "brand-yandex"
    BRAND_YATSE = "brand-yatse"
    BRAND_YCOMBINATOR = "brand-ycombinator"
    BRAND_YOUTUBE = "brand-youtube"
    BRAND_YOUTUBE_KIDS = "brand-youtube-kids"
    BRAND_ZALANDO = "brand-zalando"
    BRAND_ZAPIER = "brand-zapier"
    BRAND_ZEIT = "brand-zeit"
    BRAND_ZHIHU = "brand-zhihu"
    BRAND_ZOOM = "brand-zoom"
    BRAND_ZULIP = "brand-zulip"
    BRAND_ZWIFT = "brand-zwift"
    BREAD = "bread"
    BREAD_OFF = "bread-off"
    BRIEFCASE = "briefcase"
    BRIEFCASE_OFF = "briefcase-off"
    BRIGHTNESS = "brightness"
    BRIGHTNESS_2 = "brightness-2"
    BRIGHTNESS_DOWN = "brightness-down"
    BRIGHTNESS_HALF = "brightness-half"
    BRIGHTNESS_OFF = "brightness-off"
    BRIGHTNESS_UP = "brightness-up"
    BROADCAST = "broadcast"
    BROADCAST_OFF = "broadcast-off"
    BROWSER = "browser"
    BROWSER_CHECK = "browser-check"
    BROWSER_OFF = "browser-off"
    BROWSER_PLUS = "browser-plus"
    BROWSER_X = "browser-x"
    BRUSH = "brush"
    BRUSH_OFF = "brush-off"
    BUCKET = "bucket"
    BUCKET_DROPLET = "bucket-droplet"
    BUCKET_OFF = "bucket-off"
    BUG = "bug"
    BUG_OFF = "bug-off"
    BUILDING = "building"
    BUILDING_ARCH = "building-arch"
    BUILDING_BANK = "building-bank"
    BUILDING_BRIDGE = "building-bridge"
    BUILDING_BRIDGE_2 = "building-bridge-2"
    BUILDING_BROADCAST_TOWER = "building-broadcast-tower"
    BUILDING_CAROUSEL = "building-carousel"
    BUILDING_CASTLE = "building-castle"
    BUILDING_CHURCH = "building-church"
    BUILDING_CIRCUS = "building-circus"
    BUILDING_COMMUNITY = "building-community"
    BUILDING_COTTAGE = "building-cottage"
    BUILDING_ESTATE = "building-estate"
    BUILDING_FACTORY = "building-factory"
    BUILDING_FACTORY_2 = "building-factory-2"
    BUILDING_FORTRESS = "building-fortress"
    BUILDING_HOSPITAL = "building-hospital"
    BUILDING_LIGHTHOUSE = "building-lighthouse"
    BUILDING_MONUMENT = "building-monument"
    BUILDING_MOSQUE = "building-mosque"
    BUILDING_PAVILION = "building-pavilion"
    BUILDING_SKYSCRAPER = "building-skyscraper"
    BUILDING_STADIUM = "building-stadium"
    BUILDING_STORE = "building-store"
    BUILDING_TUNNEL = "building-tunnel"
    BUILDING_WAREHOUSE = "building-warehouse"
    BUILDING_WIND_TURBINE = "building-wind-turbine"
    BULB = "bulb"
    BULB_FILLED = "bulb-filled"
    BULB_OFF = "bulb-off"
    BULLDOZER = "bulldozer"
    BUS = "bus"
    BUS_OFF = "bus-off"
    BUS_STOP = "bus-stop"
    BUSINESSPLAN = "businessplan"
    BUTTERFLY = "butterfly"
    CACTUS = "cactus"
    CACTUS_OFF = "cactus-off"
    CAKE = "cake"
    CAKE_OFF = "cake-off"
    CALCULATOR = "calculator"
    CALCULATOR_OFF = "calculator-off"
    CALENDAR = "calendar"
    CALENDAR_BOLT = "calendar-bolt"
    CALENDAR_CANCEL = "calendar-cancel"
    CALENDAR_CHECK = "calendar-check"
    CALENDAR_CODE = "calendar-code"
    CALENDAR_COG = "calendar-cog"
    CALENDAR_DOLLAR = "calendar-dollar"
    CALENDAR_DOWN = "calendar-down"
    CALENDAR_DUE = "calendar-due"
    CALENDAR_EVENT = "calendar-event"
    CALENDAR_EXCLAMATION = "calendar-exclamation"
    CALENDAR_HEART = "calendar-heart"
    CALENDAR_MINUS = "calendar-minus"
    CALENDAR_OFF = "calendar-off"
    CALENDAR_PAUSE = "calendar-pause"
    CALENDAR_PIN = "calendar-pin"
    CALENDAR_PLUS = "calendar-plus"
    CALENDAR_QUESTION = "calendar-question"
    CALENDAR_REPEAT = "calendar-repeat"
    CALENDAR_SEARCH = "calendar-search"
    CALENDAR_SHARE = "calendar-share"
    CALENDAR_STAR = "calendar-star"
    CALENDAR_STATS = "calendar-stats"
    CALENDAR_TIME = "calendar-time"
    CALENDAR_UP = "calendar-up"
    CALENDAR_X = "calendar-x"
    CAMERA = "camera"
    CAMERA_BOLT = "camera-bolt"
    CAMERA_CANCEL = "camera-cancel"
    CAMERA_CHECK = "camera-check"
    CAMERA_CODE = "camera-code"
    CAMERA_COG = "camera-cog"
    CAMERA_DOLLAR = "camera-dollar"
    CAMERA_DOWN = "camera-down"
    CAMERA_EXCLAMATION = "camera-exclamation"
    CAMERA_FILLED = "camera-filled"
    CAMERA_HEART = "camera-heart"
    CAMERA_MINUS = "camera-minus"
    CAMERA_OFF = "camera-off"
    CAMERA_PAUSE = "camera-pause"
    CAMERA_PIN = "camera-pin"
    CAMERA_PLUS = "camera-plus"
    CAMERA_QUESTION = "camera-question"
    CAMERA_ROTATE = "camera-rotate"
    CAMERA_SEARCH = "camera-search"
    CAMERA_SELFIE = "camera-selfie"
    CAMERA_SHARE = "camera-share"
    CAMERA_STAR = "camera-star"
    CAMERA_UP = "camera-up"
    CAMERA_X = "camera-x"
    CAMPER = "camper"
    CAMPFIRE = "campfire"
    CANDLE = "candle"
    CANDY = "candy"
    CANDY_OFF = "candy-off"
    CANE = "cane"
    CANNABIS = "cannabis"
    CAPSULE = "capsule"
    CAPSULE_HORIZONTAL = "capsule-horizontal"
    CAPTURE = "capture"
    CAPTURE_OFF = "capture-off"
    CAR = "car"
    CAR_CRANE = "car-crane"
    CAR_CRASH = "car-crash"
    CAR_OFF = "car-off"
    CAR_TURBINE = "car-turbine"
    CARAVAN = "caravan"
    CARDBOARDS = "cardboards"
    CARDBOARDS_OFF = "cardboards-off"
    CARDS = "cards"
    CARET_DOWN = "caret-down"
    CARET_LEFT = "caret-left"
    CARET_RIGHT = "caret-right"
    CARET_UP = "caret-up"
    CAROUSEL_HORIZONTAL = "carousel-horizontal"
    CAROUSEL_HORIZONTAL_FILLED = "carousel-horizontal-filled"
    CAROUSEL_VERTICAL = "carousel-vertical"
    CAROUSEL_VERTICAL_FILLED = "carousel-vertical-filled"
    CARROT = "carrot"
    CARROT_OFF = "carrot-off"
    CASH = "cash"
    CASH_BANKNOTE = "cash-banknote"
    CASH_BANKNOTE_OFF = "cash-banknote-off"
    CASH_OFF = "cash-off"
    CAST = "cast"
    CAST_OFF = "cast-off"
    CAT = "cat"
    CATEGORY = "category"
    CATEGORY_2 = "category-2"
    CE = "ce"
    CE_OFF = "ce-off"
    CELL = "cell"
    CELL_SIGNAL_1 = "cell-signal-1"
    CELL_SIGNAL_2 = "cell-signal-2"
    CELL_SIGNAL_3 = "cell-signal-3"
    CELL_SIGNAL_4 = "cell-signal-4"
    CELL_SIGNAL_5 = "cell-signal-5"
    CELL_SIGNAL_OFF = "cell-signal-off"
    CERTIFICATE = "certificate"
    CERTIFICATE_2 = "certificate-2"
    CERTIFICATE_2_OFF = "certificate-2-off"
    CERTIFICATE_OFF = "certificate-off"
    CHAIR_DIRECTOR = "chair-director"
    CHALKBOARD = "chalkboard"
    CHALKBOARD_OFF = "chalkboard-off"
    CHARGING_PILE = "charging-pile"
    CHART_ARCS = "chart-arcs"
    CHART_ARCS_3 = "chart-arcs-3"
    CHART_AREA = "chart-area"
    CHART_AREA_FILLED = "chart-area-filled"
    CHART_AREA_LINE = "chart-area-line"
    CHART_AREA_LINE_FILLED = "chart-area-line-filled"
    CHART_ARROWS = "chart-arrows"
    CHART_ARROWS_VERTICAL = "chart-arrows-vertical"
    CHART_BAR = "chart-bar"
    CHART_BAR_OFF = "chart-bar-off"
    CHART_BUBBLE = "chart-bubble"
    CHART_BUBBLE_FILLED = "chart-bubble-filled"
    CHART_CANDLE = "chart-candle"
    CHART_CANDLE_FILLED = "chart-candle-filled"
    CHART_CIRCLES = "chart-circles"
    CHART_DONUT = "chart-donut"
    CHART_DONUT_2 = "chart-donut-2"
    CHART_DONUT_3 = "chart-donut-3"
    CHART_DONUT_4 = "chart-donut-4"
    CHART_DONUT_FILLED = "chart-donut-filled"
    CHART_DOTS = "chart-dots"
    CHART_DOTS_2 = "chart-dots-2"
    CHART_DOTS_3 = "chart-dots-3"
    CHART_GRID_DOTS = "chart-grid-dots"
    CHART_HISTOGRAM = "chart-histogram"
    CHART_INFOGRAPHIC = "chart-infographic"
    CHART_LINE = "chart-line"
    CHART_PIE = "chart-pie"
    CHART_PIE_2 = "chart-pie-2"
    CHART_PIE_3 = "chart-pie-3"
    CHART_PIE_4 = "chart-pie-4"
    CHART_PIE_FILLED = "chart-pie-filled"
    CHART_PIE_OFF = "chart-pie-off"
    CHART_PPF = "chart-ppf"
    CHART_RADAR = "chart-radar"
    CHART_SANKEY = "chart-sankey"
    CHART_TREEMAP = "chart-treemap"
    CHECK = "check"
    CHECKBOX = "checkbox"
    CHECKLIST = "checklist"
    CHECKS = "checks"
    CHECKUP_LIST = "checkup-list"
    CHEESE = "cheese"
    CHEF_HAT = "chef-hat"
    CHEF_HAT_OFF = "chef-hat-off"
    CHERRY = "cherry"
    CHERRY_FILLED = "cherry-filled"
    CHESS = "chess"
    CHESS_BISHOP = "chess-bishop"
    CHESS_BISHOP_FILLED = "chess-bishop-filled"
    CHESS_FILLED = "chess-filled"
    CHESS_KING = "chess-king"
    CHESS_KING_FILLED = "chess-king-filled"
    CHESS_KNIGHT = "chess-knight"
    CHESS_KNIGHT_FILLED = "chess-knight-filled"
    CHESS_QUEEN = "chess-queen"
    CHESS_QUEEN_FILLED = "chess-queen-filled"
    CHESS_ROOK = "chess-rook"
    CHESS_ROOK_FILLED = "chess-rook-filled"
    CHEVRON_COMPACT_DOWN = "chevron-compact-down"
    CHEVRON_COMPACT_LEFT = "chevron-compact-left"
    CHEVRON_COMPACT_RIGHT = "chevron-compact-right"
    CHEVRON_COMPACT_UP = "chevron-compact-up"
    CHEVRON_DOWN = "chevron-down"
    CHEVRON_DOWN_LEFT = "chevron-down-left"
    CHEVRON_DOWN_RIGHT = "chevron-down-right"
    CHEVRON_LEFT = "chevron-left"
    CHEVRON_LEFT_PIPE = "chevron-left-pipe"
    CHEVRON_RIGHT = "chevron-right"
    CHEVRON_RIGHT_PIPE = "chevron-right-pipe"
    CHEVRON_UP = "chevron-up"
    CHEVRON_UP_LEFT = "chevron-up-left"
    CHEVRON_UP_RIGHT = "chevron-up-right"
    CHEVRONS_DOWN = "chevrons-down"
    CHEVRONS_DOWN_LEFT = "chevrons-down-left"
    CHEVRONS_DOWN_RIGHT = "chevrons-down-right"
    CHEVRONS_LEFT = "chevrons-left"
    CHEVRONS_RIGHT = "chevrons-right"
    CHEVRONS_UP = "chevrons-up"
    CHEVRONS_UP_LEFT = "chevrons-up-left"
    CHEVRONS_UP_RIGHT = "chevrons-up-right"
    CHISEL = "chisel"
    CHRISTMAS_TREE = "christmas-tree"
    CHRISTMAS_TREE_OFF = "christmas-tree-off"
    CIRCLE = "circle"
    CIRCLE_0_FILLED = "circle-0-filled"
    CIRCLE_1_FILLED = "circle-1-filled"
    CIRCLE_2_FILLED = "circle-2-filled"
    CIRCLE_3_FILLED = "circle-3-filled"
    CIRCLE_4_FILLED = "circle-4-filled"
    CIRCLE_5_FILLED = "circle-5-filled"
    CIRCLE_6_FILLED = "circle-6-filled"
    CIRCLE_7_FILLED = "circle-7-filled"
    CIRCLE_8_FILLED = "circle-8-filled"
    CIRCLE_9_FILLED = "circle-9-filled"
    CIRCLE_ARROW_DOWN = "circle-arrow-down"
    CIRCLE_ARROW_DOWN_FILLED = "circle-arrow-down-filled"
    CIRCLE_ARROW_DOWN_LEFT = "circle-arrow-down-left"
    CIRCLE_ARROW_DOWN_LEFT_FILLED = "circle-arrow-down-left-filled"
    CIRCLE_ARROW_DOWN_RIGHT = "circle-arrow-down-right"
    CIRCLE_ARROW_DOWN_RIGHT_FILLED = "circle-arrow-down-right-filled"
    CIRCLE_ARROW_LEFT = "circle-arrow-left"
    CIRCLE_ARROW_LEFT_FILLED = "circle-arrow-left-filled"
    CIRCLE_ARROW_RIGHT = "circle-arrow-right"
    CIRCLE_ARROW_RIGHT_FILLED = "circle-arrow-right-filled"
    CIRCLE_ARROW_UP = "circle-arrow-up"
    CIRCLE_ARROW_UP_FILLED = "circle-arrow-up-filled"
    CIRCLE_ARROW_UP_LEFT = "circle-arrow-up-left"
    CIRCLE_ARROW_UP_LEFT_FILLED = "circle-arrow-up-left-filled"
    CIRCLE_ARROW_UP_RIGHT = "circle-arrow-up-right"
    CIRCLE_ARROW_UP_RIGHT_FILLED = "circle-arrow-up-right-filled"
    CIRCLE_CARET_DOWN = "circle-caret-down"
    CIRCLE_CARET_LEFT = "circle-caret-left"
    CIRCLE_CARET_RIGHT = "circle-caret-right"
    CIRCLE_CARET_UP = "circle-caret-up"
    CIRCLE_CHECK = "circle-check"
    CIRCLE_CHECK_FILLED = "circle-check-filled"
    CIRCLE_CHEVRON_DOWN = "circle-chevron-down"
    CIRCLE_CHEVRON_LEFT = "circle-chevron-left"
    CIRCLE_CHEVRON_RIGHT = "circle-chevron-right"
    CIRCLE_CHEVRON_UP = "circle-chevron-up"
    CIRCLE_CHEVRONS_DOWN = "circle-chevrons-down"
    CIRCLE_CHEVRONS_LEFT = "circle-chevrons-left"
    CIRCLE_CHEVRONS_RIGHT = "circle-chevrons-right"
    CIRCLE_CHEVRONS_UP = "circle-chevrons-up"
    CIRCLE_DASHED = "circle-dashed"
    CIRCLE_DOT = "circle-dot"
    CIRCLE_DOT_FILLED = "circle-dot-filled"
    CIRCLE_DOTTED = "circle-dotted"
    CIRCLE_FILLED = "circle-filled"
    CIRCLE_HALF = "circle-half"
    CIRCLE_HALF_2 = "circle-half-2"
    CIRCLE_HALF_VERTICAL = "circle-half-vertical"
    CIRCLE_KEY = "circle-key"
    CIRCLE_KEY_FILLED = "circle-key-filled"
    CIRCLE_LETTER_A = "circle-letter-a"
    CIRCLE_LETTER_B = "circle-letter-b"
    CIRCLE_LETTER_C = "circle-letter-c"
    CIRCLE_LETTER_D = "circle-letter-d"
    CIRCLE_LETTER_E = "circle-letter-e"
    CIRCLE_LETTER_F = "circle-letter-f"
    CIRCLE_LETTER_G = "circle-letter-g"
    CIRCLE_LETTER_H = "circle-letter-h"
    CIRCLE_LETTER_I = "circle-letter-i"
    CIRCLE_LETTER_J = "circle-letter-j"
    CIRCLE_LETTER_K = "circle-letter-k"
    CIRCLE_LETTER_L = "circle-letter-l"
    CIRCLE_LETTER_M = "circle-letter-m"
    CIRCLE_LETTER_N = "circle-letter-n"
    CIRCLE_LETTER_O = "circle-letter-o"
    CIRCLE_LETTER_P = "circle-letter-p"
    CIRCLE_LETTER_Q = "circle-letter-q"
    CIRCLE_LETTER_R = "circle-letter-r"
    CIRCLE_LETTER_S = "circle-letter-s"
    CIRCLE_LETTER_T = "circle-letter-t"
    CIRCLE_LETTER_U = "circle-letter-u"
    CIRCLE_LETTER_V = "circle-letter-v"
    CIRCLE_LETTER_W = "circle-letter-w"
    CIRCLE_LETTER_X = "circle-letter-x"
    CIRCLE_LETTER_Y = "circle-letter-y"
    CIRCLE_LETTER_Z = "circle-letter-z"
    CIRCLE_MINUS = "circle-minus"
    CIRCLE_NUMBER_0 = "circle-number-0"
    CIRCLE_NUMBER_1 = "circle-number-1"
    CIRCLE_NUMBER_2 = "circle-number-2"
    CIRCLE_NUMBER_3 = "circle-number-3"
    CIRCLE_NUMBER_4 = "circle-number-4"
    CIRCLE_NUMBER_5 = "circle-number-5"
    CIRCLE_NUMBER_6 = "circle-number-6"
    CIRCLE_NUMBER_7 = "circle-number-7"
    CIRCLE_NUMBER_8 = "circle-number-8"
    CIRCLE_NUMBER_9 = "circle-number-9"
    CIRCLE_OFF = "circle-off"
    CIRCLE_PLUS = "circle-plus"
    CIRCLE_RECTANGLE = "circle-rectangle"
    CIRCLE_RECTANGLE_OFF = "circle-rectangle-off"
    CIRCLE_SQUARE = "circle-square"
    CIRCLE_TRIANGLE = "circle-triangle"
    CIRCLE_X = "circle-x"
    CIRCLE_X_FILLED = "circle-x-filled"
    CIRCLES = "circles"
    CIRCLES_FILLED = "circles-filled"
    CIRCLES_RELATION = "circles-relation"
    CIRCUIT_AMMETER = "circuit-ammeter"
    CIRCUIT_BATTERY = "circuit-battery"
    CIRCUIT_BULB = "circuit-bulb"
    CIRCUIT_CAPACITOR = "circuit-capacitor"
    CIRCUIT_CAPACITOR_POLARIZED = "circuit-capacitor-polarized"
    CIRCUIT_CELL = "circuit-cell"
    CIRCUIT_CELL_PLUS = "circuit-cell-plus"
    CIRCUIT_CHANGEOVER = "circuit-changeover"
    CIRCUIT_DIODE = "circuit-diode"
    CIRCUIT_DIODE_ZENER = "circuit-diode-zener"
    CIRCUIT_GROUND = "circuit-ground"
    CIRCUIT_GROUND_DIGITAL = "circuit-ground-digital"
    CIRCUIT_INDUCTOR = "circuit-inductor"
    CIRCUIT_MOTOR = "circuit-motor"
    CIRCUIT_PUSHBUTTON = "circuit-pushbutton"
    CIRCUIT_RESISTOR = "circuit-resistor"
    CIRCUIT_SWITCH_CLOSED = "circuit-switch-closed"
    CIRCUIT_SWITCH_OPEN = "circuit-switch-open"
    CIRCUIT_VOLTMETER = "circuit-voltmeter"
    CLEAR_ALL = "clear-all"
    CLEAR_FORMATTING = "clear-formatting"
    CLICK = "click"
    CLIPBOARD = "clipboard"
    CLIPBOARD_CHECK = "clipboard-check"
    CLIPBOARD_COPY = "clipboard-copy"
    CLIPBOARD_DATA = "clipboard-data"
    CLIPBOARD_HEART = "clipboard-heart"
    CLIPBOARD_LIST = "clipboard-list"
    CLIPBOARD_OFF = "clipboard-off"
    CLIPBOARD_PLUS = "clipboard-plus"
    CLIPBOARD_TEXT = "clipboard-text"
    CLIPBOARD_TYPOGRAPHY = "clipboard-typography"
    CLIPBOARD_X = "clipboard-x"
    CLOCK = "clock"
    CLOCK_2 = "clock-2"
    CLOCK_BOLT = "clock-bolt"
    CLOCK_CANCEL = "clock-cancel"
    CLOCK_CHECK = "clock-check"
    CLOCK_CODE = "clock-code"
    CLOCK_COG = "clock-cog"
    CLOCK_DOLLAR = "clock-dollar"
    CLOCK_DOWN = "clock-down"
    CLOCK_EDIT = "clock-edit"
    CLOCK_EXCLAMATION = "clock-exclamation"
    CLOCK_FILLED = "clock-filled"
    CLOCK_HEART = "clock-heart"
    CLOCK_HOUR_1 = "clock-hour-1"
    CLOCK_HOUR_10 = "clock-hour-10"
    CLOCK_HOUR_11 = "clock-hour-11"
    CLOCK_HOUR_12 = "clock-hour-12"
    CLOCK_HOUR_2 = "clock-hour-2"
    CLOCK_HOUR_3 = "clock-hour-3"
    CLOCK_HOUR_4 = "clock-hour-4"
    CLOCK_HOUR_5 = "clock-hour-5"
    CLOCK_HOUR_6 = "clock-hour-6"
    CLOCK_HOUR_7 = "clock-hour-7"
    CLOCK_HOUR_8 = "clock-hour-8"
    CLOCK_HOUR_9 = "clock-hour-9"
    CLOCK_MINUS = "clock-minus"
    CLOCK_OFF = "clock-off"
    CLOCK_PAUSE = "clock-pause"
    CLOCK_PIN = "clock-pin"
    CLOCK_PLAY = "clock-play"
    CLOCK_PLUS = "clock-plus"
    CLOCK_QUESTION = "clock-question"
    CLOCK_RECORD = "clock-record"
    CLOCK_SEARCH = "clock-search"
    CLOCK_SHARE = "clock-share"
    CLOCK_SHIELD = "clock-shield"
    CLOCK_STAR = "clock-star"
    CLOCK_STOP = "clock-stop"
    CLOCK_UP = "clock-up"
    CLOCK_X = "clock-x"
    CLOTHES_RACK = "clothes-rack"
    CLOTHES_RACK_OFF = "clothes-rack-off"
    CLOUD = "cloud"
    CLOUD_BOLT = "cloud-bolt"
    CLOUD_CANCEL = "cloud-cancel"
    CLOUD_CHECK = "cloud-check"
    CLOUD_CODE = "cloud-code"
    CLOUD_COG = "cloud-cog"
    CLOUD_COMPUTING = "cloud-computing"
    CLOUD_DATA_CONNECTION = "cloud-data-connection"
    CLOUD_DOLLAR = "cloud-dollar"
    CLOUD_DOWN = "cloud-down"
    CLOUD_DOWNLOAD = "cloud-download"
    CLOUD_EXCLAMATION = "cloud-exclamation"
    CLOUD_FILLED = "cloud-filled"
    CLOUD_FOG = "cloud-fog"
    CLOUD_HEART = "cloud-heart"
    CLOUD_LOCK = "cloud-lock"
    CLOUD_LOCK_OPEN = "cloud-lock-open"
    CLOUD_MINUS = "cloud-minus"
    CLOUD_OFF = "cloud-off"
    CLOUD_PAUSE = "cloud-pause"
    CLOUD_PIN = "cloud-pin"
    CLOUD_PLUS = "cloud-plus"
    CLOUD_QUESTION = "cloud-question"
    CLOUD_RAIN = "cloud-rain"
    CLOUD_SEARCH = "cloud-search"
    CLOUD_SHARE = "cloud-share"
    CLOUD_SNOW = "cloud-snow"
    CLOUD_STAR = "cloud-star"
    CLOUD_STORM = "cloud-storm"
    CLOUD_UP = "cloud-up"
    CLOUD_UPLOAD = "cloud-upload"
    CLOUD_X = "cloud-x"
    CLOVER = "clover"
    CLOVER_2 = "clover-2"
    CLUBS = "clubs"
    CLUBS_FILLED = "clubs-filled"
    CODE = "code"
    CODE_ASTERIX = "code-asterix"
    CODE_CIRCLE = "code-circle"
    CODE_CIRCLE_2 = "code-circle-2"
    CODE_DOTS = "code-dots"
    CODE_MINUS = "code-minus"
    CODE_OFF = "code-off"
    CODE_PLUS = "code-plus"
    COFFEE = "coffee"
    COFFEE_OFF = "coffee-off"
    COFFIN = "coffin"
    COIN = "coin"
    COIN_BITCOIN = "coin-bitcoin"
    COIN_EURO = "coin-euro"
    COIN_MONERO = "coin-monero"
    COIN_OFF = "coin-off"
    COIN_POUND = "coin-pound"
    COIN_RUPEE = "coin-rupee"
    COIN_YEN = "coin-yen"
    COIN_YUAN = "coin-yuan"
    COINS = "coins"
    COLOR_FILTER = "color-filter"
    COLOR_PICKER = "color-picker"
    COLOR_PICKER_OFF = "color-picker-off"
    COLOR_SWATCH = "color-swatch"
    COLOR_SWATCH_OFF = "color-swatch-off"
    COLUMN_INSERT_LEFT = "column-insert-left"
    COLUMN_INSERT_RIGHT = "column-insert-right"
    COLUMN_REMOVE = "column-remove"
    COLUMNS = "columns"
    COLUMNS_1 = "columns-1"
    COLUMNS_2 = "columns-2"
    COLUMNS_3 = "columns-3"
    COLUMNS_OFF = "columns-off"
    COMET = "comet"
    COMMAND = "command"
    COMMAND_OFF = "command-off"
    COMPASS = "compass"
    COMPASS_OFF = "compass-off"
    COMPONENTS = "components"
    COMPONENTS_OFF = "components-off"
    CONE = "cone"
    CONE_2 = "cone-2"
    CONE_OFF = "cone-off"
    CONE_PLUS = "cone-plus"
    CONFETTI = "confetti"
    CONFETTI_OFF = "confetti-off"
    CONFUCIUS = "confucius"
    CONTAINER = "container"
    CONTAINER_OFF = "container-off"
    CONTRAST = "contrast"
    CONTRAST_2 = "contrast-2"
    CONTRAST_2_OFF = "contrast-2-off"
    CONTRAST_OFF = "contrast-off"
    COOKER = "cooker"
    COOKIE = "cookie"
    COOKIE_MAN = "cookie-man"
    COOKIE_OFF = "cookie-off"
    COPY = "copy"
    COPY_OFF = "copy-off"
    COPYLEFT = "copyleft"
    COPYLEFT_FILLED = "copyleft-filled"
    COPYLEFT_OFF = "copyleft-off"
    COPYRIGHT = "copyright"
    COPYRIGHT_FILLED = "copyright-filled"
    COPYRIGHT_OFF = "copyright-off"
    CORNER_DOWN_LEFT = "corner-down-left"
    CORNER_DOWN_LEFT_DOUBLE = "corner-down-left-double"
    CORNER_DOWN_RIGHT = "corner-down-right"
    CORNER_DOWN_RIGHT_DOUBLE = "corner-down-right-double"
    CORNER_LEFT_DOWN = "corner-left-down"
    CORNER_LEFT_DOWN_DOUBLE = "corner-left-down-double"
    CORNER_LEFT_UP = "corner-left-up"
    CORNER_LEFT_UP_DOUBLE = "corner-left-up-double"
    CORNER_RIGHT_DOWN = "corner-right-down"
    CORNER_RIGHT_DOWN_DOUBLE = "corner-right-down-double"
    CORNER_RIGHT_UP = "corner-right-up"
    CORNER_RIGHT_UP_DOUBLE = "corner-right-up-double"
    CORNER_UP_LEFT = "corner-up-left"
    CORNER_UP_LEFT_DOUBLE = "corner-up-left-double"
    CORNER_UP_RIGHT = "corner-up-right"
    CORNER_UP_RIGHT_DOUBLE = "corner-up-right-double"
    CPU = "cpu"
    CPU_2 = "cpu-2"
    CPU_OFF = "cpu-off"
    CRANE = "crane"
    CRANE_OFF = "crane-off"
    CREATIVE_COMMONS = "creative-commons"
    CREATIVE_COMMONS_BY = "creative-commons-by"
    CREATIVE_COMMONS_NC = "creative-commons-nc"
    CREATIVE_COMMONS_ND = "creative-commons-nd"
    CREATIVE_COMMONS_OFF = "creative-commons-off"
    CREATIVE_COMMONS_SA = "creative-commons-sa"
    CREATIVE_COMMONS_ZERO = "creative-commons-zero"
    CREDIT_CARD = "credit-card"
    CREDIT_CARD_OFF = "credit-card-off"
    CRICKET = "cricket"
    CROP = "crop"
    CROSS = "cross"
    CROSS_FILLED = "cross-filled"
    CROSS_OFF = "cross-off"
    CROSSHAIR = "crosshair"
    CROWN = "crown"
    CROWN_OFF = "crown-off"
    CRUTCHES = "crutches"
    CRUTCHES_OFF = "crutches-off"
    CRYSTAL_BALL = "crystal-ball"
    CSV = "csv"
    CUBE = "cube"
    CUBE_OFF = "cube-off"
    CUBE_PLUS = "cube-plus"
    CUBE_SEND = "cube-send"
    CUBE_UNFOLDED = "cube-unfolded"
    CUP = "cup"
    CUP_OFF = "cup-off"
    CURLING = "curling"
    CURLY_LOOP = "curly-loop"
    CURRENCY = "currency"
    CURRENCY_AFGHANI = "currency-afghani"
    CURRENCY_BAHRAINI = "currency-bahraini"
    CURRENCY_BAHT = "currency-baht"
    CURRENCY_BITCOIN = "currency-bitcoin"
    CURRENCY_CENT = "currency-cent"
    CURRENCY_DINAR = "currency-dinar"
    CURRENCY_DIRHAM = "currency-dirham"
    CURRENCY_DOGECOIN = "currency-dogecoin"
    CURRENCY_DOLLAR = "currency-dollar"
    CURRENCY_DOLLAR_AUSTRALIAN = "currency-dollar-australian"
    CURRENCY_DOLLAR_BRUNEI = "currency-dollar-brunei"
    CURRENCY_DOLLAR_CANADIAN = "currency-dollar-canadian"
    CURRENCY_DOLLAR_GUYANESE = "currency-dollar-guyanese"
    CURRENCY_DOLLAR_OFF = "currency-dollar-off"
    CURRENCY_DOLLAR_SINGAPORE = "currency-dollar-singapore"
    CURRENCY_DOLLAR_ZIMBABWEAN = "currency-dollar-zimbabwean"
    CURRENCY_DONG = "currency-dong"
    CURRENCY_DRAM = "currency-dram"
    CURRENCY_ETHEREUM = "currency-ethereum"
    CURRENCY_EURO = "currency-euro"
    CURRENCY_EURO_OFF = "currency-euro-off"
    CURRENCY_FLORIN = "currency-florin"
    CURRENCY_FORINT = "currency-forint"
    CURRENCY_FRANK = "currency-frank"
    CURRENCY_GUARANI = "currency-guarani"
    CURRENCY_HRYVNIA = "currency-hryvnia"
    CURRENCY_IRANIAN_RIAL = "currency-iranian-rial"
    CURRENCY_KIP = "currency-kip"
    CURRENCY_KRONE_CZECH = "currency-krone-czech"
    CURRENCY_KRONE_DANISH = "currency-krone-danish"
    CURRENCY_KRONE_SWEDISH = "currency-krone-swedish"
    CURRENCY_LARI = "currency-lari"
    CURRENCY_LEU = "currency-leu"
    CURRENCY_LIRA = "currency-lira"
    CURRENCY_LITECOIN = "currency-litecoin"
    CURRENCY_LYD = "currency-lyd"
    CURRENCY_MANAT = "currency-manat"
    CURRENCY_MONERO = "currency-monero"
    CURRENCY_NAIRA = "currency-naira"
    CURRENCY_NANO = "currency-nano"
    CURRENCY_OFF = "currency-off"
    CURRENCY_PAANGA = "currency-paanga"
    CURRENCY_PESO = "currency-peso"
    CURRENCY_POUND = "currency-pound"
    CURRENCY_POUND_OFF = "currency-pound-off"
    CURRENCY_QUETZAL = "currency-quetzal"
    CURRENCY_REAL = "currency-real"
    CURRENCY_RENMINBI = "currency-renminbi"
    CURRENCY_RIPPLE = "currency-ripple"
    CURRENCY_RIYAL = "currency-riyal"
    CURRENCY_RUBEL = "currency-rubel"
    CURRENCY_RUFIYAA = "currency-rufiyaa"
    CURRENCY_RUPEE = "currency-rupee"
    CURRENCY_RUPEE_NEPALESE = "currency-rupee-nepalese"
    CURRENCY_SHEKEL = "currency-shekel"
    CURRENCY_SOLANA = "currency-solana"
    CURRENCY_SOM = "currency-som"
    CURRENCY_TAKA = "currency-taka"
    CURRENCY_TENGE = "currency-tenge"
    CURRENCY_TUGRIK = "currency-tugrik"
    CURRENCY_WON = "currency-won"
    CURRENCY_YEN = "currency-yen"
    CURRENCY_YEN_OFF = "currency-yen-off"
    CURRENCY_YUAN = "currency-yuan"
    CURRENCY_ZLOTY = "currency-zloty"
    CURRENT_LOCATION = "current-location"
    CURRENT_LOCATION_OFF = "current-location-off"
    CURSOR_OFF = "cursor-off"
    CURSOR_TEXT = "cursor-text"
    CUT = "cut"
    CYLINDER = "cylinder"
    CYLINDER_OFF = "cylinder-off"
    CYLINDER_PLUS = "cylinder-plus"
    DASHBOARD = "dashboard"
    DASHBOARD_OFF = "dashboard-off"
    DATABASE = "database"
    DATABASE_COG = "database-cog"
    DATABASE_DOLLAR = "database-dollar"
    DATABASE_EDIT = "database-edit"
    DATABASE_EXCLAMATION = "database-exclamation"
    DATABASE_EXPORT = "database-export"
    DATABASE_HEART = "database-heart"
    DATABASE_IMPORT = "database-import"
    DATABASE_LEAK = "database-leak"
    DATABASE_MINUS = "database-minus"
    DATABASE_OFF = "database-off"
    DATABASE_PLUS = "database-plus"
    DATABASE_SEARCH = "database-search"
    DATABASE_SHARE = "database-share"
    DATABASE_STAR = "database-star"
    DATABASE_X = "database-x"
    DECIMAL = "decimal"
    DEER = "deer"
    DELTA = "delta"
    DENTAL = "dental"
    DENTAL_BROKEN = "dental-broken"
    DENTAL_OFF = "dental-off"
    DESELECT = "deselect"
    DETAILS = "details"
    DETAILS_OFF = "details-off"
    DEVICE_AIRPODS = "device-airpods"
    DEVICE_AIRPODS_CASE = "device-airpods-case"
    DEVICE_AIRTAG = "device-airtag"
    DEVICE_ANALYTICS = "device-analytics"
    DEVICE_AUDIO_TAPE = "device-audio-tape"
    DEVICE_CAMERA_PHONE = "device-camera-phone"
    DEVICE_CCTV = "device-cctv"
    DEVICE_CCTV_OFF = "device-cctv-off"
    DEVICE_COMPUTER_CAMERA = "device-computer-camera"
    DEVICE_COMPUTER_CAMERA_OFF = "device-computer-camera-off"
    DEVICE_DESKTOP = "device-desktop"
    DEVICE_DESKTOP_ANALYTICS = "device-desktop-analytics"
    DEVICE_DESKTOP_BOLT = "device-desktop-bolt"
    DEVICE_DESKTOP_CANCEL = "device-desktop-cancel"
    DEVICE_DESKTOP_CHECK = "device-desktop-check"
    DEVICE_DESKTOP_CODE = "device-desktop-code"
    DEVICE_DESKTOP_COG = "device-desktop-cog"
    DEVICE_DESKTOP_DOLLAR = "device-desktop-dollar"
    DEVICE_DESKTOP_DOWN = "device-desktop-down"
    DEVICE_DESKTOP_EXCLAMATION = "device-desktop-exclamation"
    DEVICE_DESKTOP_HEART = "device-desktop-heart"
    DEVICE_DESKTOP_MINUS = "device-desktop-minus"
    DEVICE_DESKTOP_OFF = "device-desktop-off"
    DEVICE_DESKTOP_PAUSE = "device-desktop-pause"
    DEVICE_DESKTOP_PIN = "device-desktop-pin"
    DEVICE_DESKTOP_PLUS = "device-desktop-plus"
    DEVICE_DESKTOP_QUESTION = "device-desktop-question"
    DEVICE_DESKTOP_SEARCH = "device-desktop-search"
    DEVICE_DESKTOP_SHARE = "device-desktop-share"
    DEVICE_DESKTOP_STAR = "device-desktop-star"
    DEVICE_DESKTOP_UP = "device-desktop-up"
    DEVICE_DESKTOP_X = "device-desktop-x"
    DEVICE_FLOPPY = "device-floppy"
    DEVICE_GAMEPAD = "device-gamepad"
    DEVICE_GAMEPAD_2 = "device-gamepad-2"
    DEVICE_HEART_MONITOR = "device-heart-monitor"
    DEVICE_HEART_MONITOR_FILLED = "device-heart-monitor-filled"
    DEVICE_IMAC = "device-imac"
    DEVICE_IMAC_BOLT = "device-imac-bolt"
    DEVICE_IMAC_CANCEL = "device-imac-cancel"
    DEVICE_IMAC_CHECK = "device-imac-check"
    DEVICE_IMAC_CODE = "device-imac-code"
    DEVICE_IMAC_COG = "device-imac-cog"
    DEVICE_IMAC_DOLLAR = "device-imac-dollar"
    DEVICE_IMAC_DOWN = "device-imac-down"
    DEVICE_IMAC_EXCLAMATION = "device-imac-exclamation"
    DEVICE_IMAC_HEART = "device-imac-heart"
    DEVICE_IMAC_MINUS = "device-imac-minus"
    DEVICE_IMAC_OFF = "device-imac-off"
    DEVICE_IMAC_PAUSE = "device-imac-pause"
    DEVICE_IMAC_PIN = "device-imac-pin"
    DEVICE_IMAC_PLUS = "device-imac-plus"
    DEVICE_IMAC_QUESTION = "device-imac-question"
    DEVICE_IMAC_SEARCH = "device-imac-search"
    DEVICE_IMAC_SHARE = "device-imac-share"
    DEVICE_IMAC_STAR = "device-imac-star"
    DEVICE_IMAC_UP = "device-imac-up"
    DEVICE_IMAC_X = "device-imac-x"
    DEVICE_IPAD = "device-ipad"
    DEVICE_IPAD_BOLT = "device-ipad-bolt"
    DEVICE_IPAD_CANCEL = "device-ipad-cancel"
    DEVICE_IPAD_CHECK = "device-ipad-check"
    DEVICE_IPAD_CODE = "device-ipad-code"
    DEVICE_IPAD_COG = "device-ipad-cog"
    DEVICE_IPAD_DOLLAR = "device-ipad-dollar"
    DEVICE_IPAD_DOWN = "device-ipad-down"
    DEVICE_IPAD_EXCLAMATION = "device-ipad-exclamation"
    DEVICE_IPAD_HEART = "device-ipad-heart"
    DEVICE_IPAD_HORIZONTAL = "device-ipad-horizontal"
    DEVICE_IPAD_HORIZONTAL_BOLT = "device-ipad-horizontal-bolt"
    DEVICE_IPAD_HORIZONTAL_CANCEL = "device-ipad-horizontal-cancel"
    DEVICE_IPAD_HORIZONTAL_CHECK = "device-ipad-horizontal-check"
    DEVICE_IPAD_HORIZONTAL_CODE = "device-ipad-horizontal-code"
    DEVICE_IPAD_HORIZONTAL_COG = "device-ipad-horizontal-cog"
    DEVICE_IPAD_HORIZONTAL_DOLLAR = "device-ipad-horizontal-dollar"
    DEVICE_IPAD_HORIZONTAL_DOWN = "device-ipad-horizontal-down"
    DEVICE_IPAD_HORIZONTAL_EXCLAMATION = "device-ipad-horizontal-exclamation"
    DEVICE_IPAD_HORIZONTAL_HEART = "device-ipad-horizontal-heart"
    DEVICE_IPAD_HORIZONTAL_MINUS = "device-ipad-horizontal-minus"
    DEVICE_IPAD_HORIZONTAL_OFF = "device-ipad-horizontal-off"
    DEVICE_IPAD_HORIZONTAL_PAUSE = "device-ipad-horizontal-pause"
    DEVICE_IPAD_HORIZONTAL_PIN = "device-ipad-horizontal-pin"
    DEVICE_IPAD_HORIZONTAL_PLUS = "device-ipad-horizontal-plus"
    DEVICE_IPAD_HORIZONTAL_QUESTION = "device-ipad-horizontal-question"
    DEVICE_IPAD_HORIZONTAL_SEARCH = "device-ipad-horizontal-search"
    DEVICE_IPAD_HORIZONTAL_SHARE = "device-ipad-horizontal-share"
    DEVICE_IPAD_HORIZONTAL_STAR = "device-ipad-horizontal-star"
    DEVICE_IPAD_HORIZONTAL_UP = "device-ipad-horizontal-up"
    DEVICE_IPAD_HORIZONTAL_X = "device-ipad-horizontal-x"
    DEVICE_IPAD_MINUS = "device-ipad-minus"
    DEVICE_IPAD_OFF = "device-ipad-off"
    DEVICE_IPAD_PAUSE = "device-ipad-pause"
    DEVICE_IPAD_PIN = "device-ipad-pin"
    DEVICE_IPAD_PLUS = "device-ipad-plus"
    DEVICE_IPAD_QUESTION = "device-ipad-question"
    DEVICE_IPAD_SEARCH = "device-ipad-search"
    DEVICE_IPAD_SHARE = "device-ipad-share"
    DEVICE_IPAD_STAR = "device-ipad-star"
    DEVICE_IPAD_UP = "device-ipad-up"
    DEVICE_IPAD_X = "device-ipad-x"
    DEVICE_LANDLINE_PHONE = "device-landline-phone"
    DEVICE_LAPTOP = "device-laptop"
    DEVICE_LAPTOP_OFF = "device-laptop-off"
    DEVICE_MOBILE = "device-mobile"
    DEVICE_MOBILE_BOLT = "device-mobile-bolt"
    DEVICE_MOBILE_CANCEL = "device-mobile-cancel"
    DEVICE_MOBILE_CHARGING = "device-mobile-charging"
    DEVICE_MOBILE_CHECK = "device-mobile-check"
    DEVICE_MOBILE_CODE = "device-mobile-code"
    DEVICE_MOBILE_COG = "device-mobile-cog"
    DEVICE_MOBILE_DOLLAR = "device-mobile-dollar"
    DEVICE_MOBILE_DOWN = "device-mobile-down"
    DEVICE_MOBILE_EXCLAMATION = "device-mobile-exclamation"
    DEVICE_MOBILE_FILLED = "device-mobile-filled"
    DEVICE_MOBILE_HEART = "device-mobile-heart"
    DEVICE_MOBILE_MESSAGE = "device-mobile-message"
    DEVICE_MOBILE_MINUS = "device-mobile-minus"
    DEVICE_MOBILE_OFF = "device-mobile-off"
    DEVICE_MOBILE_PAUSE = "device-mobile-pause"
    DEVICE_MOBILE_PIN = "device-mobile-pin"
    DEVICE_MOBILE_PLUS = "device-mobile-plus"
    DEVICE_MOBILE_QUESTION = "device-mobile-question"
    DEVICE_MOBILE_ROTATED = "device-mobile-rotated"
    DEVICE_MOBILE_SEARCH = "device-mobile-search"
    DEVICE_MOBILE_SHARE = "device-mobile-share"
    DEVICE_MOBILE_STAR = "device-mobile-star"
    DEVICE_MOBILE_UP = "device-mobile-up"
    DEVICE_MOBILE_VIBRATION = "device-mobile-vibration"
    DEVICE_MOBILE_X = "device-mobile-x"
    DEVICE_NINTENDO = "device-nintendo"
    DEVICE_NINTENDO_OFF = "device-nintendo-off"
    DEVICE_REMOTE = "device-remote"
    DEVICE_SD_CARD = "device-sd-card"
    DEVICE_SIM = "device-sim"
    DEVICE_SIM_1 = "device-sim-1"
    DEVICE_SIM_2 = "device-sim-2"
    DEVICE_SIM_3 = "device-sim-3"
    DEVICE_SPEAKER = "device-speaker"
    DEVICE_SPEAKER_OFF = "device-speaker-off"
    DEVICE_TABLET = "device-tablet"
    DEVICE_TABLET_BOLT = "device-tablet-bolt"
    DEVICE_TABLET_CANCEL = "device-tablet-cancel"
    DEVICE_TABLET_CHECK = "device-tablet-check"
    DEVICE_TABLET_CODE = "device-tablet-code"
    DEVICE_TABLET_COG = "device-tablet-cog"
    DEVICE_TABLET_DOLLAR = "device-tablet-dollar"
    DEVICE_TABLET_DOWN = "device-tablet-down"
    DEVICE_TABLET_EXCLAMATION = "device-tablet-exclamation"
    DEVICE_TABLET_FILLED = "device-tablet-filled"
    DEVICE_TABLET_HEART = "device-tablet-heart"
    DEVICE_TABLET_MINUS = "device-tablet-minus"
    DEVICE_TABLET_OFF = "device-tablet-off"
    DEVICE_TABLET_PAUSE = "device-tablet-pause"
    DEVICE_TABLET_PIN = "device-tablet-pin"
    DEVICE_TABLET_PLUS = "device-tablet-plus"
    DEVICE_TABLET_QUESTION = "device-tablet-question"
    DEVICE_TABLET_SEARCH = "device-tablet-search"
    DEVICE_TABLET_SHARE = "device-tablet-share"
    DEVICE_TABLET_STAR = "device-tablet-star"
    DEVICE_TABLET_UP = "device-tablet-up"
    DEVICE_TABLET_X = "device-tablet-x"
    DEVICE_TV = "device-tv"
    DEVICE_TV_OFF = "device-tv-off"
    DEVICE_TV_OLD = "device-tv-old"
    DEVICE_VISION_PRO = "device-vision-pro"
    DEVICE_WATCH = "device-watch"
    DEVICE_WATCH_BOLT = "device-watch-bolt"
    DEVICE_WATCH_CANCEL = "device-watch-cancel"
    DEVICE_WATCH_CHECK = "device-watch-check"
    DEVICE_WATCH_CODE = "device-watch-code"
    DEVICE_WATCH_COG = "device-watch-cog"
    DEVICE_WATCH_DOLLAR = "device-watch-dollar"
    DEVICE_WATCH_DOWN = "device-watch-down"
    DEVICE_WATCH_EXCLAMATION = "device-watch-exclamation"
    DEVICE_WATCH_HEART = "device-watch-heart"
    DEVICE_WATCH_MINUS = "device-watch-minus"
    DEVICE_WATCH_OFF = "device-watch-off"
    DEVICE_WATCH_PAUSE = "device-watch-pause"
    DEVICE_WATCH_PIN = "device-watch-pin"
    DEVICE_WATCH_PLUS = "device-watch-plus"
    DEVICE_WATCH_QUESTION = "device-watch-question"
    DEVICE_WATCH_SEARCH = "device-watch-search"
    DEVICE_WATCH_SHARE = "device-watch-share"
    DEVICE_WATCH_STAR = "device-watch-star"
    DEVICE_WATCH_STATS = "device-watch-stats"
    DEVICE_WATCH_STATS_2 = "device-watch-stats-2"
    DEVICE_WATCH_UP = "device-watch-up"
    DEVICE_WATCH_X = "device-watch-x"
    DEVICES = "devices"
    DEVICES_2 = "devices-2"
    DEVICES_BOLT = "devices-bolt"
    DEVICES_CANCEL = "devices-cancel"
    DEVICES_CHECK = "devices-check"
    DEVICES_CODE = "devices-code"
    DEVICES_COG = "devices-cog"
    DEVICES_DOLLAR = "devices-dollar"
    DEVICES_DOWN = "devices-down"
    DEVICES_EXCLAMATION = "devices-exclamation"
    DEVICES_HEART = "devices-heart"
    DEVICES_MINUS = "devices-minus"
    DEVICES_OFF = "devices-off"
    DEVICES_PAUSE = "devices-pause"
    DEVICES_PC = "devices-pc"
    DEVICES_PC_OFF = "devices-pc-off"
    DEVICES_PIN = "devices-pin"
    DEVICES_PLUS = "devices-plus"
    DEVICES_QUESTION = "devices-question"
    DEVICES_SEARCH = "devices-search"
    DEVICES_SHARE = "devices-share"
    DEVICES_STAR = "devices-star"
    DEVICES_UP = "devices-up"
    DEVICES_X = "devices-x"
    DIABOLO = "diabolo"
    DIABOLO_OFF = "diabolo-off"
    DIABOLO_PLUS = "diabolo-plus"
    DIALPAD = "dialpad"
    DIALPAD_FILLED = "dialpad-filled"
    DIALPAD_OFF = "dialpad-off"
    DIAMOND = "diamond"
    DIAMOND_FILLED = "diamond-filled"
    DIAMOND_OFF = "diamond-off"
    DIAMONDS = "diamonds"
    DIAMONDS_FILLED = "diamonds-filled"
    DICE = "dice"
    DICE_1 = "dice-1"
    DICE_1_FILLED = "dice-1-filled"
    DICE_2 = "dice-2"
    DICE_2_FILLED = "dice-2-filled"
    DICE_3 = "dice-3"
    DICE_3_FILLED = "dice-3-filled"
    DICE_4 = "dice-4"
    DICE_4_FILLED = "dice-4-filled"
    DICE_5 = "dice-5"
    DICE_5_FILLED = "dice-5-filled"
    DICE_6 = "dice-6"
    DICE_6_FILLED = "dice-6-filled"
    DICE_FILLED = "dice-filled"
    DIMENSIONS = "dimensions"
    DIRECTION = "direction"
    DIRECTION_HORIZONTAL = "direction-horizontal"
    DIRECTION_SIGN = "direction-sign"
    DIRECTION_SIGN_FILLED = "direction-sign-filled"
    DIRECTION_SIGN_OFF = "direction-sign-off"
    DIRECTIONS = "directions"
    DIRECTIONS_OFF = "directions-off"
    DISABLED = "disabled"
    DISABLED_2 = "disabled-2"
    DISABLED_OFF = "disabled-off"
    DISC = "disc"
    DISC_GOLF = "disc-golf"
    DISC_OFF = "disc-off"
    DISCOUNT = "discount"
    DISCOUNT_2 = "discount-2"
    DISCOUNT_2_OFF = "discount-2-off"
    DISCOUNT_CHECK = "discount-check"
    DISCOUNT_CHECK_FILLED = "discount-check-filled"
    DISCOUNT_OFF = "discount-off"
    DIVIDE = "divide"
    DNA = "dna"
    DNA_2 = "dna-2"
    DNA_2_OFF = "dna-2-off"
    DNA_OFF = "dna-off"
    DOG = "dog"
    DOG_BOWL = "dog-bowl"
    DOOR = "door"
    DOOR_ENTER = "door-enter"
    DOOR_EXIT = "door-exit"
    DOOR_OFF = "door-off"
    DOTS = "dots"
    DOTS_CIRCLE_HORIZONTAL = "dots-circle-horizontal"
    DOTS_DIAGONAL = "dots-diagonal"
    DOTS_DIAGONAL_2 = "dots-diagonal-2"
    DOTS_VERTICAL = "dots-vertical"
    DOWNLOAD = "download"
    DOWNLOAD_OFF = "download-off"
    DRAG_DROP = "drag-drop"
    DRAG_DROP_2 = "drag-drop-2"
    DRONE = "drone"
    DRONE_OFF = "drone-off"
    DROP_CIRCLE = "drop-circle"
    DROPLET = "droplet"
    DROPLET_BOLT = "droplet-bolt"
    DROPLET_CANCEL = "droplet-cancel"
    DROPLET_CHECK = "droplet-check"
    DROPLET_CODE = "droplet-code"
    DROPLET_COG = "droplet-cog"
    DROPLET_DOLLAR = "droplet-dollar"
    DROPLET_DOWN = "droplet-down"
    DROPLET_EXCLAMATION = "droplet-exclamation"
    DROPLET_FILLED = "droplet-filled"
    DROPLET_FILLED_2 = "droplet-filled-2"
    DROPLET_HALF = "droplet-half"
    DROPLET_HALF_2 = "droplet-half-2"
    DROPLET_HALF_FILLED = "droplet-half-filled"
    DROPLET_HEART = "droplet-heart"
    DROPLET_MINUS = "droplet-minus"
    DROPLET_OFF = "droplet-off"
    DROPLET_PAUSE = "droplet-pause"
    DROPLET_PIN = "droplet-pin"
    DROPLET_PLUS = "droplet-plus"
    DROPLET_QUESTION = "droplet-question"
    DROPLET_SEARCH = "droplet-search"
    DROPLET_SHARE = "droplet-share"
    DROPLET_STAR = "droplet-star"
    DROPLET_UP = "droplet-up"
    DROPLET_X = "droplet-x"
    DUAL_SCREEN = "dual-screen"
    E_PASSPORT = "e-passport"
    EAR = "ear"
    EAR_OFF = "ear-off"
    EASE_IN = "ease-in"
    EASE_IN_CONTROL_POINT = "ease-in-control-point"
    EASE_IN_OUT = "ease-in-out"
    EASE_IN_OUT_CONTROL_POINTS = "ease-in-out-control-points"
    EASE_OUT = "ease-out"
    EASE_OUT_CONTROL_POINT = "ease-out-control-point"
    EDIT = "edit"
    EDIT_CIRCLE = "edit-circle"
    EDIT_CIRCLE_OFF = "edit-circle-off"
    EDIT_OFF = "edit-off"
    EGG = "egg"
    EGG_CRACKED = "egg-cracked"
    EGG_FILLED = "egg-filled"
    EGG_FRIED = "egg-fried"
    EGG_OFF = "egg-off"
    EGGS = "eggs"
    ELEVATOR = "elevator"
    ELEVATOR_OFF = "elevator-off"
    EMERGENCY_BED = "emergency-bed"
    EMPATHIZE = "empathize"
    EMPATHIZE_OFF = "empathize-off"
    EMPHASIS = "emphasis"
    ENGINE = "engine"
    ENGINE_OFF = "engine-off"
    EQUAL = "equal"
    EQUAL_DOUBLE = "equal-double"
    EQUAL_NOT = "equal-not"
    ERASER = "eraser"
    ERASER_OFF = "eraser-off"
    ERROR_404 = "error-404"
    ERROR_404_OFF = "error-404-off"
    EXCHANGE = "exchange"
    EXCHANGE_OFF = "exchange-off"
    EXCLAMATION_CIRCLE = "exclamation-circle"
    EXCLAMATION_MARK = "exclamation-mark"
    EXCLAMATION_MARK_OFF = "exclamation-mark-off"
    EXPLICIT = "explicit"
    EXPLICIT_OFF = "explicit-off"
    EXPOSURE = "exposure"
    EXPOSURE_0 = "exposure-0"
    EXPOSURE_MINUS_1 = "exposure-minus-1"
    EXPOSURE_MINUS_2 = "exposure-minus-2"
    EXPOSURE_OFF = "exposure-off"
    EXPOSURE_PLUS_1 = "exposure-plus-1"
    EXPOSURE_PLUS_2 = "exposure-plus-2"
    EXTERNAL_LINK = "external-link"
    EXTERNAL_LINK_OFF = "external-link-off"
    EYE = "eye"
    EYE_CHECK = "eye-check"
    EYE_CLOSED = "eye-closed"
    EYE_COG = "eye-cog"
    EYE_EDIT = "eye-edit"
    EYE_EXCLAMATION = "eye-exclamation"
    EYE_FILLED = "eye-filled"
    EYE_HEART = "eye-heart"
    EYE_OFF = "eye-off"
    EYE_TABLE = "eye-table"
    EYE_X = "eye-x"
    EYEGLASS = "eyeglass"
    EYEGLASS_2 = "eyeglass-2"
    EYEGLASS_OFF = "eyeglass-off"
    FACE_ID = "face-id"
    FACE_ID_ERROR = "face-id-error"
    FACE_MASK = "face-mask"
    FACE_MASK_OFF = "face-mask-off"
    FALL = "fall"
    FEATHER = "feather"
    FEATHER_OFF = "feather-off"
    FENCE = "fence"
    FENCE_OFF = "fence-off"
    FIDGET_SPINNER = "fidget-spinner"
    FILE = "file"
    FILE_3D = "file-3d"
    FILE_ALERT = "file-alert"
    FILE_ANALYTICS = "file-analytics"
    FILE_ARROW_LEFT = "file-arrow-left"
    FILE_ARROW_RIGHT = "file-arrow-right"
    FILE_BARCODE = "file-barcode"
    FILE_BROKEN = "file-broken"
    FILE_CERTIFICATE = "file-certificate"
    FILE_CHART = "file-chart"
    FILE_CHECK = "file-check"
    FILE_CODE = "file-code"
    FILE_CODE_2 = "file-code-2"
    FILE_CV = "file-cv"
    FILE_DATABASE = "file-database"
    FILE_DELTA = "file-delta"
    FILE_DESCRIPTION = "file-description"
    FILE_DIFF = "file-diff"
    FILE_DIGIT = "file-digit"
    FILE_DISLIKE = "file-dislike"
    FILE_DOLLAR = "file-dollar"
    FILE_DOTS = "file-dots"
    FILE_DOWNLOAD = "file-download"
    FILE_EURO = "file-euro"
    FILE_EXPORT = "file-export"
    FILE_FILLED = "file-filled"
    FILE_FUNCTION = "file-function"
    FILE_HORIZONTAL = "file-horizontal"
    FILE_IMPORT = "file-import"
    FILE_INFINITY = "file-infinity"
    FILE_INFO = "file-info"
    FILE_INVOICE = "file-invoice"
    FILE_LAMBDA = "file-lambda"
    FILE_LIKE = "file-like"
    FILE_MINUS = "file-minus"
    FILE_MUSIC = "file-music"
    FILE_OFF = "file-off"
    FILE_ORIENTATION = "file-orientation"
    FILE_PENCIL = "file-pencil"
    FILE_PERCENT = "file-percent"
    FILE_PHONE = "file-phone"
    FILE_PLUS = "file-plus"
    FILE_POWER = "file-power"
    FILE_REPORT = "file-report"
    FILE_RSS = "file-rss"
    FILE_SCISSORS = "file-scissors"
    FILE_SEARCH = "file-search"
    FILE_SETTINGS = "file-settings"
    FILE_SHREDDER = "file-shredder"
    FILE_SIGNAL = "file-signal"
    FILE_SPREADSHEET = "file-spreadsheet"
    FILE_STACK = "file-stack"
    FILE_STAR = "file-star"
    FILE_SYMLINK = "file-symlink"
    FILE_TEXT = "file-text"
    FILE_TEXT_AI = "file-text-ai"
    FILE_TIME = "file-time"
    FILE_TYPOGRAPHY = "file-typography"
    FILE_UNKNOWN = "file-unknown"
    FILE_UPLOAD = "file-upload"
    FILE_VECTOR = "file-vector"
    FILE_X = "file-x"
    FILE_X_FILLED = "file-x-filled"
    FILE_ZIP = "file-zip"
    FILES = "files"
    FILES_OFF = "files-off"
    FILTER = "filter"
    FILTER_COG = "filter-cog"
    FILTER_DOLLAR = "filter-dollar"
    FILTER_EDIT = "filter-edit"
    FILTER_MINUS = "filter-minus"
    FILTER_OFF = "filter-off"
    FILTER_PLUS = "filter-plus"
    FILTER_STAR = "filter-star"
    FILTER_X = "filter-x"
    FILTERS = "filters"
    FINGERPRINT = "fingerprint"
    FINGERPRINT_OFF = "fingerprint-off"
    FIRE_EXTINGUISHER = "fire-extinguisher"
    FIRE_HYDRANT = "fire-hydrant"
    FIRE_HYDRANT_OFF = "fire-hydrant-off"
    FIRETRUCK = "firetruck"
    FIRST_AID_KIT = "first-aid-kit"
    FIRST_AID_KIT_OFF = "first-aid-kit-off"
    FISH = "fish"
    FISH_BONE = "fish-bone"
    FISH_CHRISTIANITY = "fish-christianity"
    FISH_HOOK = "fish-hook"
    FISH_HOOK_OFF = "fish-hook-off"
    FISH_OFF = "fish-off"
    FLAG = "flag"
    FLAG_2 = "flag-2"
    FLAG_2_FILLED = "flag-2-filled"
    FLAG_2_OFF = "flag-2-off"
    FLAG_3 = "flag-3"
    FLAG_3_FILLED = "flag-3-filled"
    FLAG_FILLED = "flag-filled"
    FLAG_OFF = "flag-off"
    FLAME = "flame"
    FLAME_OFF = "flame-off"
    FLARE = "flare"
    FLASK = "flask"
    FLASK_2 = "flask-2"
    FLASK_2_OFF = "flask-2-off"
    FLASK_OFF = "flask-off"
    FLIP_FLOPS = "flip-flops"
    FLIP_HORIZONTAL = "flip-horizontal"
    FLIP_VERTICAL = "flip-vertical"
    FLOAT_CENTER = "float-center"
    FLOAT_LEFT = "float-left"
    FLOAT_NONE = "float-none"
    FLOAT_RIGHT = "float-right"
    FLOWER = "flower"
    FLOWER_OFF = "flower-off"
    FOCUS = "focus"
    FOCUS_2 = "focus-2"
    FOCUS_AUTO = "focus-auto"
    FOCUS_CENTERED = "focus-centered"
    FOLD = "fold"
    FOLD_DOWN = "fold-down"
    FOLD_UP = "fold-up"
    FOLDER = "folder"
    FOLDER_BOLT = "folder-bolt"
    FOLDER_CANCEL = "folder-cancel"
    FOLDER_CHECK = "folder-check"
    FOLDER_CODE = "folder-code"
    FOLDER_COG = "folder-cog"
    FOLDER_DOLLAR = "folder-dollar"
    FOLDER_DOWN = "folder-down"
    FOLDER_EXCLAMATION = "folder-exclamation"
    FOLDER_FILLED = "folder-filled"
    FOLDER_HEART = "folder-heart"
    FOLDER_MINUS = "folder-minus"
    FOLDER_OFF = "folder-off"
    FOLDER_OPEN = "folder-open"
    FOLDER_PAUSE = "folder-pause"
    FOLDER_PIN = "folder-pin"
    FOLDER_PLUS = "folder-plus"
    FOLDER_QUESTION = "folder-question"
    FOLDER_SEARCH = "folder-search"
    FOLDER_SHARE = "folder-share"
    FOLDER_STAR = "folder-star"
    FOLDER_SYMLINK = "folder-symlink"
    FOLDER_UP = "folder-up"
    FOLDER_X = "folder-x"
    FOLDERS = "folders"
    FOLDERS_OFF = "folders-off"
    FORBID = "forbid"
    FORBID_2 = "forbid-2"
    FORKLIFT = "forklift"
    FORMS = "forms"
    FOUNTAIN = "fountain"
    FOUNTAIN_OFF = "fountain-off"
    FRAME = "frame"
    FRAME_OFF = "frame-off"
    FREE_RIGHTS = "free-rights"
    FREEZE_COLUMN = "freeze-column"
    FREEZE_ROW = "freeze-row"
    FREEZE_ROW_COLUMN = "freeze-row-column"
    FRIDGE = "fridge"
    FRIDGE_OFF = "fridge-off"
    FRIENDS = "friends"
    FRIENDS_OFF = "friends-off"
    FRUSTUM = "frustum"
    FRUSTUM_OFF = "frustum-off"
    FRUSTUM_PLUS = "frustum-plus"
    FUNCTION = "function"
    FUNCTION_OFF = "function-off"
    GARDEN_CART = "garden-cart"
    GARDEN_CART_OFF = "garden-cart-off"
    GAS_STATION = "gas-station"
    GAS_STATION_OFF = "gas-station-off"
    GAUGE = "gauge"
    GAUGE_OFF = "gauge-off"
    GAVEL = "gavel"
    GENDER_AGENDER = "gender-agender"
    GENDER_ANDROGYNE = "gender-androgyne"
    GENDER_BIGENDER = "gender-bigender"
    GENDER_DEMIBOY = "gender-demiboy"
    GENDER_DEMIGIRL = "gender-demigirl"
    GENDER_EPICENE = "gender-epicene"
    GENDER_FEMALE = "gender-female"
    GENDER_FEMME = "gender-femme"
    GENDER_GENDERFLUID = "gender-genderfluid"
    GENDER_GENDERLESS = "gender-genderless"
    GENDER_GENDERQUEER = "gender-genderqueer"
    GENDER_HERMAPHRODITE = "gender-hermaphrodite"
    GENDER_INTERGENDER = "gender-intergender"
    GENDER_MALE = "gender-male"
    GENDER_NEUTROIS = "gender-neutrois"
    GENDER_THIRD = "gender-third"
    GENDER_TRANSGENDER = "gender-transgender"
    GENDER_TRASVESTI = "gender-trasvesti"
    GEOMETRY = "geometry"
    GHOST = "ghost"
    GHOST_2 = "ghost-2"
    GHOST_2_FILLED = "ghost-2-filled"
    GHOST_FILLED = "ghost-filled"
    GHOST_OFF = "ghost-off"
    GIF = "gif"
    GIFT = "gift"
    GIFT_CARD = "gift-card"
    GIFT_OFF = "gift-off"
    GIT_BRANCH = "git-branch"
    GIT_BRANCH_DELETED = "git-branch-deleted"
    GIT_CHERRY_PICK = "git-cherry-pick"
    GIT_COMMIT = "git-commit"
    GIT_COMPARE = "git-compare"
    GIT_FORK = "git-fork"
    GIT_MERGE = "git-merge"
    GIT_PULL_REQUEST = "git-pull-request"
    GIT_PULL_REQUEST_CLOSED = "git-pull-request-closed"
    GIT_PULL_REQUEST_DRAFT = "git-pull-request-draft"
    GIZMO = "gizmo"
    GLASS = "glass"
    GLASS_FULL = "glass-full"
    GLASS_OFF = "glass-off"
    GLOBE = "globe"
    GLOBE_OFF = "globe-off"
    GO_GAME = "go-game"
    GOLF = "golf"
    GOLF_OFF = "golf-off"
    GPS = "gps"
    GRADIENTER = "gradienter"
    GRAIN = "grain"
    GRAPH = "graph"
    GRAPH_OFF = "graph-off"
    GRAVE = "grave"
    GRAVE_2 = "grave-2"
    GRID_DOTS = "grid-dots"
    GRID_PATTERN = "grid-pattern"
    GRILL = "grill"
    GRILL_FORK = "grill-fork"
    GRILL_OFF = "grill-off"
    GRILL_SPATULA = "grill-spatula"
    GRIP_HORIZONTAL = "grip-horizontal"
    GRIP_VERTICAL = "grip-vertical"
    GROWTH = "growth"
    GUITAR_PICK = "guitar-pick"
    GUITAR_PICK_FILLED = "guitar-pick-filled"
    H_1 = "h-1"
    H_2 = "h-2"
    H_3 = "h-3"
    H_4 = "h-4"
    H_5 = "h-5"
    H_6 = "h-6"
    HAMMER = "hammer"
    HAMMER_OFF = "hammer-off"
    HAND_CLICK = "hand-click"
    HAND_FINGER = "hand-finger"
    HAND_FINGER_OFF = "hand-finger-off"
    HAND_GRAB = "hand-grab"
    HAND_LITTLE_FINGER = "hand-little-finger"
    HAND_MIDDLE_FINGER = "hand-middle-finger"
    HAND_MOVE = "hand-move"
    HAND_OFF = "hand-off"
    HAND_RING_FINGER = "hand-ring-finger"
    HAND_ROCK = "hand-rock"
    HAND_SANITIZER = "hand-sanitizer"
    HAND_STOP = "hand-stop"
    HAND_THREE_FINGERS = "hand-three-fingers"
    HAND_TWO_FINGERS = "hand-two-fingers"
    HANGER = "hanger"
    HANGER_2 = "hanger-2"
    HANGER_OFF = "hanger-off"
    HASH = "hash"
    HAZE = "haze"
    HAZE_MOON = "haze-moon"
    HDR = "hdr"
    HEADING = "heading"
    HEADING_OFF = "heading-off"
    HEADPHONES = "headphones"
    HEADPHONES_FILLED = "headphones-filled"
    HEADPHONES_OFF = "headphones-off"
    HEADSET = "headset"
    HEADSET_OFF = "headset-off"
    HEALTH_RECOGNITION = "health-recognition"
    HEART = "heart"
    HEART_BROKEN = "heart-broken"
    HEART_FILLED = "heart-filled"
    HEART_HANDSHAKE = "heart-handshake"
    HEART_MINUS = "heart-minus"
    HEART_OFF = "heart-off"
    HEART_PLUS = "heart-plus"
    HEART_RATE_MONITOR = "heart-rate-monitor"
    HEARTBEAT = "heartbeat"
    HEARTS = "hearts"
    HEARTS_OFF = "hearts-off"
    HELICOPTER = "helicopter"
    HELICOPTER_LANDING = "helicopter-landing"
    HELMET = "helmet"
    HELMET_OFF = "helmet-off"
    HELP = "help"
    HELP_CIRCLE = "help-circle"
    HELP_CIRCLE_FILLED = "help-circle-filled"
    HELP_HEXAGON = "help-hexagon"
    HELP_HEXAGON_FILLED = "help-hexagon-filled"
    HELP_OCTAGON = "help-octagon"
    HELP_OCTAGON_FILLED = "help-octagon-filled"
    HELP_OFF = "help-off"
    HELP_SMALL = "help-small"
    HELP_SQUARE = "help-square"
    HELP_SQUARE_FILLED = "help-square-filled"
    HELP_SQUARE_ROUNDED = "help-square-rounded"
    HELP_SQUARE_ROUNDED_FILLED = "help-square-rounded-filled"
    HELP_TRIANGLE = "help-triangle"
    HELP_TRIANGLE_FILLED = "help-triangle-filled"
    HEMISPHERE = "hemisphere"
    HEMISPHERE_OFF = "hemisphere-off"
    HEMISPHERE_PLUS = "hemisphere-plus"
    HEXAGON = "hexagon"
    HEXAGON_0_FILLED = "hexagon-0-filled"
    HEXAGON_1_FILLED = "hexagon-1-filled"
    HEXAGON_2_FILLED = "hexagon-2-filled"
    HEXAGON_3_FILLED = "hexagon-3-filled"
    HEXAGON_3D = "hexagon-3d"
    HEXAGON_4_FILLED = "hexagon-4-filled"
    HEXAGON_5_FILLED = "hexagon-5-filled"
    HEXAGON_6_FILLED = "hexagon-6-filled"
    HEXAGON_7_FILLED = "hexagon-7-filled"
    HEXAGON_8_FILLED = "hexagon-8-filled"
    HEXAGON_9_FILLED = "hexagon-9-filled"
    HEXAGON_FILLED = "hexagon-filled"
    HEXAGON_LETTER_A = "hexagon-letter-a"
    HEXAGON_LETTER_B = "hexagon-letter-b"
    HEXAGON_LETTER_C = "hexagon-letter-c"
    HEXAGON_LETTER_D = "hexagon-letter-d"
    HEXAGON_LETTER_E = "hexagon-letter-e"
    HEXAGON_LETTER_F = "hexagon-letter-f"
    HEXAGON_LETTER_G = "hexagon-letter-g"
    HEXAGON_LETTER_H = "hexagon-letter-h"
    HEXAGON_LETTER_I = "hexagon-letter-i"
    HEXAGON_LETTER_J = "hexagon-letter-j"
    HEXAGON_LETTER_K = "hexagon-letter-k"
    HEXAGON_LETTER_L = "hexagon-letter-l"
    HEXAGON_LETTER_M = "hexagon-letter-m"
    HEXAGON_LETTER_N = "hexagon-letter-n"
    HEXAGON_LETTER_O = "hexagon-letter-o"
    HEXAGON_LETTER_P = "hexagon-letter-p"
    HEXAGON_LETTER_Q = "hexagon-letter-q"
    HEXAGON_LETTER_R = "hexagon-letter-r"
    HEXAGON_LETTER_S = "hexagon-letter-s"
    HEXAGON_LETTER_T = "hexagon-letter-t"
    HEXAGON_LETTER_U = "hexagon-letter-u"
    HEXAGON_LETTER_V = "hexagon-letter-v"
    HEXAGON_LETTER_W = "hexagon-letter-w"
    HEXAGON_LETTER_X = "hexagon-letter-x"
    HEXAGON_LETTER_Y = "hexagon-letter-y"
    HEXAGON_LETTER_Z = "hexagon-letter-z"
    HEXAGON_NUMBER_0 = "hexagon-number-0"
    HEXAGON_NUMBER_1 = "hexagon-number-1"
    HEXAGON_NUMBER_2 = "hexagon-number-2"
    HEXAGON_NUMBER_3 = "hexagon-number-3"
    HEXAGON_NUMBER_4 = "hexagon-number-4"
    HEXAGON_NUMBER_5 = "hexagon-number-5"
    HEXAGON_NUMBER_6 = "hexagon-number-6"
    HEXAGON_NUMBER_7 = "hexagon-number-7"
    HEXAGON_NUMBER_8 = "hexagon-number-8"
    HEXAGON_NUMBER_9 = "hexagon-number-9"
    HEXAGON_OFF = "hexagon-off"
    HEXAGONAL_PRISM = "hexagonal-prism"
    HEXAGONAL_PRISM_OFF = "hexagonal-prism-off"
    HEXAGONAL_PRISM_PLUS = "hexagonal-prism-plus"
    HEXAGONAL_PYRAMID = "hexagonal-pyramid"
    HEXAGONAL_PYRAMID_OFF = "hexagonal-pyramid-off"
    HEXAGONAL_PYRAMID_PLUS = "hexagonal-pyramid-plus"
    HEXAGONS = "hexagons"
    HEXAGONS_OFF = "hexagons-off"
    HIERARCHY = "hierarchy"
    HIERARCHY_2 = "hierarchy-2"
    HIERARCHY_3 = "hierarchy-3"
    HIERARCHY_OFF = "hierarchy-off"
    HIGHLIGHT = "highlight"
    HIGHLIGHT_OFF = "highlight-off"
    HISTORY = "history"
    HISTORY_OFF = "history-off"
    HISTORY_TOGGLE = "history-toggle"
    HOME = "home"
    HOME_2 = "home-2"
    HOME_BOLT = "home-bolt"
    HOME_CANCEL = "home-cancel"
    HOME_CHECK = "home-check"
    HOME_COG = "home-cog"
    HOME_DOLLAR = "home-dollar"
    HOME_DOT = "home-dot"
    HOME_DOWN = "home-down"
    HOME_ECO = "home-eco"
    HOME_EDIT = "home-edit"
    HOME_EXCLAMATION = "home-exclamation"
    HOME_HAND = "home-hand"
    HOME_HEART = "home-heart"
    HOME_INFINITY = "home-infinity"
    HOME_LINK = "home-link"
    HOME_MINUS = "home-minus"
    HOME_MOVE = "home-move"
    HOME_OFF = "home-off"
    HOME_PLUS = "home-plus"
    HOME_QUESTION = "home-question"
    HOME_RIBBON = "home-ribbon"
    HOME_SEARCH = "home-search"
    HOME_SHARE = "home-share"
    HOME_SHIELD = "home-shield"
    HOME_SIGNAL = "home-signal"
    HOME_STAR = "home-star"
    HOME_STATS = "home-stats"
    HOME_UP = "home-up"
    HOME_X = "home-x"
    HORSE_TOY = "horse-toy"
    HOTEL_SERVICE = "hotel-service"
    HOURGLASS = "hourglass"
    HOURGLASS_EMPTY = "hourglass-empty"
    HOURGLASS_FILLED = "hourglass-filled"
    HOURGLASS_HIGH = "hourglass-high"
    HOURGLASS_LOW = "hourglass-low"
    HOURGLASS_OFF = "hourglass-off"
    HTML = "html"
    HTTP_CONNECT = "http-connect"
    HTTP_DELETE = "http-delete"
    HTTP_GET = "http-get"
    HTTP_HEAD = "http-head"
    HTTP_OPTIONS = "http-options"
    HTTP_PATCH = "http-patch"
    HTTP_POST = "http-post"
    HTTP_PUT = "http-put"
    HTTP_QUE = "http-que"
    HTTP_TRACE = "http-trace"
    ICE_CREAM = "ice-cream"
    ICE_CREAM_2 = "ice-cream-2"
    ICE_CREAM_OFF = "ice-cream-off"
    ICE_SKATING = "ice-skating"
    ICONS = "icons"
    ICONS_OFF = "icons-off"
    ID = "id"
    ID_BADGE = "id-badge"
    ID_BADGE_2 = "id-badge-2"
    ID_BADGE_OFF = "id-badge-off"
    ID_OFF = "id-off"
    INBOX = "inbox"
    INBOX_OFF = "inbox-off"
    INDENT_DECREASE = "indent-decrease"
    INDENT_INCREASE = "indent-increase"
    INFINITY = "infinity"
    INFINITY_OFF = "infinity-off"
    INFO_CIRCLE = "info-circle"
    INFO_CIRCLE_FILLED = "info-circle-filled"
    INFO_HEXAGON = "info-hexagon"
    INFO_HEXAGON_FILLED = "info-hexagon-filled"
    INFO_OCTAGON = "info-octagon"
    INFO_OCTAGON_FILLED = "info-octagon-filled"
    INFO_SMALL = "info-small"
    INFO_SQUARE = "info-square"
    INFO_SQUARE_FILLED = "info-square-filled"
    INFO_SQUARE_ROUNDED = "info-square-rounded"
    INFO_SQUARE_ROUNDED_FILLED = "info-square-rounded-filled"
    INFO_TRIANGLE = "info-triangle"
    INFO_TRIANGLE_FILLED = "info-triangle-filled"
    INNER_SHADOW_BOTTOM = "inner-shadow-bottom"
    INNER_SHADOW_BOTTOM_FILLED = "inner-shadow-bottom-filled"
    INNER_SHADOW_BOTTOM_LEFT = "inner-shadow-bottom-left"
    INNER_SHADOW_BOTTOM_LEFT_FILLED = "inner-shadow-bottom-left-filled"
    INNER_SHADOW_BOTTOM_RIGHT = "inner-shadow-bottom-right"
    INNER_SHADOW_BOTTOM_RIGHT_FILLED = "inner-shadow-bottom-right-filled"
    INNER_SHADOW_LEFT = "inner-shadow-left"
    INNER_SHADOW_LEFT_FILLED = "inner-shadow-left-filled"
    INNER_SHADOW_RIGHT = "inner-shadow-right"
    INNER_SHADOW_RIGHT_FILLED = "inner-shadow-right-filled"
    INNER_SHADOW_TOP = "inner-shadow-top"
    INNER_SHADOW_TOP_FILLED = "inner-shadow-top-filled"
    INNER_SHADOW_TOP_LEFT = "inner-shadow-top-left"
    INNER_SHADOW_TOP_LEFT_FILLED = "inner-shadow-top-left-filled"
    INNER_SHADOW_TOP_RIGHT = "inner-shadow-top-right"
    INNER_SHADOW_TOP_RIGHT_FILLED = "inner-shadow-top-right-filled"
    INPUT_SEARCH = "input-search"
    IRONING = "ironing"
    IRONING_1 = "ironing-1"
    IRONING_2 = "ironing-2"
    IRONING_3 = "ironing-3"
    IRONING_OFF = "ironing-off"
    IRONING_STEAM = "ironing-steam"
    IRONING_STEAM_OFF = "ironing-steam-off"
    IRREGULAR_POLYHEDRON = "irregular-polyhedron"
    IRREGULAR_POLYHEDRON_OFF = "irregular-polyhedron-off"
    IRREGULAR_POLYHEDRON_PLUS = "irregular-polyhedron-plus"
    ITALIC = "italic"
    JACKET = "jacket"
    JETPACK = "jetpack"
    JEWISH_STAR = "jewish-star"
    JEWISH_STAR_FILLED = "jewish-star-filled"
    JPG = "jpg"
    JSON = "json"
    JUMP_ROPE = "jump-rope"
    KARATE = "karate"
    KAYAK = "kayak"
    KERING = "kering"
    KEY = "key"
    KEY_OFF = "key-off"
    KEYBOARD = "keyboard"
    KEYBOARD_HIDE = "keyboard-hide"
    KEYBOARD_OFF = "keyboard-off"
    KEYBOARD_SHOW = "keyboard-show"
    KEYFRAME = "keyframe"
    KEYFRAME_ALIGN_CENTER = "keyframe-align-center"
    KEYFRAME_ALIGN_HORIZONTAL = "keyframe-align-horizontal"
    KEYFRAME_ALIGN_VERTICAL = "keyframe-align-vertical"
    KEYFRAMES = "keyframes"
    LADDER = "ladder"
    LADDER_OFF = "ladder-off"
    LAMBDA = "lambda"
    LAMP = "lamp"
    LAMP_2 = "lamp-2"
    LAMP_OFF = "lamp-off"
    LANE = "lane"
    LANGUAGE = "language"
    LANGUAGE_HIRAGANA = "language-hiragana"
    LANGUAGE_KATAKANA = "language-katakana"
    LANGUAGE_OFF = "language-off"
    LASSO = "lasso"
    LASSO_OFF = "lasso-off"
    LASSO_POLYGON = "lasso-polygon"
    LAYERS_DIFFERENCE = "layers-difference"
    LAYERS_INTERSECT = "layers-intersect"
    LAYERS_INTERSECT_2 = "layers-intersect-2"
    LAYERS_LINKED = "layers-linked"
    LAYERS_OFF = "layers-off"
    LAYERS_SUBTRACT = "layers-subtract"
    LAYERS_UNION = "layers-union"
    LAYOUT = "layout"
    LAYOUT_2 = "layout-2"
    LAYOUT_ALIGN_BOTTOM = "layout-align-bottom"
    LAYOUT_ALIGN_CENTER = "layout-align-center"
    LAYOUT_ALIGN_LEFT = "layout-align-left"
    LAYOUT_ALIGN_MIDDLE = "layout-align-middle"
    LAYOUT_ALIGN_RIGHT = "layout-align-right"
    LAYOUT_ALIGN_TOP = "layout-align-top"
    LAYOUT_BOARD = "layout-board"
    LAYOUT_BOARD_SPLIT = "layout-board-split"
    LAYOUT_BOTTOMBAR = "layout-bottombar"
    LAYOUT_BOTTOMBAR_COLLAPSE = "layout-bottombar-collapse"
    LAYOUT_BOTTOMBAR_EXPAND = "layout-bottombar-expand"
    LAYOUT_CARDS = "layout-cards"
    LAYOUT_COLLAGE = "layout-collage"
    LAYOUT_COLUMNS = "layout-columns"
    LAYOUT_DASHBOARD = "layout-dashboard"
    LAYOUT_DISTRIBUTE_HORIZONTAL = "layout-distribute-horizontal"
    LAYOUT_DISTRIBUTE_VERTICAL = "layout-distribute-vertical"
    LAYOUT_GRID = "layout-grid"
    LAYOUT_GRID_ADD = "layout-grid-add"
    LAYOUT_GRID_REMOVE = "layout-grid-remove"
    LAYOUT_KANBAN = "layout-kanban"
    LAYOUT_LIST = "layout-list"
    LAYOUT_NAVBAR = "layout-navbar"
    LAYOUT_NAVBAR_COLLAPSE = "layout-navbar-collapse"
    LAYOUT_NAVBAR_EXPAND = "layout-navbar-expand"
    LAYOUT_OFF = "layout-off"
    LAYOUT_ROWS = "layout-rows"
    LAYOUT_SIDEBAR = "layout-sidebar"
    LAYOUT_SIDEBAR_LEFT_COLLAPSE = "layout-sidebar-left-collapse"
    LAYOUT_SIDEBAR_LEFT_EXPAND = "layout-sidebar-left-expand"
    LAYOUT_SIDEBAR_RIGHT = "layout-sidebar-right"
    LAYOUT_SIDEBAR_RIGHT_COLLAPSE = "layout-sidebar-right-collapse"
    LAYOUT_SIDEBAR_RIGHT_EXPAND = "layout-sidebar-right-expand"
    LEAF = "leaf"
    LEAF_OFF = "leaf-off"
    LEGO = "lego"
    LEGO_OFF = "lego-off"
    LEMON = "lemon"
    LEMON_2 = "lemon-2"
    LETTER_A = "letter-a"
    LETTER_B = "letter-b"
    LETTER_C = "letter-c"
    LETTER_CASE = "letter-case"
    LETTER_CASE_LOWER = "letter-case-lower"
    LETTER_CASE_TOGGLE = "letter-case-toggle"
    LETTER_CASE_UPPER = "letter-case-upper"
    LETTER_D = "letter-d"
    LETTER_E = "letter-e"
    LETTER_F = "letter-f"
    LETTER_G = "letter-g"
    LETTER_H = "letter-h"
    LETTER_I = "letter-i"
    LETTER_J = "letter-j"
    LETTER_K = "letter-k"
    LETTER_L = "letter-l"
    LETTER_M = "letter-m"
    LETTER_N = "letter-n"
    LETTER_O = "letter-o"
    LETTER_P = "letter-p"
    LETTER_Q = "letter-q"
    LETTER_R = "letter-r"
    LETTER_S = "letter-s"
    LETTER_SPACING = "letter-spacing"
    LETTER_T = "letter-t"
    LETTER_U = "letter-u"
    LETTER_V = "letter-v"
    LETTER_W = "letter-w"
    LETTER_X = "letter-x"
    LETTER_Y = "letter-y"
    LETTER_Z = "letter-z"
    LICENSE = "license"
    LICENSE_OFF = "license-off"
    LIFEBUOY = "lifebuoy"
    LIFEBUOY_OFF = "lifebuoy-off"
    LIGHTER = "lighter"
    LINE = "line"
    LINE_DASHED = "line-dashed"
    LINE_DOTTED = "line-dotted"
    LINE_HEIGHT = "line-height"
    LINK = "link"
    LINK_OFF = "link-off"
    LIST = "list"
    LIST_CHECK = "list-check"
    LIST_DETAILS = "list-details"
    LIST_NUMBERS = "list-numbers"
    LIST_SEARCH = "list-search"
    LIST_TREE = "list-tree"
    LIVE_PHOTO = "live-photo"
    LIVE_PHOTO_OFF = "live-photo-off"
    LIVE_VIEW = "live-view"
    LOAD_BALANCER = "load-balancer"
    LOADER = "loader"
    LOADER_2 = "loader-2"
    LOADER_3 = "loader-3"
    LOADER_QUARTER = "loader-quarter"
    LOCATION = "location"
    LOCATION_BROKEN = "location-broken"
    LOCATION_FILLED = "location-filled"
    LOCATION_OFF = "location-off"
    LOCK = "lock"
    LOCK_ACCESS = "lock-access"
    LOCK_ACCESS_OFF = "lock-access-off"
    LOCK_BOLT = "lock-bolt"
    LOCK_CANCEL = "lock-cancel"
    LOCK_CHECK = "lock-check"
    LOCK_CODE = "lock-code"
    LOCK_COG = "lock-cog"
    LOCK_DOLLAR = "lock-dollar"
    LOCK_DOWN = "lock-down"
    LOCK_EXCLAMATION = "lock-exclamation"
    LOCK_HEART = "lock-heart"
    LOCK_MINUS = "lock-minus"
    LOCK_OFF = "lock-off"
    LOCK_OPEN = "lock-open"
    LOCK_OPEN_OFF = "lock-open-off"
    LOCK_PAUSE = "lock-pause"
    LOCK_PIN = "lock-pin"
    LOCK_PLUS = "lock-plus"
    LOCK_QUESTION = "lock-question"
    LOCK_SEARCH = "lock-search"
    LOCK_SHARE = "lock-share"
    LOCK_SQUARE = "lock-square"
    LOCK_SQUARE_ROUNDED = "lock-square-rounded"
    LOCK_SQUARE_ROUNDED_FILLED = "lock-square-rounded-filled"
    LOCK_STAR = "lock-star"
    LOCK_UP = "lock-up"
    LOCK_X = "lock-x"
    LOGIC_AND = "logic-and"
    LOGIC_BUFFER = "logic-buffer"
    LOGIC_NAND = "logic-nand"
    LOGIC_NOR = "logic-nor"
    LOGIC_NOT = "logic-not"
    LOGIC_OR = "logic-or"
    LOGIC_XNOR = "logic-xnor"
    LOGIC_XOR = "logic-xor"
    LOGIN = "login"
    LOGOUT = "logout"
    LOGOUT_2 = "logout-2"
    LOLLIPOP = "lollipop"
    LOLLIPOP_OFF = "lollipop-off"
    LUGGAGE = "luggage"
    LUGGAGE_OFF = "luggage-off"
    LUNGS = "lungs"
    LUNGS_OFF = "lungs-off"
    MACRO = "macro"
    MACRO_OFF = "macro-off"
    MAGNET = "magnet"
    MAGNET_OFF = "magnet-off"
    MAIL = "mail"
    MAIL_AI = "mail-ai"
    MAIL_BOLT = "mail-bolt"
    MAIL_CANCEL = "mail-cancel"
    MAIL_CHECK = "mail-check"
    MAIL_CODE = "mail-code"
    MAIL_COG = "mail-cog"
    MAIL_DOLLAR = "mail-dollar"
    MAIL_DOWN = "mail-down"
    MAIL_EXCLAMATION = "mail-exclamation"
    MAIL_FAST = "mail-fast"
    MAIL_FILLED = "mail-filled"
    MAIL_FORWARD = "mail-forward"
    MAIL_HEART = "mail-heart"
    MAIL_MINUS = "mail-minus"
    MAIL_OFF = "mail-off"
    MAIL_OPENED = "mail-opened"
    MAIL_OPENED_FILLED = "mail-opened-filled"
    MAIL_PAUSE = "mail-pause"
    MAIL_PIN = "mail-pin"
    MAIL_PLUS = "mail-plus"
    MAIL_QUESTION = "mail-question"
    MAIL_SEARCH = "mail-search"
    MAIL_SHARE = "mail-share"
    MAIL_STAR = "mail-star"
    MAIL_UP = "mail-up"
    MAIL_X = "mail-x"
    MAILBOX = "mailbox"
    MAILBOX_OFF = "mailbox-off"
    MAN = "man"
    MANUAL_GEARBOX = "manual-gearbox"
    MAP = "map"
    MAP_2 = "map-2"
    MAP_OFF = "map-off"
    MAP_PIN = "map-pin"
    MAP_PIN_BOLT = "map-pin-bolt"
    MAP_PIN_CANCEL = "map-pin-cancel"
    MAP_PIN_CHECK = "map-pin-check"
    MAP_PIN_CODE = "map-pin-code"
    MAP_PIN_COG = "map-pin-cog"
    MAP_PIN_DOLLAR = "map-pin-dollar"
    MAP_PIN_DOWN = "map-pin-down"
    MAP_PIN_EXCLAMATION = "map-pin-exclamation"
    MAP_PIN_FILLED = "map-pin-filled"
    MAP_PIN_HEART = "map-pin-heart"
    MAP_PIN_MINUS = "map-pin-minus"
    MAP_PIN_OFF = "map-pin-off"
    MAP_PIN_PAUSE = "map-pin-pause"
    MAP_PIN_PIN = "map-pin-pin"
    MAP_PIN_PLUS = "map-pin-plus"
    MAP_PIN_QUESTION = "map-pin-question"
    MAP_PIN_SEARCH = "map-pin-search"
    MAP_PIN_SHARE = "map-pin-share"
    MAP_PIN_STAR = "map-pin-star"
    MAP_PIN_UP = "map-pin-up"
    MAP_PIN_X = "map-pin-x"
    MAP_PINS = "map-pins"
    MAP_SEARCH = "map-search"
    MARKDOWN = "markdown"
    MARKDOWN_OFF = "markdown-off"
    MARQUEE = "marquee"
    MARQUEE_2 = "marquee-2"
    MARQUEE_OFF = "marquee-off"
    MARS = "mars"
    MASK = "mask"
    MASK_OFF = "mask-off"
    MASKS_THEATER = "masks-theater"
    MASKS_THEATER_OFF = "masks-theater-off"
    MASSAGE = "massage"
    MATCHSTICK = "matchstick"
    MATH = "math"
    MATH_1_DIVIDE_2 = "math-1-divide-2"
    MATH_1_DIVIDE_3 = "math-1-divide-3"
    MATH_AVG = "math-avg"
    MATH_EQUAL_GREATER = "math-equal-greater"
    MATH_EQUAL_LOWER = "math-equal-lower"
    MATH_FUNCTION = "math-function"
    MATH_FUNCTION_OFF = "math-function-off"
    MATH_FUNCTION_Y = "math-function-y"
    MATH_GREATER = "math-greater"
    MATH_INTEGRAL = "math-integral"
    MATH_INTEGRAL_X = "math-integral-x"
    MATH_INTEGRALS = "math-integrals"
    MATH_LOWER = "math-lower"
    MATH_MAX = "math-max"
    MATH_MIN = "math-min"
    MATH_NOT = "math-not"
    MATH_OFF = "math-off"
    MATH_PI = "math-pi"
    MATH_PI_DIVIDE_2 = "math-pi-divide-2"
    MATH_SYMBOLS = "math-symbols"
    MATH_X_DIVIDE_2 = "math-x-divide-2"
    MATH_X_DIVIDE_Y = "math-x-divide-y"
    MATH_X_DIVIDE_Y_2 = "math-x-divide-y-2"
    MATH_X_MINUS_X = "math-x-minus-x"
    MATH_X_MINUS_Y = "math-x-minus-y"
    MATH_X_PLUS_X = "math-x-plus-x"
    MATH_X_PLUS_Y = "math-x-plus-y"
    MATH_XY = "math-xy"
    MATH_Y_MINUS_Y = "math-y-minus-y"
    MATH_Y_PLUS_Y = "math-y-plus-y"
    MAXIMIZE = "maximize"
    MAXIMIZE_OFF = "maximize-off"
    MEAT = "meat"
    MEAT_OFF = "meat-off"
    MEDAL = "medal"
    MEDAL_2 = "medal-2"
    MEDICAL_CROSS = "medical-cross"
    MEDICAL_CROSS_CIRCLE = "medical-cross-circle"
    MEDICAL_CROSS_FILLED = "medical-cross-filled"
    MEDICAL_CROSS_OFF = "medical-cross-off"
    MEDICINE_SYRUP = "medicine-syrup"
    MEEPLE = "meeple"
    MENORAH = "menorah"
    MENU = "menu"
    MENU_2 = "menu-2"
    MENU_DEEP = "menu-deep"
    MENU_ORDER = "menu-order"
    MESSAGE = "message"
    MESSAGE_2 = "message-2"
    MESSAGE_2_BOLT = "message-2-bolt"
    MESSAGE_2_CANCEL = "message-2-cancel"
    MESSAGE_2_CHECK = "message-2-check"
    MESSAGE_2_CODE = "message-2-code"
    MESSAGE_2_COG = "message-2-cog"
    MESSAGE_2_DOLLAR = "message-2-dollar"
    MESSAGE_2_DOWN = "message-2-down"
    MESSAGE_2_EXCLAMATION = "message-2-exclamation"
    MESSAGE_2_HEART = "message-2-heart"
    MESSAGE_2_MINUS = "message-2-minus"
    MESSAGE_2_OFF = "message-2-off"
    MESSAGE_2_PAUSE = "message-2-pause"
    MESSAGE_2_PIN = "message-2-pin"
    MESSAGE_2_PLUS = "message-2-plus"
    MESSAGE_2_QUESTION = "message-2-question"
    MESSAGE_2_SEARCH = "message-2-search"
    MESSAGE_2_SHARE = "message-2-share"
    MESSAGE_2_STAR = "message-2-star"
    MESSAGE_2_UP = "message-2-up"
    MESSAGE_2_X = "message-2-x"
    MESSAGE_BOLT = "message-bolt"
    MESSAGE_CANCEL = "message-cancel"
    MESSAGE_CHATBOT = "message-chatbot"
    MESSAGE_CHECK = "message-check"
    MESSAGE_CIRCLE = "message-circle"
    MESSAGE_CIRCLE_2 = "message-circle-2"
    MESSAGE_CIRCLE_2_FILLED = "message-circle-2-filled"
    MESSAGE_CIRCLE_BOLT = "message-circle-bolt"
    MESSAGE_CIRCLE_CANCEL = "message-circle-cancel"
    MESSAGE_CIRCLE_CHECK = "message-circle-check"
    MESSAGE_CIRCLE_CODE = "message-circle-code"
    MESSAGE_CIRCLE_COG = "message-circle-cog"
    MESSAGE_CIRCLE_DOLLAR = "message-circle-dollar"
    MESSAGE_CIRCLE_DOWN = "message-circle-down"
    MESSAGE_CIRCLE_EXCLAMATION = "message-circle-exclamation"
    MESSAGE_CIRCLE_HEART = "message-circle-heart"
    MESSAGE_CIRCLE_MINUS = "message-circle-minus"
    MESSAGE_CIRCLE_OFF = "message-circle-off"
    MESSAGE_CIRCLE_PAUSE = "message-circle-pause"
    MESSAGE_CIRCLE_PIN = "message-circle-pin"
    MESSAGE_CIRCLE_PLUS = "message-circle-plus"
    MESSAGE_CIRCLE_QUESTION = "message-circle-question"
    MESSAGE_CIRCLE_SEARCH = "message-circle-search"
    MESSAGE_CIRCLE_SHARE = "message-circle-share"
    MESSAGE_CIRCLE_STAR = "message-circle-star"
    MESSAGE_CIRCLE_UP = "message-circle-up"
    MESSAGE_CIRCLE_X = "message-circle-x"
    MESSAGE_CODE = "message-code"
    MESSAGE_COG = "message-cog"
    MESSAGE_DOLLAR = "message-dollar"
    MESSAGE_DOTS = "message-dots"
    MESSAGE_DOWN = "message-down"
    MESSAGE_EXCLAMATION = "message-exclamation"
    MESSAGE_FORWARD = "message-forward"
    MESSAGE_HEART = "message-heart"
    MESSAGE_LANGUAGE = "message-language"
    MESSAGE_MINUS = "message-minus"
    MESSAGE_OFF = "message-off"
    MESSAGE_PAUSE = "message-pause"
    MESSAGE_PIN = "message-pin"
    MESSAGE_PLUS = "message-plus"
    MESSAGE_QUESTION = "message-question"
    MESSAGE_REPORT = "message-report"
    MESSAGE_SEARCH = "message-search"
    MESSAGE_SHARE = "message-share"
    MESSAGE_STAR = "message-star"
    MESSAGE_UP = "message-up"
    MESSAGE_X = "message-x"
    MESSAGES = "messages"
    MESSAGES_OFF = "messages-off"
    METEOR = "meteor"
    METEOR_OFF = "meteor-off"
    MICHELIN_BIB_GOURMAND = "michelin-bib-gourmand"
    MICHELIN_STAR = "michelin-star"
    MICHELIN_STAR_GREEN = "michelin-star-green"
    MICKEY = "mickey"
    MICKEY_FILLED = "mickey-filled"
    MICROPHONE = "microphone"
    MICROPHONE_2 = "microphone-2"
    MICROPHONE_2_OFF = "microphone-2-off"
    MICROPHONE_OFF = "microphone-off"
    MICROSCOPE = "microscope"
    MICROSCOPE_OFF = "microscope-off"
    MICROWAVE = "microwave"
    MICROWAVE_OFF = "microwave-off"
    MILITARY_AWARD = "military-award"
    MILITARY_RANK = "military-rank"
    MILK = "milk"
    MILK_OFF = "milk-off"
    MILKSHAKE = "milkshake"
    MINIMIZE = "minimize"
    MINUS = "minus"
    MINUS_VERTICAL = "minus-vertical"
    MIST = "mist"
    MIST_OFF = "mist-off"
    MOBILEDATA = "mobiledata"
    MOBILEDATA_OFF = "mobiledata-off"
    MONEYBAG = "moneybag"
    MOOD_ANGRY = "mood-angry"
    MOOD_ANNOYED = "mood-annoyed"
    MOOD_ANNOYED_2 = "mood-annoyed-2"
    MOOD_BOY = "mood-boy"
    MOOD_CHECK = "mood-check"
    MOOD_COG = "mood-cog"
    MOOD_CONFUZED = "mood-confuzed"
    MOOD_CONFUZED_FILLED = "mood-confuzed-filled"
    MOOD_CRAZY_HAPPY = "mood-crazy-happy"
    MOOD_CRY = "mood-cry"
    MOOD_DOLLAR = "mood-dollar"
    MOOD_EDIT = "mood-edit"
    MOOD_EMPTY = "mood-empty"
    MOOD_EMPTY_FILLED = "mood-empty-filled"
    MOOD_HAPPY = "mood-happy"
    MOOD_HAPPY_FILLED = "mood-happy-filled"
    MOOD_HEART = "mood-heart"
    MOOD_KID = "mood-kid"
    MOOD_KID_FILLED = "mood-kid-filled"
    MOOD_LOOK_LEFT = "mood-look-left"
    MOOD_LOOK_RIGHT = "mood-look-right"
    MOOD_MINUS = "mood-minus"
    MOOD_NERD = "mood-nerd"
    MOOD_NERVOUS = "mood-nervous"
    MOOD_NEUTRAL = "mood-neutral"
    MOOD_NEUTRAL_FILLED = "mood-neutral-filled"
    MOOD_OFF = "mood-off"
    MOOD_PIN = "mood-pin"
    MOOD_PLUS = "mood-plus"
    MOOD_SAD = "mood-sad"
    MOOD_SAD_2 = "mood-sad-2"
    MOOD_SAD_DIZZY = "mood-sad-dizzy"
    MOOD_SAD_FILLED = "mood-sad-filled"
    MOOD_SAD_SQUINT = "mood-sad-squint"
    MOOD_SEARCH = "mood-search"
    MOOD_SHARE = "mood-share"
    MOOD_SICK = "mood-sick"
    MOOD_SILENCE = "mood-silence"
    MOOD_SING = "mood-sing"
    MOOD_SMILE = "mood-smile"
    MOOD_SMILE_BEAM = "mood-smile-beam"
    MOOD_SMILE_DIZZY = "mood-smile-dizzy"
    MOOD_SMILE_FILLED = "mood-smile-filled"
    MOOD_SUPRISED = "mood-suprised"
    MOOD_TONGUE = "mood-tongue"
    MOOD_TONGUE_WINK = "mood-tongue-wink"
    MOOD_TONGUE_WINK_2 = "mood-tongue-wink-2"
    MOOD_UNAMUSED = "mood-unamused"
    MOOD_UP = "mood-up"
    MOOD_WINK = "mood-wink"
    MOOD_WINK_2 = "mood-wink-2"
    MOOD_WRRR = "mood-wrrr"
    MOOD_X = "mood-x"
    MOOD_XD = "mood-xd"
    MOON = "moon"
    MOON_2 = "moon-2"
    MOON_FILLED = "moon-filled"
    MOON_OFF = "moon-off"
    MOON_STARS = "moon-stars"
    MOPED = "moped"
    MOTORBIKE = "motorbike"
    MOUNTAIN = "mountain"
    MOUNTAIN_OFF = "mountain-off"
    MOUSE = "mouse"
    MOUSE_2 = "mouse-2"
    MOUSE_OFF = "mouse-off"
    MOUSTACHE = "moustache"
    MOVIE = "movie"
    MOVIE_OFF = "movie-off"
    MUG = "mug"
    MUG_OFF = "mug-off"
    MULTIPLIER_0_5X = "multiplier-0-5x"
    MULTIPLIER_1_5X = "multiplier-1-5x"
    MULTIPLIER_1X = "multiplier-1x"
    MULTIPLIER_2X = "multiplier-2x"
    MUSHROOM = "mushroom"
    MUSHROOM_FILLED = "mushroom-filled"
    MUSHROOM_OFF = "mushroom-off"
    MUSIC = "music"
    MUSIC_OFF = "music-off"
    NAVIGATION = "navigation"
    NAVIGATION_FILLED = "navigation-filled"
    NAVIGATION_NORTH = "navigation-north"
    NAVIGATION_OFF = "navigation-off"
    NEEDLE = "needle"
    NEEDLE_THREAD = "needle-thread"
    NETWORK = "network"
    NETWORK_OFF = "network-off"
    NEW_SECTION = "new-section"
    NEWS = "news"
    NEWS_OFF = "news-off"
    NFC = "nfc"
    NFC_OFF = "nfc-off"
    NO_COPYRIGHT = "no-copyright"
    NO_CREATIVE_COMMONS = "no-creative-commons"
    NO_DERIVATIVES = "no-derivatives"
    NORTH_STAR = "north-star"
    NOTE = "note"
    NOTE_OFF = "note-off"
    NOTEBOOK = "notebook"
    NOTEBOOK_OFF = "notebook-off"
    NOTES = "notes"
    NOTES_OFF = "notes-off"
    NOTIFICATION = "notification"
    NOTIFICATION_OFF = "notification-off"
    NUMBER = "number"
    NUMBER_0 = "number-0"
    NUMBER_1 = "number-1"
    NUMBER_2 = "number-2"
    NUMBER_3 = "number-3"
    NUMBER_4 = "number-4"
    NUMBER_5 = "number-5"
    NUMBER_6 = "number-6"
    NUMBER_7 = "number-7"
    NUMBER_8 = "number-8"
    NUMBER_9 = "number-9"
    NUMBERS = "numbers"
    NURSE = "nurse"
    OCTAGON = "octagon"
    OCTAGON_FILLED = "octagon-filled"
    OCTAGON_OFF = "octagon-off"
    OCTAHEDRON = "octahedron"
    OCTAHEDRON_OFF = "octahedron-off"
    OCTAHEDRON_PLUS = "octahedron-plus"
    OLD = "old"
    OLYMPICS = "olympics"
    OLYMPICS_OFF = "olympics-off"
    OM = "om"
    OMEGA = "omega"
    OUTBOUND = "outbound"
    OUTLET = "outlet"
    OVAL = "oval"
    OVAL_FILLED = "oval-filled"
    OVAL_VERTICAL = "oval-vertical"
    OVAL_VERTICAL_FILLED = "oval-vertical-filled"
    OVERLINE = "overline"
    PACKAGE = "package"
    PACKAGE_EXPORT = "package-export"
    PACKAGE_IMPORT = "package-import"
    PACKAGE_OFF = "package-off"
    PACKAGES = "packages"
    PACMAN = "pacman"
    PAGE_BREAK = "page-break"
    PAINT = "paint"
    PAINT_FILLED = "paint-filled"
    PAINT_OFF = "paint-off"
    PALETTE = "palette"
    PALETTE_OFF = "palette-off"
    PANORAMA_HORIZONTAL = "panorama-horizontal"
    PANORAMA_HORIZONTAL_OFF = "panorama-horizontal-off"
    PANORAMA_VERTICAL = "panorama-vertical"
    PANORAMA_VERTICAL_OFF = "panorama-vertical-off"
    PAPER_BAG = "paper-bag"
    PAPER_BAG_OFF = "paper-bag-off"
    PAPERCLIP = "paperclip"
    PARACHUTE = "parachute"
    PARACHUTE_OFF = "parachute-off"
    PARENTHESES = "parentheses"
    PARENTHESES_OFF = "parentheses-off"
    PARKING = "parking"
    PARKING_OFF = "parking-off"
    PASSWORD = "password"
    PAW = "paw"
    PAW_FILLED = "paw-filled"
    PAW_OFF = "paw-off"
    PDF = "pdf"
    PEACE = "peace"
    PENCIL = "pencil"
    PENCIL_MINUS = "pencil-minus"
    PENCIL_OFF = "pencil-off"
    PENCIL_PLUS = "pencil-plus"
    PENNANT = "pennant"
    PENNANT_2 = "pennant-2"
    PENNANT_2_FILLED = "pennant-2-filled"
    PENNANT_FILLED = "pennant-filled"
    PENNANT_OFF = "pennant-off"
    PENTAGON = "pentagon"
    PENTAGON_FILLED = "pentagon-filled"
    PENTAGON_OFF = "pentagon-off"
    PENTAGRAM = "pentagram"
    PEPPER = "pepper"
    PEPPER_OFF = "pepper-off"
    PERCENTAGE = "percentage"
    PERFUME = "perfume"
    PERSPECTIVE = "perspective"
    PERSPECTIVE_OFF = "perspective-off"
    PHONE = "phone"
    PHONE_CALL = "phone-call"
    PHONE_CALLING = "phone-calling"
    PHONE_CHECK = "phone-check"
    PHONE_FILLED = "phone-filled"
    PHONE_INCOMING = "phone-incoming"
    PHONE_OFF = "phone-off"
    PHONE_OUTGOING = "phone-outgoing"
    PHONE_PAUSE = "phone-pause"
    PHONE_PLUS = "phone-plus"
    PHONE_X = "phone-x"
    PHOTO = "photo"
    PHOTO_AI = "photo-ai"
    PHOTO_BOLT = "photo-bolt"
    PHOTO_CANCEL = "photo-cancel"
    PHOTO_CHECK = "photo-check"
    PHOTO_CODE = "photo-code"
    PHOTO_COG = "photo-cog"
    PHOTO_DOLLAR = "photo-dollar"
    PHOTO_DOWN = "photo-down"
    PHOTO_EDIT = "photo-edit"
    PHOTO_EXCLAMATION = "photo-exclamation"
    PHOTO_FILLED = "photo-filled"
    PHOTO_HEART = "photo-heart"
    PHOTO_MINUS = "photo-minus"
    PHOTO_OFF = "photo-off"
    PHOTO_PAUSE = "photo-pause"
    PHOTO_PIN = "photo-pin"
    PHOTO_PLUS = "photo-plus"
    PHOTO_QUESTION = "photo-question"
    PHOTO_SEARCH = "photo-search"
    PHOTO_SENSOR = "photo-sensor"
    PHOTO_SENSOR_2 = "photo-sensor-2"
    PHOTO_SENSOR_3 = "photo-sensor-3"
    PHOTO_SHARE = "photo-share"
    PHOTO_SHIELD = "photo-shield"
    PHOTO_STAR = "photo-star"
    PHOTO_UP = "photo-up"
    PHOTO_X = "photo-x"
    PHYSOTHERAPIST = "physotherapist"
    PIANO = "piano"
    PICK = "pick"
    PICTURE_IN_PICTURE = "picture-in-picture"
    PICTURE_IN_PICTURE_OFF = "picture-in-picture-off"
    PICTURE_IN_PICTURE_ON = "picture-in-picture-on"
    PICTURE_IN_PICTURE_TOP = "picture-in-picture-top"
    PIG = "pig"
    PIG_MONEY = "pig-money"
    PIG_OFF = "pig-off"
    PILCROW = "pilcrow"
    PILL = "pill"
    PILL_OFF = "pill-off"
    PILLS = "pills"
    PIN = "pin"
    PIN_FILLED = "pin-filled"
    PING_PONG = "ping-pong"
    PINNED = "pinned"
    PINNED_FILLED = "pinned-filled"
    PINNED_OFF = "pinned-off"
    PIZZA = "pizza"
    PIZZA_OFF = "pizza-off"
    PLACEHOLDER = "placeholder"
    PLANE = "plane"
    PLANE_ARRIVAL = "plane-arrival"
    PLANE_DEPARTURE = "plane-departure"
    PLANE_INFLIGHT = "plane-inflight"
    PLANE_OFF = "plane-off"
    PLANE_TILT = "plane-tilt"
    PLANET = "planet"
    PLANET_OFF = "planet-off"
    PLANT = "plant"
    PLANT_2 = "plant-2"
    PLANT_2_OFF = "plant-2-off"
    PLANT_OFF = "plant-off"
    PLAY_BASKETBALL = "play-basketball"
    PLAY_CARD = "play-card"
    PLAY_CARD_OFF = "play-card-off"
    PLAY_FOOTBALL = "play-football"
    PLAY_HANDBALL = "play-handball"
    PLAY_VOLLEYBALL = "play-volleyball"
    PLAYER_EJECT = "player-eject"
    PLAYER_EJECT_FILLED = "player-eject-filled"
    PLAYER_PAUSE = "player-pause"
    PLAYER_PAUSE_FILLED = "player-pause-filled"
    PLAYER_PLAY = "player-play"
    PLAYER_PLAY_FILLED = "player-play-filled"
    PLAYER_RECORD = "player-record"
    PLAYER_RECORD_FILLED = "player-record-filled"
    PLAYER_SKIP_BACK = "player-skip-back"
    PLAYER_SKIP_BACK_FILLED = "player-skip-back-filled"
    PLAYER_SKIP_FORWARD = "player-skip-forward"
    PLAYER_SKIP_FORWARD_FILLED = "player-skip-forward-filled"
    PLAYER_STOP = "player-stop"
    PLAYER_STOP_FILLED = "player-stop-filled"
    PLAYER_TRACK_NEXT = "player-track-next"
    PLAYER_TRACK_NEXT_FILLED = "player-track-next-filled"
    PLAYER_TRACK_PREV = "player-track-prev"
    PLAYER_TRACK_PREV_FILLED = "player-track-prev-filled"
    PLAYLIST = "playlist"
    PLAYLIST_ADD = "playlist-add"
    PLAYLIST_OFF = "playlist-off"
    PLAYLIST_X = "playlist-x"
    PLAYSTATION_CIRCLE = "playstation-circle"
    PLAYSTATION_SQUARE = "playstation-square"
    PLAYSTATION_TRIANGLE = "playstation-triangle"
    PLAYSTATION_X = "playstation-x"
    PLUG = "plug"
    PLUG_CONNECTED = "plug-connected"
    PLUG_CONNECTED_X = "plug-connected-x"
    PLUG_OFF = "plug-off"
    PLUG_X = "plug-x"
    PLUS = "plus"
    PLUS_EQUAL = "plus-equal"
    PLUS_MINUS = "plus-minus"
    PNG = "png"
    PODIUM = "podium"
    PODIUM_OFF = "podium-off"
    POINT = "point"
    POINT_FILLED = "point-filled"
    POINT_OFF = "point-off"
    POINTER = "pointer"
    POINTER_BOLT = "pointer-bolt"
    POINTER_CANCEL = "pointer-cancel"
    POINTER_CHECK = "pointer-check"
    POINTER_CODE = "pointer-code"
    POINTER_COG = "pointer-cog"
    POINTER_DOLLAR = "pointer-dollar"
    POINTER_DOWN = "pointer-down"
    POINTER_EXCLAMATION = "pointer-exclamation"
    POINTER_HEART = "pointer-heart"
    POINTER_MINUS = "pointer-minus"
    POINTER_OFF = "pointer-off"
    POINTER_PAUSE = "pointer-pause"
    POINTER_PIN = "pointer-pin"
    POINTER_PLUS = "pointer-plus"
    POINTER_QUESTION = "pointer-question"
    POINTER_SEARCH = "pointer-search"
    POINTER_SHARE = "pointer-share"
    POINTER_STAR = "pointer-star"
    POINTER_UP = "pointer-up"
    POINTER_X = "pointer-x"
    POKEBALL = "pokeball"
    POKEBALL_OFF = "pokeball-off"
    POKER_CHIP = "poker-chip"
    POLAROID = "polaroid"
    POLAROID_FILLED = "polaroid-filled"
    POLYGON = "polygon"
    POLYGON_OFF = "polygon-off"
    POO = "poo"
    POOL = "pool"
    POOL_OFF = "pool-off"
    POWER = "power"
    PRAY = "pray"
    PREMIUM_RIGHTS = "premium-rights"
    PRESCRIPTION = "prescription"
    PRESENTATION = "presentation"
    PRESENTATION_ANALYTICS = "presentation-analytics"
    PRESENTATION_OFF = "presentation-off"
    PRINTER = "printer"
    PRINTER_OFF = "printer-off"
    PRISM = "prism"
    PRISM_OFF = "prism-off"
    PRISM_PLUS = "prism-plus"
    PRISON = "prison"
    PROGRESS = "progress"
    PROGRESS_ALERT = "progress-alert"
    PROGRESS_BOLT = "progress-bolt"
    PROGRESS_CHECK = "progress-check"
    PROGRESS_DOWN = "progress-down"
    PROGRESS_HELP = "progress-help"
    PROGRESS_X = "progress-x"
    PROMPT = "prompt"
    PROPELLER = "propeller"
    PROPELLER_OFF = "propeller-off"
    PUMPKIN_SCARY = "pumpkin-scary"
    PUZZLE = "puzzle"
    PUZZLE_2 = "puzzle-2"
    PUZZLE_FILLED = "puzzle-filled"
    PUZZLE_OFF = "puzzle-off"
    PYRAMID = "pyramid"
    PYRAMID_OFF = "pyramid-off"
    PYRAMID_PLUS = "pyramid-plus"
    QRCODE = "qrcode"
    QRCODE_OFF = "qrcode-off"
    QUESTION_MARK = "question-mark"
    QUOTE = "quote"
    QUOTE_OFF = "quote-off"
    RADAR = "radar"
    RADAR_2 = "radar-2"
    RADAR_OFF = "radar-off"
    RADIO = "radio"
    RADIO_OFF = "radio-off"
    RADIOACTIVE = "radioactive"
    RADIOACTIVE_FILLED = "radioactive-filled"
    RADIOACTIVE_OFF = "radioactive-off"
    RADIUS_BOTTOM_LEFT = "radius-bottom-left"
    RADIUS_BOTTOM_RIGHT = "radius-bottom-right"
    RADIUS_TOP_LEFT = "radius-top-left"
    RADIUS_TOP_RIGHT = "radius-top-right"
    RAINBOW = "rainbow"
    RAINBOW_OFF = "rainbow-off"
    RATING_12_PLUS = "rating-12-plus"
    RATING_14_PLUS = "rating-14-plus"
    RATING_16_PLUS = "rating-16-plus"
    RATING_18_PLUS = "rating-18-plus"
    RATING_21_PLUS = "rating-21-plus"
    RAZOR = "razor"
    RAZOR_ELECTRIC = "razor-electric"
    RECEIPT = "receipt"
    RECEIPT_2 = "receipt-2"
    RECEIPT_OFF = "receipt-off"
    RECEIPT_REFUND = "receipt-refund"
    RECEIPT_TAX = "receipt-tax"
    RECHARGING = "recharging"
    RECORD_MAIL = "record-mail"
    RECORD_MAIL_OFF = "record-mail-off"
    RECTANGLE = "rectangle"
    RECTANGLE_FILLED = "rectangle-filled"
    RECTANGLE_ROUNDED_BOTTOM = "rectangle-rounded-bottom"
    RECTANGLE_ROUNDED_TOP = "rectangle-rounded-top"
    RECTANGLE_VERTICAL = "rectangle-vertical"
    RECTANGLE_VERTICAL_FILLED = "rectangle-vertical-filled"
    RECTANGULAR_PRISM = "rectangular-prism"
    RECTANGULAR_PRISM_OFF = "rectangular-prism-off"
    RECTANGULAR_PRISM_PLUS = "rectangular-prism-plus"
    RECYCLE = "recycle"
    RECYCLE_OFF = "recycle-off"
    REFRESH = "refresh"
    REFRESH_ALERT = "refresh-alert"
    REFRESH_DOT = "refresh-dot"
    REFRESH_OFF = "refresh-off"
    REGEX = "regex"
    REGEX_OFF = "regex-off"
    REGISTERED = "registered"
    RELATION_MANY_TO_MANY = "relation-many-to-many"
    RELATION_ONE_TO_MANY = "relation-one-to-many"
    RELATION_ONE_TO_ONE = "relation-one-to-one"
    RELOAD = "reload"
    REPEAT = "repeat"
    REPEAT_OFF = "repeat-off"
    REPEAT_ONCE = "repeat-once"
    REPLACE = "replace"
    REPLACE_FILLED = "replace-filled"
    REPLACE_OFF = "replace-off"
    REPORT = "report"
    REPORT_ANALYTICS = "report-analytics"
    REPORT_MEDICAL = "report-medical"
    REPORT_MONEY = "report-money"
    REPORT_OFF = "report-off"
    REPORT_SEARCH = "report-search"
    RESERVED_LINE = "reserved-line"
    RESIZE = "resize"
    RESTORE = "restore"
    REWIND_BACKWARD_10 = "rewind-backward-10"
    REWIND_BACKWARD_15 = "rewind-backward-15"
    REWIND_BACKWARD_20 = "rewind-backward-20"
    REWIND_BACKWARD_30 = "rewind-backward-30"
    REWIND_BACKWARD_40 = "rewind-backward-40"
    REWIND_BACKWARD_5 = "rewind-backward-5"
    REWIND_BACKWARD_50 = "rewind-backward-50"
    REWIND_BACKWARD_60 = "rewind-backward-60"
    REWIND_FORWARD_10 = "rewind-forward-10"
    REWIND_FORWARD_15 = "rewind-forward-15"
    REWIND_FORWARD_20 = "rewind-forward-20"
    REWIND_FORWARD_30 = "rewind-forward-30"
    REWIND_FORWARD_40 = "rewind-forward-40"
    REWIND_FORWARD_5 = "rewind-forward-5"
    REWIND_FORWARD_50 = "rewind-forward-50"
    REWIND_FORWARD_60 = "rewind-forward-60"
    RIBBON_HEALTH = "ribbon-health"
    RINGS = "rings"
    RIPPLE = "ripple"
    RIPPLE_OFF = "ripple-off"
    ROAD = "road"
    ROAD_OFF = "road-off"
    ROAD_SIGN = "road-sign"
    ROBOT = "robot"
    ROBOT_OFF = "robot-off"
    ROCKET = "rocket"
    ROCKET_OFF = "rocket-off"
    ROLLER_SKATING = "roller-skating"
    ROLLERCOASTER = "rollercoaster"
    ROLLERCOASTER_OFF = "rollercoaster-off"
    ROSETTE = "rosette"
    ROSETTE_FILLED = "rosette-filled"
    ROSETTE_NUMBER_0 = "rosette-number-0"
    ROSETTE_NUMBER_1 = "rosette-number-1"
    ROSETTE_NUMBER_2 = "rosette-number-2"
    ROSETTE_NUMBER_3 = "rosette-number-3"
    ROSETTE_NUMBER_4 = "rosette-number-4"
    ROSETTE_NUMBER_5 = "rosette-number-5"
    ROSETTE_NUMBER_6 = "rosette-number-6"
    ROSETTE_NUMBER_7 = "rosette-number-7"
    ROSETTE_NUMBER_8 = "rosette-number-8"
    ROSETTE_NUMBER_9 = "rosette-number-9"
    ROTATE = "rotate"
    ROTATE_2 = "rotate-2"
    ROTATE_360 = "rotate-360"
    ROTATE_CLOCKWISE = "rotate-clockwise"
    ROTATE_CLOCKWISE_2 = "rotate-clockwise-2"
    ROTATE_DOT = "rotate-dot"
    ROTATE_RECTANGLE = "rotate-rectangle"
    ROUTE = "route"
    ROUTE_2 = "route-2"
    ROUTE_OFF = "route-off"
    ROUTER = "router"
    ROUTER_OFF = "router-off"
    ROW_INSERT_BOTTOM = "row-insert-bottom"
    ROW_INSERT_TOP = "row-insert-top"
    ROW_REMOVE = "row-remove"
    RSS = "rss"
    RUBBER_STAMP = "rubber-stamp"
    RUBBER_STAMP_OFF = "rubber-stamp-off"
    RULER = "ruler"
    RULER_2 = "ruler-2"
    RULER_2_OFF = "ruler-2-off"
    RULER_3 = "ruler-3"
    RULER_MEASURE = "ruler-measure"
    RULER_OFF = "ruler-off"
    RUN = "run"
    S_TURN_DOWN = "s-turn-down"
    S_TURN_LEFT = "s-turn-left"
    S_TURN_RIGHT = "s-turn-right"
    S_TURN_UP = "s-turn-up"
    SAILBOAT = "sailboat"
    SAILBOAT_2 = "sailboat-2"
    SAILBOAT_OFF = "sailboat-off"
    SALAD = "salad"
    SALT = "salt"
    SATELLITE = "satellite"
    SATELLITE_OFF = "satellite-off"
    SAUSAGE = "sausage"
    SCALE = "scale"
    SCALE_OFF = "scale-off"
    SCALE_OUTLINE = "scale-outline"
    SCALE_OUTLINE_OFF = "scale-outline-off"
    SCAN = "scan"
    SCAN_EYE = "scan-eye"
    SCHEMA = "schema"
    SCHEMA_OFF = "schema-off"
    SCHOOL = "school"
    SCHOOL_BELL = "school-bell"
    SCHOOL_OFF = "school-off"
    SCISSORS = "scissors"
    SCISSORS_OFF = "scissors-off"
    SCOOTER = "scooter"
    SCOOTER_ELECTRIC = "scooter-electric"
    SCOREBOARD = "scoreboard"
    SCREEN_SHARE = "screen-share"
    SCREEN_SHARE_OFF = "screen-share-off"
    SCREENSHOT = "screenshot"
    SCRIBBLE = "scribble"
    SCRIBBLE_OFF = "scribble-off"
    SCRIPT = "script"
    SCRIPT_MINUS = "script-minus"
    SCRIPT_PLUS = "script-plus"
    SCRIPT_X = "script-x"
    SCUBA_MASK = "scuba-mask"
    SCUBA_MASK_OFF = "scuba-mask-off"
    SDK = "sdk"
    SEARCH = "search"
    SEARCH_OFF = "search-off"
    SECTION = "section"
    SECTION_SIGN = "section-sign"
    SEEDING = "seeding"
    SEEDING_OFF = "seeding-off"
    SELECT = "select"
    SELECT_ALL = "select-all"
    SELECTOR = "selector"
    SEND = "send"
    SEND_OFF = "send-off"
    SEO = "seo"
    SEPARATOR = "separator"
    SEPARATOR_HORIZONTAL = "separator-horizontal"
    SEPARATOR_VERTICAL = "separator-vertical"
    SERVER = "server"
    SERVER_2 = "server-2"
    SERVER_BOLT = "server-bolt"
    SERVER_COG = "server-cog"
    SERVER_OFF = "server-off"
    SERVICEMARK = "servicemark"
    SETTINGS = "settings"
    SETTINGS_2 = "settings-2"
    SETTINGS_AUTOMATION = "settings-automation"
    SETTINGS_BOLT = "settings-bolt"
    SETTINGS_CANCEL = "settings-cancel"
    SETTINGS_CHECK = "settings-check"
    SETTINGS_CODE = "settings-code"
    SETTINGS_COG = "settings-cog"
    SETTINGS_DOLLAR = "settings-dollar"
    SETTINGS_DOWN = "settings-down"
    SETTINGS_EXCLAMATION = "settings-exclamation"
    SETTINGS_FILLED = "settings-filled"
    SETTINGS_HEART = "settings-heart"
    SETTINGS_MINUS = "settings-minus"
    SETTINGS_OFF = "settings-off"
    SETTINGS_PAUSE = "settings-pause"
    SETTINGS_PIN = "settings-pin"
    SETTINGS_PLUS = "settings-plus"
    SETTINGS_QUESTION = "settings-question"
    SETTINGS_SEARCH = "settings-search"
    SETTINGS_SHARE = "settings-share"
    SETTINGS_STAR = "settings-star"
    SETTINGS_UP = "settings-up"
    SETTINGS_X = "settings-x"
    SHADOW = "shadow"
    SHADOW_OFF = "shadow-off"
    SHAPE = "shape"
    SHAPE_2 = "shape-2"
    SHAPE_3 = "shape-3"
    SHAPE_OFF = "shape-off"
    SHARE = "share"
    SHARE_2 = "share-2"
    SHARE_3 = "share-3"
    SHARE_OFF = "share-off"
    SHI_JUMPING = "shi-jumping"
    SHIELD = "shield"
    SHIELD_BOLT = "shield-bolt"
    SHIELD_CANCEL = "shield-cancel"
    SHIELD_CHECK = "shield-check"
    SHIELD_CHECK_FILLED = "shield-check-filled"
    SHIELD_CHECKERED = "shield-checkered"
    SHIELD_CHECKERED_FILLED = "shield-checkered-filled"
    SHIELD_CHEVRON = "shield-chevron"
    SHIELD_CODE = "shield-code"
    SHIELD_COG = "shield-cog"
    SHIELD_DOLLAR = "shield-dollar"
    SHIELD_DOWN = "shield-down"
    SHIELD_EXCLAMATION = "shield-exclamation"
    SHIELD_FILLED = "shield-filled"
    SHIELD_HALF = "shield-half"
    SHIELD_HALF_FILLED = "shield-half-filled"
    SHIELD_HEART = "shield-heart"
    SHIELD_LOCK = "shield-lock"
    SHIELD_LOCK_FILLED = "shield-lock-filled"
    SHIELD_MINUS = "shield-minus"
    SHIELD_OFF = "shield-off"
    SHIELD_PAUSE = "shield-pause"
    SHIELD_PIN = "shield-pin"
    SHIELD_PLUS = "shield-plus"
    SHIELD_QUESTION = "shield-question"
    SHIELD_SEARCH = "shield-search"
    SHIELD_SHARE = "shield-share"
    SHIELD_STAR = "shield-star"
    SHIELD_UP = "shield-up"
    SHIELD_X = "shield-x"
    SHIP = "ship"
    SHIP_OFF = "ship-off"
    SHIRT = "shirt"
    SHIRT_FILLED = "shirt-filled"
    SHIRT_OFF = "shirt-off"
    SHIRT_SPORT = "shirt-sport"
    SHOE = "shoe"
    SHOE_OFF = "shoe-off"
    SHOPPING_BAG = "shopping-bag"
    SHOPPING_CART = "shopping-cart"
    SHOPPING_CART_DISCOUNT = "shopping-cart-discount"
    SHOPPING_CART_OFF = "shopping-cart-off"
    SHOPPING_CART_PLUS = "shopping-cart-plus"
    SHOPPING_CART_X = "shopping-cart-x"
    SHOVEL = "shovel"
    SHREDDER = "shredder"
    SIGN_LEFT = "sign-left"
    SIGN_LEFT_FILLED = "sign-left-filled"
    SIGN_RIGHT = "sign-right"
    SIGN_RIGHT_FILLED = "sign-right-filled"
    SIGNAL_2G = "signal-2g"
    SIGNAL_3G = "signal-3g"
    SIGNAL_4G = "signal-4g"
    SIGNAL_4G_PLUS = "signal-4g-plus"
    SIGNAL_5G = "signal-5g"
    SIGNAL_6G = "signal-6g"
    SIGNAL_E = "signal-e"
    SIGNAL_G = "signal-g"
    SIGNAL_H = "signal-h"
    SIGNAL_H_PLUS = "signal-h-plus"
    SIGNAL_LTE = "signal-lte"
    SIGNATURE = "signature"
    SIGNATURE_OFF = "signature-off"
    SITEMAP = "sitemap"
    SITEMAP_OFF = "sitemap-off"
    SKATEBOARD = "skateboard"
    SKATEBOARD_OFF = "skateboard-off"
    SKATEBOARDING = "skateboarding"
    SKULL = "skull"
    SLASH = "slash"
    SLASHES = "slashes"
    SLEIGH = "sleigh"
    SLICE = "slice"
    SLIDESHOW = "slideshow"
    SMART_HOME = "smart-home"
    SMART_HOME_OFF = "smart-home-off"
    SMOKING = "smoking"
    SMOKING_NO = "smoking-no"
    SNOWFLAKE = "snowflake"
    SNOWFLAKE_OFF = "snowflake-off"
    SNOWMAN = "snowman"
    SOCCER_FIELD = "soccer-field"
    SOCIAL = "social"
    SOCIAL_OFF = "social-off"
    SOCK = "sock"
    SOFA = "sofa"
    SOFA_OFF = "sofa-off"
    SOLAR_PANEL = "solar-panel"
    SOLAR_PANEL_2 = "solar-panel-2"
    SORT_0_9 = "sort-0-9"
    SORT_9_0 = "sort-9-0"
    SORT_A_Z = "sort-a-z"
    SORT_ASCENDING = "sort-ascending"
    SORT_ASCENDING_2 = "sort-ascending-2"
    SORT_ASCENDING_LETTERS = "sort-ascending-letters"
    SORT_ASCENDING_NUMBERS = "sort-ascending-numbers"
    SORT_DESCENDING = "sort-descending"
    SORT_DESCENDING_2 = "sort-descending-2"
    SORT_DESCENDING_LETTERS = "sort-descending-letters"
    SORT_DESCENDING_NUMBERS = "sort-descending-numbers"
    SORT_Z_A = "sort-z-a"
    SOS = "sos"
    SOUP = "soup"
    SOUP_OFF = "soup-off"
    SOURCE_CODE = "source-code"
    SPACE = "space"
    SPACE_OFF = "space-off"
    SPACING_HORIZONTAL = "spacing-horizontal"
    SPACING_VERTICAL = "spacing-vertical"
    SPADE = "spade"
    SPADE_FILLED = "spade-filled"
    SPARKLES = "sparkles"
    SPEAKERPHONE = "speakerphone"
    SPEEDBOAT = "speedboat"
    SPHERE = "sphere"
    SPHERE_OFF = "sphere-off"
    SPHERE_PLUS = "sphere-plus"
    SPIDER = "spider"
    SPIRAL = "spiral"
    SPIRAL_OFF = "spiral-off"
    SPORT_BILLARD = "sport-billard"
    SPRAY = "spray"
    SPY = "spy"
    SPY_OFF = "spy-off"
    SQL = "sql"
    SQUARE = "square"
    SQUARE_0_FILLED = "square-0-filled"
    SQUARE_1_FILLED = "square-1-filled"
    SQUARE_2_FILLED = "square-2-filled"
    SQUARE_3_FILLED = "square-3-filled"
    SQUARE_4_FILLED = "square-4-filled"
    SQUARE_5_FILLED = "square-5-filled"
    SQUARE_6_FILLED = "square-6-filled"
    SQUARE_7_FILLED = "square-7-filled"
    SQUARE_8_FILLED = "square-8-filled"
    SQUARE_9_FILLED = "square-9-filled"
    SQUARE_ARROW_DOWN = "square-arrow-down"
    SQUARE_ARROW_LEFT = "square-arrow-left"
    SQUARE_ARROW_RIGHT = "square-arrow-right"
    SQUARE_ARROW_UP = "square-arrow-up"
    SQUARE_ASTERISK = "square-asterisk"
    SQUARE_CHECK = "square-check"
    SQUARE_CHECK_FILLED = "square-check-filled"
    SQUARE_CHEVRON_DOWN = "square-chevron-down"
    SQUARE_CHEVRON_LEFT = "square-chevron-left"
    SQUARE_CHEVRON_RIGHT = "square-chevron-right"
    SQUARE_CHEVRON_UP = "square-chevron-up"
    SQUARE_CHEVRONS_DOWN = "square-chevrons-down"
    SQUARE_CHEVRONS_LEFT = "square-chevrons-left"
    SQUARE_CHEVRONS_RIGHT = "square-chevrons-right"
    SQUARE_CHEVRONS_UP = "square-chevrons-up"
    SQUARE_DOT = "square-dot"
    SQUARE_F0 = "square-f0"
    SQUARE_F0_FILLED = "square-f0-filled"
    SQUARE_F1 = "square-f1"
    SQUARE_F1_FILLED = "square-f1-filled"
    SQUARE_F2 = "square-f2"
    SQUARE_F2_FILLED = "square-f2-filled"
    SQUARE_F3 = "square-f3"
    SQUARE_F3_FILLED = "square-f3-filled"
    SQUARE_F4 = "square-f4"
    SQUARE_F4_FILLED = "square-f4-filled"
    SQUARE_F5 = "square-f5"
    SQUARE_F5_FILLED = "square-f5-filled"
    SQUARE_F6 = "square-f6"
    SQUARE_F6_FILLED = "square-f6-filled"
    SQUARE_F7 = "square-f7"
    SQUARE_F7_FILLED = "square-f7-filled"
    SQUARE_F8 = "square-f8"
    SQUARE_F8_FILLED = "square-f8-filled"
    SQUARE_F9 = "square-f9"
    SQUARE_F9_FILLED = "square-f9-filled"
    SQUARE_FORBID = "square-forbid"
    SQUARE_FORBID_2 = "square-forbid-2"
    SQUARE_HALF = "square-half"
    SQUARE_KEY = "square-key"
    SQUARE_LETTER_A = "square-letter-a"
    SQUARE_LETTER_B = "square-letter-b"
    SQUARE_LETTER_C = "square-letter-c"
    SQUARE_LETTER_D = "square-letter-d"
    SQUARE_LETTER_E = "square-letter-e"
    SQUARE_LETTER_F = "square-letter-f"
    SQUARE_LETTER_G = "square-letter-g"
    SQUARE_LETTER_H = "square-letter-h"
    SQUARE_LETTER_I = "square-letter-i"
    SQUARE_LETTER_J = "square-letter-j"
    SQUARE_LETTER_K = "square-letter-k"
    SQUARE_LETTER_L = "square-letter-l"
    SQUARE_LETTER_M = "square-letter-m"
    SQUARE_LETTER_N = "square-letter-n"
    SQUARE_LETTER_O = "square-letter-o"
    SQUARE_LETTER_P = "square-letter-p"
    SQUARE_LETTER_Q = "square-letter-q"
    SQUARE_LETTER_R = "square-letter-r"
    SQUARE_LETTER_S = "square-letter-s"
    SQUARE_LETTER_T = "square-letter-t"
    SQUARE_LETTER_U = "square-letter-u"
    SQUARE_LETTER_V = "square-letter-v"
    SQUARE_LETTER_W = "square-letter-w"
    SQUARE_LETTER_X = "square-letter-x"
    SQUARE_LETTER_Y = "square-letter-y"
    SQUARE_LETTER_Z = "square-letter-z"
    SQUARE_MINUS = "square-minus"
    SQUARE_NUMBER_0 = "square-number-0"
    SQUARE_NUMBER_1 = "square-number-1"
    SQUARE_NUMBER_2 = "square-number-2"
    SQUARE_NUMBER_3 = "square-number-3"
    SQUARE_NUMBER_4 = "square-number-4"
    SQUARE_NUMBER_5 = "square-number-5"
    SQUARE_NUMBER_6 = "square-number-6"
    SQUARE_NUMBER_7 = "square-number-7"
    SQUARE_NUMBER_8 = "square-number-8"
    SQUARE_NUMBER_9 = "square-number-9"
    SQUARE_OFF = "square-off"
    SQUARE_PLUS = "square-plus"
    SQUARE_ROOT = "square-root"
    SQUARE_ROOT_2 = "square-root-2"
    SQUARE_ROTATED = "square-rotated"
    SQUARE_ROTATED_FILLED = "square-rotated-filled"
    SQUARE_ROTATED_FORBID = "square-rotated-forbid"
    SQUARE_ROTATED_FORBID_2 = "square-rotated-forbid-2"
    SQUARE_ROTATED_OFF = "square-rotated-off"
    SQUARE_ROUNDED = "square-rounded"
    SQUARE_ROUNDED_ARROW_DOWN = "square-rounded-arrow-down"
    SQUARE_ROUNDED_ARROW_DOWN_FILLED = "square-rounded-arrow-down-filled"
    SQUARE_ROUNDED_ARROW_LEFT = "square-rounded-arrow-left"
    SQUARE_ROUNDED_ARROW_LEFT_FILLED = "square-rounded-arrow-left-filled"
    SQUARE_ROUNDED_ARROW_RIGHT = "square-rounded-arrow-right"
    SQUARE_ROUNDED_ARROW_RIGHT_FILLED = "square-rounded-arrow-right-filled"
    SQUARE_ROUNDED_ARROW_UP = "square-rounded-arrow-up"
    SQUARE_ROUNDED_ARROW_UP_FILLED = "square-rounded-arrow-up-filled"
    SQUARE_ROUNDED_CHECK = "square-rounded-check"
    SQUARE_ROUNDED_CHECK_FILLED = "square-rounded-check-filled"
    SQUARE_ROUNDED_CHEVRON_DOWN = "square-rounded-chevron-down"
    SQUARE_ROUNDED_CHEVRON_DOWN_FILLED = "square-rounded-chevron-down-filled"
    SQUARE_ROUNDED_CHEVRON_LEFT = "square-rounded-chevron-left"
    SQUARE_ROUNDED_CHEVRON_LEFT_FILLED = "square-rounded-chevron-left-filled"
    SQUARE_ROUNDED_CHEVRON_RIGHT = "square-rounded-chevron-right"
    SQUARE_ROUNDED_CHEVRON_RIGHT_FILLED = "square-rounded-chevron-right-filled"
    SQUARE_ROUNDED_CHEVRON_UP = "square-rounded-chevron-up"
    SQUARE_ROUNDED_CHEVRON_UP_FILLED = "square-rounded-chevron-up-filled"
    SQUARE_ROUNDED_CHEVRONS_DOWN = "square-rounded-chevrons-down"
    SQUARE_ROUNDED_CHEVRONS_DOWN_FILLED = "square-rounded-chevrons-down-filled"
    SQUARE_ROUNDED_CHEVRONS_LEFT = "square-rounded-chevrons-left"
    SQUARE_ROUNDED_CHEVRONS_LEFT_FILLED = "square-rounded-chevrons-left-filled"
    SQUARE_ROUNDED_CHEVRONS_RIGHT = "square-rounded-chevrons-right"
    SQUARE_ROUNDED_CHEVRONS_RIGHT_FILLED = "square-rounded-chevrons-right-filled"
    SQUARE_ROUNDED_CHEVRONS_UP = "square-rounded-chevrons-up"
    SQUARE_ROUNDED_CHEVRONS_UP_FILLED = "square-rounded-chevrons-up-filled"
    SQUARE_ROUNDED_FILLED = "square-rounded-filled"
    SQUARE_ROUNDED_LETTER_A = "square-rounded-letter-a"
    SQUARE_ROUNDED_LETTER_B = "square-rounded-letter-b"
    SQUARE_ROUNDED_LETTER_C = "square-rounded-letter-c"
    SQUARE_ROUNDED_LETTER_D = "square-rounded-letter-d"
    SQUARE_ROUNDED_LETTER_E = "square-rounded-letter-e"
    SQUARE_ROUNDED_LETTER_F = "square-rounded-letter-f"
    SQUARE_ROUNDED_LETTER_G = "square-rounded-letter-g"
    SQUARE_ROUNDED_LETTER_H = "square-rounded-letter-h"
    SQUARE_ROUNDED_LETTER_I = "square-rounded-letter-i"
    SQUARE_ROUNDED_LETTER_J = "square-rounded-letter-j"
    SQUARE_ROUNDED_LETTER_K = "square-rounded-letter-k"
    SQUARE_ROUNDED_LETTER_L = "square-rounded-letter-l"
    SQUARE_ROUNDED_LETTER_M = "square-rounded-letter-m"
    SQUARE_ROUNDED_LETTER_N = "square-rounded-letter-n"
    SQUARE_ROUNDED_LETTER_O = "square-rounded-letter-o"
    SQUARE_ROUNDED_LETTER_P = "square-rounded-letter-p"
    SQUARE_ROUNDED_LETTER_Q = "square-rounded-letter-q"
    SQUARE_ROUNDED_LETTER_R = "square-rounded-letter-r"
    SQUARE_ROUNDED_LETTER_S = "square-rounded-letter-s"
    SQUARE_ROUNDED_LETTER_T = "square-rounded-letter-t"
    SQUARE_ROUNDED_LETTER_U = "square-rounded-letter-u"
    SQUARE_ROUNDED_LETTER_V = "square-rounded-letter-v"
    SQUARE_ROUNDED_LETTER_W = "square-rounded-letter-w"
    SQUARE_ROUNDED_LETTER_X = "square-rounded-letter-x"
    SQUARE_ROUNDED_LETTER_Y = "square-rounded-letter-y"
    SQUARE_ROUNDED_LETTER_Z = "square-rounded-letter-z"
    SQUARE_ROUNDED_MINUS = "square-rounded-minus"
    SQUARE_ROUNDED_NUMBER_0 = "square-rounded-number-0"
    SQUARE_ROUNDED_NUMBER_0_FILLED = "square-rounded-number-0-filled"
    SQUARE_ROUNDED_NUMBER_1 = "square-rounded-number-1"
    SQUARE_ROUNDED_NUMBER_1_FILLED = "square-rounded-number-1-filled"
    SQUARE_ROUNDED_NUMBER_2 = "square-rounded-number-2"
    SQUARE_ROUNDED_NUMBER_2_FILLED = "square-rounded-number-2-filled"
    SQUARE_ROUNDED_NUMBER_3 = "square-rounded-number-3"
    SQUARE_ROUNDED_NUMBER_3_FILLED = "square-rounded-number-3-filled"
    SQUARE_ROUNDED_NUMBER_4 = "square-rounded-number-4"
    SQUARE_ROUNDED_NUMBER_4_FILLED = "square-rounded-number-4-filled"
    SQUARE_ROUNDED_NUMBER_5 = "square-rounded-number-5"
    SQUARE_ROUNDED_NUMBER_5_FILLED = "square-rounded-number-5-filled"
    SQUARE_ROUNDED_NUMBER_6 = "square-rounded-number-6"
    SQUARE_ROUNDED_NUMBER_6_FILLED = "square-rounded-number-6-filled"
    SQUARE_ROUNDED_NUMBER_7 = "square-rounded-number-7"
    SQUARE_ROUNDED_NUMBER_7_FILLED = "square-rounded-number-7-filled"
    SQUARE_ROUNDED_NUMBER_8 = "square-rounded-number-8"
    SQUARE_ROUNDED_NUMBER_8_FILLED = "square-rounded-number-8-filled"
    SQUARE_ROUNDED_NUMBER_9 = "square-rounded-number-9"
    SQUARE_ROUNDED_NUMBER_9_FILLED = "square-rounded-number-9-filled"
    SQUARE_ROUNDED_PLUS = "square-rounded-plus"
    SQUARE_ROUNDED_PLUS_FILLED = "square-rounded-plus-filled"
    SQUARE_ROUNDED_X = "square-rounded-x"
    SQUARE_ROUNDED_X_FILLED = "square-rounded-x-filled"
    SQUARE_TOGGLE = "square-toggle"
    SQUARE_TOGGLE_HORIZONTAL = "square-toggle-horizontal"
    SQUARE_X = "square-x"
    SQUARES_DIAGONAL = "squares-diagonal"
    SQUARES_FILLED = "squares-filled"
    STACK = "stack"
    STACK_2 = "stack-2"
    STACK_3 = "stack-3"
    STACK_POP = "stack-pop"
    STACK_PUSH = "stack-push"
    STAIRS = "stairs"
    STAIRS_DOWN = "stairs-down"
    STAIRS_UP = "stairs-up"
    STAR = "star"
    STAR_FILLED = "star-filled"
    STAR_HALF = "star-half"
    STAR_HALF_FILLED = "star-half-filled"
    STAR_OFF = "star-off"
    STARS = "stars"
    STARS_FILLED = "stars-filled"
    STARS_OFF = "stars-off"
    STATUS_CHANGE = "status-change"
    STEAM = "steam"
    STEERING_WHEEL = "steering-wheel"
    STEERING_WHEEL_OFF = "steering-wheel-off"
    STEP_INTO = "step-into"
    STEP_OUT = "step-out"
    STEREO_GLASSES = "stereo-glasses"
    STETHOSCOPE = "stethoscope"
    STETHOSCOPE_OFF = "stethoscope-off"
    STICKER = "sticker"
    STORM = "storm"
    STORM_OFF = "storm-off"
    STRETCHING = "stretching"
    STRETCHING_2 = "stretching-2"
    STRIKETHROUGH = "strikethrough"
    SUBMARINE = "submarine"
    SUBSCRIPT = "subscript"
    SUBTASK = "subtask"
    SUM = "sum"
    SUM_OFF = "sum-off"
    SUN = "sun"
    SUN_FILLED = "sun-filled"
    SUN_HIGH = "sun-high"
    SUN_LOW = "sun-low"
    SUN_MOON = "sun-moon"
    SUN_OFF = "sun-off"
    SUN_WIND = "sun-wind"
    SUNGLASSES = "sunglasses"
    SUNRISE = "sunrise"
    SUNSET = "sunset"
    SUNSET_2 = "sunset-2"
    SUPERSCRIPT = "superscript"
    SVG = "svg"
    SWIMMING = "swimming"
    SWIPE = "swipe"
    SWITCH = "switch"
    SWITCH_2 = "switch-2"
    SWITCH_3 = "switch-3"
    SWITCH_HORIZONTAL = "switch-horizontal"
    SWITCH_VERTICAL = "switch-vertical"
    SWORD = "sword"
    SWORD_OFF = "sword-off"
    SWORDS = "swords"
    TABLE = "table"
    TABLE_ALIAS = "table-alias"
    TABLE_COLUMN = "table-column"
    TABLE_DOWN = "table-down"
    TABLE_EXPORT = "table-export"
    TABLE_FILLED = "table-filled"
    TABLE_HEART = "table-heart"
    TABLE_IMPORT = "table-import"
    TABLE_MINUS = "table-minus"
    TABLE_OFF = "table-off"
    TABLE_OPTIONS = "table-options"
    TABLE_PLUS = "table-plus"
    TABLE_ROW = "table-row"
    TABLE_SHARE = "table-share"
    TABLE_SHORTCUT = "table-shortcut"
    TAG = "tag"
    TAG_OFF = "tag-off"
    TAGS = "tags"
    TAGS_OFF = "tags-off"
    TALLYMARK_1 = "tallymark-1"
    TALLYMARK_2 = "tallymark-2"
    TALLYMARK_3 = "tallymark-3"
    TALLYMARK_4 = "tallymark-4"
    TALLYMARKS = "tallymarks"
    TANK = "tank"
    TARGET = "target"
    TARGET_ARROW = "target-arrow"
    TARGET_OFF = "target-off"
    TEAPOT = "teapot"
    TELESCOPE = "telescope"
    TELESCOPE_OFF = "telescope-off"
    TEMPERATURE = "temperature"
    TEMPERATURE_CELSIUS = "temperature-celsius"
    TEMPERATURE_FAHRENHEIT = "temperature-fahrenheit"
    TEMPERATURE_MINUS = "temperature-minus"
    TEMPERATURE_OFF = "temperature-off"
    TEMPERATURE_PLUS = "temperature-plus"
    TEMPLATE = "template"
    TEMPLATE_OFF = "template-off"
    TENT = "tent"
    TENT_OFF = "tent-off"
    TERMINAL = "terminal"
    TERMINAL_2 = "terminal-2"
    TEST_PIPE = "test-pipe"
    TEST_PIPE_2 = "test-pipe-2"
    TEST_PIPE_OFF = "test-pipe-off"
    TEX = "tex"
    TEXT_CAPTION = "text-caption"
    TEXT_COLOR = "text-color"
    TEXT_DECREASE = "text-decrease"
    TEXT_DIRECTION_LTR = "text-direction-ltr"
    TEXT_DIRECTION_RTL = "text-direction-rtl"
    TEXT_INCREASE = "text-increase"
    TEXT_ORIENTATION = "text-orientation"
    TEXT_PLUS = "text-plus"
    TEXT_RECOGNITION = "text-recognition"
    TEXT_RESIZE = "text-resize"
    TEXT_SIZE = "text-size"
    TEXT_SPELLCHECK = "text-spellcheck"
    TEXT_WRAP = "text-wrap"
    TEXT_WRAP_DISABLED = "text-wrap-disabled"
    TEXTURE = "texture"
    THEATER = "theater"
    THERMOMETER = "thermometer"
    THUMB_DOWN = "thumb-down"
    THUMB_DOWN_FILLED = "thumb-down-filled"
    THUMB_DOWN_OFF = "thumb-down-off"
    THUMB_UP = "thumb-up"
    THUMB_UP_FILLED = "thumb-up-filled"
    THUMB_UP_OFF = "thumb-up-off"
    TIC_TAC = "tic-tac"
    TICKET = "ticket"
    TICKET_OFF = "ticket-off"
    TIE = "tie"
    TILDE = "tilde"
    TILT_SHIFT = "tilt-shift"
    TILT_SHIFT_OFF = "tilt-shift-off"
    TIME_DURATION_0 = "time-duration-0"
    TIME_DURATION_10 = "time-duration-10"
    TIME_DURATION_15 = "time-duration-15"
    TIME_DURATION_30 = "time-duration-30"
    TIME_DURATION_45 = "time-duration-45"
    TIME_DURATION_5 = "time-duration-5"
    TIME_DURATION_60 = "time-duration-60"
    TIME_DURATION_90 = "time-duration-90"
    TIME_DURATION_OFF = "time-duration-off"
    TIMELINE = "timeline"
    TIMELINE_EVENT = "timeline-event"
    TIMELINE_EVENT_EXCLAMATION = "timeline-event-exclamation"
    TIMELINE_EVENT_MINUS = "timeline-event-minus"
    TIMELINE_EVENT_PLUS = "timeline-event-plus"
    TIMELINE_EVENT_TEXT = "timeline-event-text"
    TIMELINE_EVENT_X = "timeline-event-x"
    TIR = "tir"
    TOGGLE_LEFT = "toggle-left"
    TOGGLE_RIGHT = "toggle-right"
    TOILET_PAPER = "toilet-paper"
    TOILET_PAPER_OFF = "toilet-paper-off"
    TOML = "toml"
    TOOL = "tool"
    TOOLS = "tools"
    TOOLS_KITCHEN = "tools-kitchen"
    TOOLS_KITCHEN_2 = "tools-kitchen-2"
    TOOLS_KITCHEN_2_OFF = "tools-kitchen-2-off"
    TOOLS_KITCHEN_OFF = "tools-kitchen-off"
    TOOLS_OFF = "tools-off"
    TOOLTIP = "tooltip"
    TOPOLOGY_BUS = "topology-bus"
    TOPOLOGY_COMPLEX = "topology-complex"
    TOPOLOGY_FULL = "topology-full"
    TOPOLOGY_FULL_HIERARCHY = "topology-full-hierarchy"
    TOPOLOGY_RING = "topology-ring"
    TOPOLOGY_RING_2 = "topology-ring-2"
    TOPOLOGY_RING_3 = "topology-ring-3"
    TOPOLOGY_STAR = "topology-star"
    TOPOLOGY_STAR_2 = "topology-star-2"
    TOPOLOGY_STAR_3 = "topology-star-3"
    TOPOLOGY_STAR_RING = "topology-star-ring"
    TOPOLOGY_STAR_RING_2 = "topology-star-ring-2"
    TOPOLOGY_STAR_RING_3 = "topology-star-ring-3"
    TORII = "torii"
    TORNADO = "tornado"
    TOURNAMENT = "tournament"
    TOWER = "tower"
    TOWER_OFF = "tower-off"
    TRACK = "track"
    TRACTOR = "tractor"
    TRADEMARK = "trademark"
    TRAFFIC_CONE = "traffic-cone"
    TRAFFIC_CONE_OFF = "traffic-cone-off"
    TRAFFIC_LIGHTS = "traffic-lights"
    TRAFFIC_LIGHTS_OFF = "traffic-lights-off"
    TRAIN = "train"
    TRANSFER_IN = "transfer-in"
    TRANSFER_OUT = "transfer-out"
    TRANSFORM = "transform"
    TRANSFORM_FILLED = "transform-filled"
    TRANSITION_BOTTOM = "transition-bottom"
    TRANSITION_LEFT = "transition-left"
    TRANSITION_RIGHT = "transition-right"
    TRANSITION_TOP = "transition-top"
    TRASH = "trash"
    TRASH_FILLED = "trash-filled"
    TRASH_OFF = "trash-off"
    TRASH_X = "trash-x"
    TRASH_X_FILLED = "trash-x-filled"
    TREADMILL = "treadmill"
    TREE = "tree"
    TREES = "trees"
    TREKKING = "trekking"
    TRENDING_DOWN = "trending-down"
    TRENDING_DOWN_2 = "trending-down-2"
    TRENDING_DOWN_3 = "trending-down-3"
    TRENDING_UP = "trending-up"
    TRENDING_UP_2 = "trending-up-2"
    TRENDING_UP_3 = "trending-up-3"
    TRIANGLE = "triangle"
    TRIANGLE_FILLED = "triangle-filled"
    TRIANGLE_INVERTED = "triangle-inverted"
    TRIANGLE_INVERTED_FILLED = "triangle-inverted-filled"
    TRIANGLE_OFF = "triangle-off"
    TRIANGLE_SQUARE_CIRCLE = "triangle-square-circle"
    TRIANGLES = "triangles"
    TRIDENT = "trident"
    TROLLEY = "trolley"
    TROPHY = "trophy"
    TROPHY_FILLED = "trophy-filled"
    TROPHY_OFF = "trophy-off"
    TROWEL = "trowel"
    TRUCK = "truck"
    TRUCK_DELIVERY = "truck-delivery"
    TRUCK_LOADING = "truck-loading"
    TRUCK_OFF = "truck-off"
    TRUCK_RETURN = "truck-return"
    TXT = "txt"
    TYPOGRAPHY = "typography"
    TYPOGRAPHY_OFF = "typography-off"
    UFO = "ufo"
    UFO_OFF = "ufo-off"
    UMBRELLA = "umbrella"
    UMBRELLA_FILLED = "umbrella-filled"
    UMBRELLA_OFF = "umbrella-off"
    UNDERLINE = "underline"
    UNLINK = "unlink"
    UPLOAD = "upload"
    URGENT = "urgent"
    USB = "usb"
    USER = "user"
    USER_BOLT = "user-bolt"
    USER_CANCEL = "user-cancel"
    USER_CHECK = "user-check"
    USER_CIRCLE = "user-circle"
    USER_CODE = "user-code"
    USER_COG = "user-cog"
    USER_DOLLAR = "user-dollar"
    USER_DOWN = "user-down"
    USER_EDIT = "user-edit"
    USER_EXCLAMATION = "user-exclamation"
    USER_HEART = "user-heart"
    USER_MINUS = "user-minus"
    USER_OFF = "user-off"
    USER_PAUSE = "user-pause"
    USER_PIN = "user-pin"
    USER_PLUS = "user-plus"
    USER_QUESTION = "user-question"
    USER_SEARCH = "user-search"
    USER_SHARE = "user-share"
    USER_SHIELD = "user-shield"
    USER_STAR = "user-star"
    USER_UP = "user-up"
    USER_X = "user-x"
    USERS = "users"
    USERS_GROUP = "users-group"
    USERS_MINUS = "users-minus"
    USERS_PLUS = "users-plus"
    UV_INDEX = "uv-index"
    UX_CIRCLE = "ux-circle"
    VACCINE = "vaccine"
    VACCINE_BOTTLE = "vaccine-bottle"
    VACCINE_BOTTLE_OFF = "vaccine-bottle-off"
    VACCINE_OFF = "vaccine-off"
    VACUUM_CLEANER = "vacuum-cleaner"
    VARIABLE = "variable"
    VARIABLE_MINUS = "variable-minus"
    VARIABLE_OFF = "variable-off"
    VARIABLE_PLUS = "variable-plus"
    VECTOR = "vector"
    VECTOR_BEZIER = "vector-bezier"
    VECTOR_BEZIER_2 = "vector-bezier-2"
    VECTOR_BEZIER_ARC = "vector-bezier-arc"
    VECTOR_BEZIER_CIRCLE = "vector-bezier-circle"
    VECTOR_OFF = "vector-off"
    VECTOR_SPLINE = "vector-spline"
    VECTOR_TRIANGLE = "vector-triangle"
    VECTOR_TRIANGLE_OFF = "vector-triangle-off"
    VENUS = "venus"
    VERSIONS = "versions"
    VERSIONS_FILLED = "versions-filled"
    VERSIONS_OFF = "versions-off"
    VIDEO = "video"
    VIDEO_MINUS = "video-minus"
    VIDEO_OFF = "video-off"
    VIDEO_PLUS = "video-plus"
    VIEW_360 = "view-360"
    VIEW_360_OFF = "view-360-off"
    VIEWFINDER = "viewfinder"
    VIEWFINDER_OFF = "viewfinder-off"
    VIEWPORT_NARROW = "viewport-narrow"
    VIEWPORT_WIDE = "viewport-wide"
    VINYL = "vinyl"
    VIP = "vip"
    VIP_OFF = "vip-off"
    VIRUS = "virus"
    VIRUS_OFF = "virus-off"
    VIRUS_SEARCH = "virus-search"
    VOCABULARY = "vocabulary"
    VOCABULARY_OFF = "vocabulary-off"
    VOLCANO = "volcano"
    VOLUME = "volume"
    VOLUME_2 = "volume-2"
    VOLUME_3 = "volume-3"
    VOLUME_OFF = "volume-off"
    WALK = "walk"
    WALL = "wall"
    WALL_OFF = "wall-off"
    WALLET = "wallet"
    WALLET_OFF = "wallet-off"
    WALLPAPER = "wallpaper"
    WALLPAPER_OFF = "wallpaper-off"
    WAND = "wand"
    WAND_OFF = "wand-off"
    WASH = "wash"
    WASH_DRY = "wash-dry"
    WASH_DRY_1 = "wash-dry-1"
    WASH_DRY_2 = "wash-dry-2"
    WASH_DRY_3 = "wash-dry-3"
    WASH_DRY_A = "wash-dry-a"
    WASH_DRY_DIP = "wash-dry-dip"
    WASH_DRY_F = "wash-dry-f"
    WASH_DRY_FLAT = "wash-dry-flat"
    WASH_DRY_HANG = "wash-dry-hang"
    WASH_DRY_OFF = "wash-dry-off"
    WASH_DRY_P = "wash-dry-p"
    WASH_DRY_SHADE = "wash-dry-shade"
    WASH_DRY_W = "wash-dry-w"
    WASH_DRYCLEAN = "wash-dryclean"
    WASH_DRYCLEAN_OFF = "wash-dryclean-off"
    WASH_ECO = "wash-eco"
    WASH_GENTLE = "wash-gentle"
    WASH_HAND = "wash-hand"
    WASH_MACHINE = "wash-machine"
    WASH_OFF = "wash-off"
    WASH_PRESS = "wash-press"
    WASH_TEMPERATURE_1 = "wash-temperature-1"
    WASH_TEMPERATURE_2 = "wash-temperature-2"
    WASH_TEMPERATURE_3 = "wash-temperature-3"
    WASH_TEMPERATURE_4 = "wash-temperature-4"
    WASH_TEMPERATURE_5 = "wash-temperature-5"
    WASH_TEMPERATURE_6 = "wash-temperature-6"
    WASH_TUMBLE_DRY = "wash-tumble-dry"
    WASH_TUMBLE_OFF = "wash-tumble-off"
    WATERPOLO = "waterpolo"
    WAVE_SAW_TOOL = "wave-saw-tool"
    WAVE_SINE = "wave-sine"
    WAVE_SQUARE = "wave-square"
    WEBHOOK = "webhook"
    WEBHOOK_OFF = "webhook-off"
    WEIGHT = "weight"
    WHEELCHAIR = "wheelchair"
    WHEELCHAIR_OFF = "wheelchair-off"
    WHIRL = "whirl"
    WIFI = "wifi"
    WIFI_0 = "wifi-0"
    WIFI_1 = "wifi-1"
    WIFI_2 = "wifi-2"
    WIFI_OFF = "wifi-off"
    WIND = "wind"
    WIND_OFF = "wind-off"
    WINDMILL = "windmill"
    WINDMILL_FILLED = "windmill-filled"
    WINDMILL_OFF = "windmill-off"
    WINDOW = "window"
    WINDOW_MAXIMIZE = "window-maximize"
    WINDOW_MINIMIZE = "window-minimize"
    WINDOW_OFF = "window-off"
    WINDSOCK = "windsock"
    WIPER = "wiper"
    WIPER_WASH = "wiper-wash"
    WOMAN = "woman"
    WOOD = "wood"
    WORLD = "world"
    WORLD_BOLT = "world-bolt"
    WORLD_CANCEL = "world-cancel"
    WORLD_CHECK = "world-check"
    WORLD_CODE = "world-code"
    WORLD_COG = "world-cog"
    WORLD_DOLLAR = "world-dollar"
    WORLD_DOWN = "world-down"
    WORLD_DOWNLOAD = "world-download"
    WORLD_EXCLAMATION = "world-exclamation"
    WORLD_HEART = "world-heart"
    WORLD_LATITUDE = "world-latitude"
    WORLD_LONGITUDE = "world-longitude"
    WORLD_MINUS = "world-minus"
    WORLD_OFF = "world-off"
    WORLD_PAUSE = "world-pause"
    WORLD_PIN = "world-pin"
    WORLD_PLUS = "world-plus"
    WORLD_QUESTION = "world-question"
    WORLD_SEARCH = "world-search"
    WORLD_SHARE = "world-share"
    WORLD_STAR = "world-star"
    WORLD_UP = "world-up"
    WORLD_UPLOAD = "world-upload"
    WORLD_WWW = "world-www"
    WORLD_X = "world-x"
    WRECKING_BALL = "wrecking-ball"
    WRITING = "writing"
    WRITING_OFF = "writing-off"
    WRITING_SIGN = "writing-sign"
    WRITING_SIGN_OFF = "writing-sign-off"
    X = "x"
    XBOX_A = "xbox-a"
    XBOX_B = "xbox-b"
    XBOX_X = "xbox-x"
    XBOX_Y = "xbox-y"
    XD = "xd"
    YIN_YANG = "yin-yang"
    YIN_YANG_FILLED = "yin-yang-filled"
    YOGA = "yoga"
    ZEPPELIN = "zeppelin"
    ZEPPELIN_OFF = "zeppelin-off"
    ZIP = "zip"
    ZODIAC_AQUARIUS = "zodiac-aquarius"
    ZODIAC_ARIES = "zodiac-aries"
    ZODIAC_CANCER = "zodiac-cancer"
    ZODIAC_CAPRICORN = "zodiac-capricorn"
    ZODIAC_GEMINI = "zodiac-gemini"
    ZODIAC_LEO = "zodiac-leo"
    ZODIAC_LIBRA = "zodiac-libra"
    ZODIAC_PISCES = "zodiac-pisces"
    ZODIAC_SAGITTARIUS = "zodiac-sagittarius"
    ZODIAC_SCORPIO = "zodiac-scorpio"
    ZODIAC_TAURUS = "zodiac-taurus"
    ZODIAC_VIRGO = "zodiac-virgo"
    ZOOM_CANCEL = "zoom-cancel"
    ZOOM_CHECK = "zoom-check"
    ZOOM_CHECK_FILLED = "zoom-check-filled"
    ZOOM_CODE = "zoom-code"
    ZOOM_EXCLAMATION = "zoom-exclamation"
    ZOOM_FILLED = "zoom-filled"
    ZOOM_IN = "zoom-in"
    ZOOM_IN_AREA = "zoom-in-area"
    ZOOM_IN_AREA_FILLED = "zoom-in-area-filled"
    ZOOM_IN_FILLED = "zoom-in-filled"
    ZOOM_MONEY = "zoom-money"
    ZOOM_OUT = "zoom-out"
    ZOOM_OUT_AREA = "zoom-out-area"
    ZOOM_OUT_FILLED = "zoom-out-filled"
    ZOOM_PAN = "zoom-pan"
    ZOOM_QUESTION = "zoom-question"
    ZOOM_REPLACE = "zoom-replace"
    ZOOM_RESET = "zoom-reset"
    ZZZ = "zzz"
    ZZZ_OFF = "zzz-off"
